/****************************************************************************
** Meta object code from reading C++ file 'individualtransport.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.12.0)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../../kpublictransport-26.07.90/src/lib/datatypes/individualtransport.h"
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'individualtransport.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.12.0. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN16KPublicTransport19IndividualTransportE_t {};
} // unnamed namespace

template <> constexpr inline auto KPublicTransport::IndividualTransport::qt_create_metaobjectdata<qt_meta_tag_ZN16KPublicTransport19IndividualTransportE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "KPublicTransport::IndividualTransport",
        "modeIconName",
        "",
        "KPublicTransport::IndividualTransport::Mode",
        "mode",
        "Mode",
        "label",
        "qualifier",
        "Qualifier",
        "Walk",
        "Bike",
        "Car",
        "None",
        "Park",
        "Rent",
        "Dropoff",
        "Pickup"
    };

    QtMocHelpers::UintData qt_methods {
        // Method 'modeIconName'
        QtMocHelpers::MethodData<QString(KPublicTransport::IndividualTransport::Mode)>(1, 2, QMC::AccessPublic, QMetaType::QString, {{
            { 0x80000000 | 3, 4 },
        }}),
    };
    QtMocHelpers::UintData qt_properties {
        // property 'mode'
        QtMocHelpers::PropertyData<enum Mode>(4, 0x80000000 | 5, QMC::DefaultPropertyFlags | QMC::Writable | QMC::EnumOrFlag | QMC::StdCppSet),
        // property 'modeIconName'
        QtMocHelpers::PropertyData<QString>(1, QMetaType::QString, QMC::Readable | QMC::Designable | QMC::Scriptable),
        // property 'label'
        QtMocHelpers::PropertyData<QString>(6, QMetaType::QString, QMC::Readable | QMC::Designable | QMC::Scriptable),
        // property 'qualifier'
        QtMocHelpers::PropertyData<enum Qualifier>(7, 0x80000000 | 8, QMC::DefaultPropertyFlags | QMC::Writable | QMC::EnumOrFlag | QMC::StdCppSet),
    };
    QtMocHelpers::UintData qt_enums {
        // enum 'Mode'
        QtMocHelpers::EnumData<enum Mode>(5, 5, QMC::EnumFlags{}).add({
            {    9, Mode::Walk },
            {   10, Mode::Bike },
            {   11, Mode::Car },
        }),
        // enum 'Qualifier'
        QtMocHelpers::EnumData<enum Qualifier>(8, 8, QMC::EnumFlags{}).add({
            {   12, Qualifier::None },
            {   13, Qualifier::Park },
            {   14, Qualifier::Rent },
            {   15, Qualifier::Dropoff },
            {   16, Qualifier::Pickup },
        }),
    };
    return QtMocHelpers::metaObjectData<IndividualTransport, qt_meta_tag_ZN16KPublicTransport19IndividualTransportE_t>(QMC::PropertyAccessInStaticMetaCall, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject KPublicTransport::IndividualTransport::staticMetaObject = { {
    nullptr,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN16KPublicTransport19IndividualTransportE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN16KPublicTransport19IndividualTransportE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN16KPublicTransport19IndividualTransportE_t>.metaTypes,
    nullptr
} };

void KPublicTransport::IndividualTransport::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = reinterpret_cast<IndividualTransport *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: { QString _r = _t->modeIconName((*reinterpret_cast<std::add_pointer_t<KPublicTransport::IndividualTransport::Mode>>(_a[1])));
            if (_a[0]) *reinterpret_cast<QString*>(_a[0]) = std::move(_r); }  break;
        default: ;
        }
    }
    if (_c == QMetaObject::ReadProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: *reinterpret_cast<enum Mode*>(_v) = _t->mode(); break;
        case 1: *reinterpret_cast<QString*>(_v) = _t->modeIconName(); break;
        case 2: *reinterpret_cast<QString*>(_v) = _t->label(); break;
        case 3: *reinterpret_cast<enum Qualifier*>(_v) = _t->qualifier(); break;
        default: break;
        }
    }
    if (_c == QMetaObject::WriteProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: _t->setMode(*reinterpret_cast<enum Mode*>(_v)); break;
        case 3: _t->setQualifier(*reinterpret_cast<enum Qualifier*>(_v)); break;
        default: break;
        }
    }
}
QT_WARNING_POP
