/****************************************************************************
** Meta object code from reading C++ file 'locationrequest.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.12.0)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../../kpublictransport-26.07.90/src/lib/locationrequest.h"
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'locationrequest.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.12.0. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN16KPublicTransport15LocationRequestE_t {};
} // unnamed namespace

template <> constexpr inline auto KPublicTransport::LocationRequest::qt_create_metaobjectdata<qt_meta_tag_ZN16KPublicTransport15LocationRequestE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "KPublicTransport::LocationRequest",
        "location",
        "KPublicTransport::Location",
        "latitude",
        "longitude",
        "name",
        "backends",
        "maximumDistance",
        "maximumResults",
        "types",
        "KPublicTransport::Location::Types",
        "viewbox",
        "QRectF",
        "downloadAssets"
    };

    QtMocHelpers::UintData qt_methods {
    };
    QtMocHelpers::UintData qt_properties {
        // property 'location'
        QtMocHelpers::PropertyData<KPublicTransport::Location>(1, 0x80000000 | 2, QMC::DefaultPropertyFlags | QMC::Writable | QMC::EnumOrFlag | QMC::StdCppSet),
        // property 'latitude'
        QtMocHelpers::PropertyData<double>(3, QMetaType::Double, QMC::Readable | QMC::Writable | QMC::Designable | QMC::Scriptable | QMC::StdCppSet),
        // property 'longitude'
        QtMocHelpers::PropertyData<double>(4, QMetaType::Double, QMC::Readable | QMC::Writable | QMC::Designable | QMC::Scriptable | QMC::StdCppSet),
        // property 'name'
        QtMocHelpers::PropertyData<QString>(5, QMetaType::QString, QMC::Readable | QMC::Writable | QMC::Designable | QMC::Scriptable | QMC::StdCppSet),
        // property 'backends'
        QtMocHelpers::PropertyData<QStringList>(6, QMetaType::QStringList, QMC::DefaultPropertyFlags | QMC::Writable),
        // property 'maximumDistance'
        QtMocHelpers::PropertyData<int>(7, QMetaType::Int, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet),
        // property 'maximumResults'
        QtMocHelpers::PropertyData<int>(8, QMetaType::Int, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet),
        // property 'types'
        QtMocHelpers::PropertyData<KPublicTransport::Location::Types>(9, 0x80000000 | 10, QMC::DefaultPropertyFlags | QMC::Writable | QMC::EnumOrFlag | QMC::StdCppSet),
        // property 'viewbox'
        QtMocHelpers::PropertyData<QRectF>(11, 0x80000000 | 12, QMC::DefaultPropertyFlags | QMC::Writable | QMC::EnumOrFlag | QMC::StdCppSet),
        // property 'downloadAssets'
        QtMocHelpers::PropertyData<bool>(13, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet),
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<LocationRequest, qt_meta_tag_ZN16KPublicTransport15LocationRequestE_t>(QMC::PropertyAccessInStaticMetaCall, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT static const QMetaObject::SuperData qt_meta_extradata_ZN16KPublicTransport15LocationRequestE[] = {
    QMetaObject::SuperData::link<KPublicTransport::Location::staticMetaObject>(),
    nullptr
};

Q_CONSTINIT const QMetaObject KPublicTransport::LocationRequest::staticMetaObject = { {
    nullptr,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN16KPublicTransport15LocationRequestE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN16KPublicTransport15LocationRequestE_t>.data,
    qt_static_metacall,
    qt_meta_extradata_ZN16KPublicTransport15LocationRequestE,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN16KPublicTransport15LocationRequestE_t>.metaTypes,
    nullptr
} };

void KPublicTransport::LocationRequest::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = reinterpret_cast<LocationRequest *>(_o);
    if (_c == QMetaObject::RegisterPropertyMetaType) {
        switch (_id) {
        default: *reinterpret_cast<int*>(_a[0]) = -1; break;
        case 0:
            *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< KPublicTransport::Location >(); break;
        }
    }
    if (_c == QMetaObject::ReadProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: *reinterpret_cast<KPublicTransport::Location*>(_v) = _t->location(); break;
        case 1: *reinterpret_cast<double*>(_v) = _t->latitude(); break;
        case 2: *reinterpret_cast<double*>(_v) = _t->longitude(); break;
        case 3: *reinterpret_cast<QString*>(_v) = _t->name(); break;
        case 4: *reinterpret_cast<QStringList*>(_v) = _t->backendIds(); break;
        case 5: *reinterpret_cast<int*>(_v) = _t->maximumDistance(); break;
        case 6: *reinterpret_cast<int*>(_v) = _t->maximumResults(); break;
        case 7: *reinterpret_cast<KPublicTransport::Location::Types*>(_v) = _t->types(); break;
        case 8: *reinterpret_cast<QRectF*>(_v) = _t->viewbox(); break;
        case 9: *reinterpret_cast<bool*>(_v) = _t->downloadAssets(); break;
        default: break;
        }
    }
    if (_c == QMetaObject::WriteProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: _t->setLocation(*reinterpret_cast<KPublicTransport::Location*>(_v)); break;
        case 1: _t->setLatitude(*reinterpret_cast<double*>(_v)); break;
        case 2: _t->setLongitude(*reinterpret_cast<double*>(_v)); break;
        case 3: _t->setName(*reinterpret_cast<QString*>(_v)); break;
        case 4: _t->setBackendIds(*reinterpret_cast<QStringList*>(_v)); break;
        case 5: _t->setMaximumDistance(*reinterpret_cast<int*>(_v)); break;
        case 6: _t->setMaximumResults(*reinterpret_cast<int*>(_v)); break;
        case 7: _t->setTypes(*reinterpret_cast<KPublicTransport::Location::Types*>(_v)); break;
        case 8: _t->setViewbox(*reinterpret_cast<QRectF*>(_v)); break;
        case 9: _t->setDownloadAssets(*reinterpret_cast<bool*>(_v)); break;
        default: break;
        }
    }
}
QT_WARNING_POP
