/****************************************************************************
** Meta object code from reading C++ file 'openjourneyplannerbackend.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.12.0)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../../kpublictransport-26.07.90/src/lib/backends/openjourneyplannerbackend.h"
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'openjourneyplannerbackend.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.12.0. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN16KPublicTransport25OpenJourneyPlannerBackendE_t {};
} // unnamed namespace

template <> constexpr inline auto KPublicTransport::OpenJourneyPlannerBackend::qt_create_metaobjectdata<qt_meta_tag_ZN16KPublicTransport25OpenJourneyPlannerBackendE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "KPublicTransport::OpenJourneyPlannerBackend",
        "endpoint",
        "QUrl",
        "authorization",
        "requestorRef",
        "supportedModes",
        "QJsonArray",
        "protocol",
        "Protocol",
        "supportsTripQueries",
        "contentType",
        "uicLocationIdentifierType",
        "hafasAttributeMap",
        "OJP1",
        "OJP2",
        "TRIAS"
    };

    QtMocHelpers::UintData qt_methods {
    };
    QtMocHelpers::UintData qt_properties {
        // property 'endpoint'
        QtMocHelpers::PropertyData<QUrl>(1, 0x80000000 | 2, QMC::DefaultPropertyFlags | QMC::Writable | QMC::EnumOrFlag),
        // property 'authorization'
        QtMocHelpers::PropertyData<QString>(3, QMetaType::QString, QMC::DefaultPropertyFlags | QMC::Writable),
        // property 'requestorRef'
        QtMocHelpers::PropertyData<QString>(4, QMetaType::QString, QMC::DefaultPropertyFlags | QMC::Writable),
        // property 'supportedModes'
        QtMocHelpers::PropertyData<QJsonArray>(5, 0x80000000 | 6, QMC::Writable | QMC::Designable | QMC::Scriptable | QMC::Stored | QMC::EnumOrFlag | QMC::StdCppSet),
        // property 'protocol'
        QtMocHelpers::PropertyData<enum Protocol>(7, 0x80000000 | 8, QMC::DefaultPropertyFlags | QMC::Writable | QMC::EnumOrFlag),
        // property 'supportsTripQueries'
        QtMocHelpers::PropertyData<bool>(9, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable),
        // property 'contentType'
        QtMocHelpers::PropertyData<QByteArray>(10, QMetaType::QByteArray, QMC::DefaultPropertyFlags | QMC::Writable),
        // property 'uicLocationIdentifierType'
        QtMocHelpers::PropertyData<QString>(11, QMetaType::QString, QMC::DefaultPropertyFlags | QMC::Writable),
        // property 'hafasAttributeMap'
        QtMocHelpers::PropertyData<QString>(12, QMetaType::QString, QMC::DefaultPropertyFlags | QMC::Writable),
    };
    QtMocHelpers::UintData qt_enums {
        // enum 'Protocol'
        QtMocHelpers::EnumData<enum Protocol>(8, 8, QMC::EnumFlags{}).add({
            {   13, Protocol::OJP1 },
            {   14, Protocol::OJP2 },
            {   15, Protocol::TRIAS },
        }),
    };
    return QtMocHelpers::metaObjectData<OpenJourneyPlannerBackend, qt_meta_tag_ZN16KPublicTransport25OpenJourneyPlannerBackendE_t>(QMC::PropertyAccessInStaticMetaCall, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject KPublicTransport::OpenJourneyPlannerBackend::staticMetaObject = { {
    QtPrivate::MetaObjectForType<AbstractBackend>::value,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN16KPublicTransport25OpenJourneyPlannerBackendE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN16KPublicTransport25OpenJourneyPlannerBackendE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN16KPublicTransport25OpenJourneyPlannerBackendE_t>.metaTypes,
    nullptr
} };

void KPublicTransport::OpenJourneyPlannerBackend::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = reinterpret_cast<OpenJourneyPlannerBackend *>(_o);
    if (_c == QMetaObject::ReadProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: *reinterpret_cast<QUrl*>(_v) = _t->m_endpoint; break;
        case 1: *reinterpret_cast<QString*>(_v) = _t->m_authorization; break;
        case 2: *reinterpret_cast<QString*>(_v) = _t->m_requestorRef; break;
        case 4: *reinterpret_cast<enum Protocol*>(_v) = _t->m_protocol; break;
        case 5: *reinterpret_cast<bool*>(_v) = _t->m_supportsTripQueries; break;
        case 6: *reinterpret_cast<QByteArray*>(_v) = _t->m_contentType; break;
        case 7: *reinterpret_cast<QString*>(_v) = _t->m_uicLocationIdentifierType; break;
        case 8: *reinterpret_cast<QString*>(_v) = _t->m_hafasAttrMapName; break;
        default: break;
        }
    }
    if (_c == QMetaObject::WriteProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: QtMocHelpers::setProperty(_t->m_endpoint, *reinterpret_cast<QUrl*>(_v)); break;
        case 1: QtMocHelpers::setProperty(_t->m_authorization, *reinterpret_cast<QString*>(_v)); break;
        case 2: QtMocHelpers::setProperty(_t->m_requestorRef, *reinterpret_cast<QString*>(_v)); break;
        case 3: _t->setSupportedModes(*reinterpret_cast<QJsonArray*>(_v)); break;
        case 4: QtMocHelpers::setProperty(_t->m_protocol, *reinterpret_cast<enum Protocol*>(_v)); break;
        case 5: QtMocHelpers::setProperty(_t->m_supportsTripQueries, *reinterpret_cast<bool*>(_v)); break;
        case 6: QtMocHelpers::setProperty(_t->m_contentType, *reinterpret_cast<QByteArray*>(_v)); break;
        case 7: QtMocHelpers::setProperty(_t->m_uicLocationIdentifierType, *reinterpret_cast<QString*>(_v)); break;
        case 8: QtMocHelpers::setProperty(_t->m_hafasAttrMapName, *reinterpret_cast<QString*>(_v)); break;
        default: break;
        }
    }
}
QT_WARNING_POP
