/****************************************************************************
** Meta object code from reading C++ file 'location.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.12.0)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../../kpublictransport-26.07.90/src/lib/datatypes/location.h"
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'location.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.12.0. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN16KPublicTransport8LocationE_t {};
} // unnamed namespace

template <> constexpr inline auto KPublicTransport::Location::qt_create_metaobjectdata<qt_meta_tag_ZN16KPublicTransport8LocationE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "KPublicTransport::Location",
        "identifier",
        "",
        "identifierType",
        "type",
        "Type",
        "name",
        "latitude",
        "longitude",
        "streetAddress",
        "postalCode",
        "locality",
        "region",
        "country",
        "hasCoordinate",
        "floorLevel",
        "hasFloorLevel",
        "data",
        "QVariant",
        "stopInformation",
        "KPublicTransport::StopInformation",
        "rentalVehicleStation",
        "KPublicTransport::RentalVehicleStation",
        "rentalVehicle",
        "KPublicTransport::RentalVehicle",
        "equipment",
        "KPublicTransport::Equipment",
        "iconName",
        "identifierTypes",
        "Place",
        "Stop",
        "RentedVehicleStation",
        "RentedVehicle",
        "Equipment",
        "CarpoolPickupDropoff",
        "Address",
        "Types"
    };

    QtMocHelpers::UintData qt_methods {
        // Method 'identifier'
        QtMocHelpers::MethodData<QString(const QString &) const>(1, 2, QMC::AccessPublic, QMetaType::QString, {{
            { QMetaType::QString, 3 },
        }}),
    };
    QtMocHelpers::UintData qt_properties {
        // property 'type'
        QtMocHelpers::PropertyData<enum Type>(4, 0x80000000 | 5, QMC::DefaultPropertyFlags | QMC::Writable | QMC::EnumOrFlag | QMC::StdCppSet),
        // property 'name'
        QtMocHelpers::PropertyData<QString>(6, QMetaType::QString, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet),
        // property 'latitude'
        QtMocHelpers::PropertyData<double>(7, QMetaType::Double, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet),
        // property 'longitude'
        QtMocHelpers::PropertyData<double>(8, QMetaType::Double, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet),
        // property 'streetAddress'
        QtMocHelpers::PropertyData<QString>(9, QMetaType::QString, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet),
        // property 'postalCode'
        QtMocHelpers::PropertyData<QString>(10, QMetaType::QString, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet),
        // property 'locality'
        QtMocHelpers::PropertyData<QString>(11, QMetaType::QString, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet),
        // property 'region'
        QtMocHelpers::PropertyData<QString>(12, QMetaType::QString, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet),
        // property 'country'
        QtMocHelpers::PropertyData<QString>(13, QMetaType::QString, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet),
        // property 'hasCoordinate'
        QtMocHelpers::PropertyData<bool>(14, QMetaType::Bool, QMC::Readable | QMC::Designable | QMC::Scriptable),
        // property 'floorLevel'
        QtMocHelpers::PropertyData<int>(15, QMetaType::Int, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet),
        // property 'hasFloorLevel'
        QtMocHelpers::PropertyData<bool>(16, QMetaType::Bool, QMC::Readable | QMC::Designable | QMC::Scriptable),
        // property 'data'
        QtMocHelpers::PropertyData<QVariant>(17, 0x80000000 | 18, QMC::DefaultPropertyFlags | QMC::Writable | QMC::EnumOrFlag | QMC::StdCppSet),
        // property 'stopInformation'
        QtMocHelpers::PropertyData<KPublicTransport::StopInformation>(19, 0x80000000 | 20, QMC::Readable | QMC::Designable | QMC::Scriptable | QMC::EnumOrFlag),
        // property 'rentalVehicleStation'
        QtMocHelpers::PropertyData<KPublicTransport::RentalVehicleStation>(21, 0x80000000 | 22, QMC::Readable | QMC::Designable | QMC::Scriptable | QMC::EnumOrFlag),
        // property 'rentalVehicle'
        QtMocHelpers::PropertyData<KPublicTransport::RentalVehicle>(23, 0x80000000 | 24, QMC::Readable | QMC::Designable | QMC::Scriptable | QMC::EnumOrFlag),
        // property 'equipment'
        QtMocHelpers::PropertyData<KPublicTransport::Equipment>(25, 0x80000000 | 26, QMC::Readable | QMC::Designable | QMC::Scriptable | QMC::EnumOrFlag),
        // property 'iconName'
        QtMocHelpers::PropertyData<QString>(27, QMetaType::QString, QMC::Readable | QMC::Designable | QMC::Scriptable),
        // property 'identifierTypes'
        QtMocHelpers::PropertyData<QStringList>(28, QMetaType::QStringList, QMC::Readable | QMC::Designable | QMC::Scriptable),
    };
    QtMocHelpers::UintData qt_enums {
        // enum 'Type'
        QtMocHelpers::EnumData<enum Type>(5, 5, QMC::EnumFlags{}).add({
            {   29, Type::Place },
            {   30, Type::Stop },
            {   31, Type::RentedVehicleStation },
            {   32, Type::RentedVehicle },
            {   33, Type::Equipment },
            {   34, Type::CarpoolPickupDropoff },
            {   35, Type::Address },
        }),
        // flag 'Types'
        QtMocHelpers::EnumData<Types>(36, 5, QMC::EnumIsFlag).add({
            {   29, Type::Place },
            {   30, Type::Stop },
            {   31, Type::RentedVehicleStation },
            {   32, Type::RentedVehicle },
            {   33, Type::Equipment },
            {   34, Type::CarpoolPickupDropoff },
            {   35, Type::Address },
        }),
    };
    return QtMocHelpers::metaObjectData<Location, qt_meta_tag_ZN16KPublicTransport8LocationE_t>(QMC::PropertyAccessInStaticMetaCall, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject KPublicTransport::Location::staticMetaObject = { {
    nullptr,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN16KPublicTransport8LocationE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN16KPublicTransport8LocationE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN16KPublicTransport8LocationE_t>.metaTypes,
    nullptr
} };

void KPublicTransport::Location::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = reinterpret_cast<Location *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: { QString _r = _t->identifier((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])));
            if (_a[0]) *reinterpret_cast<QString*>(_a[0]) = std::move(_r); }  break;
        default: ;
        }
    }
    if (_c == QMetaObject::ReadProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: *reinterpret_cast<enum Type*>(_v) = _t->type(); break;
        case 1: *reinterpret_cast<QString*>(_v) = _t->name(); break;
        case 2: *reinterpret_cast<double*>(_v) = _t->latitude(); break;
        case 3: *reinterpret_cast<double*>(_v) = _t->longitude(); break;
        case 4: *reinterpret_cast<QString*>(_v) = _t->streetAddress(); break;
        case 5: *reinterpret_cast<QString*>(_v) = _t->postalCode(); break;
        case 6: *reinterpret_cast<QString*>(_v) = _t->locality(); break;
        case 7: *reinterpret_cast<QString*>(_v) = _t->region(); break;
        case 8: *reinterpret_cast<QString*>(_v) = _t->country(); break;
        case 9: *reinterpret_cast<bool*>(_v) = _t->hasCoordinate(); break;
        case 10: *reinterpret_cast<int*>(_v) = _t->floorLevel(); break;
        case 11: *reinterpret_cast<bool*>(_v) = _t->hasFloorLevel(); break;
        case 12: *reinterpret_cast<QVariant*>(_v) = _t->data(); break;
        case 13: *reinterpret_cast<KPublicTransport::StopInformation*>(_v) = _t->stopInformation(); break;
        case 14: *reinterpret_cast<KPublicTransport::RentalVehicleStation*>(_v) = _t->rentalVehicleStation(); break;
        case 15: *reinterpret_cast<KPublicTransport::RentalVehicle*>(_v) = _t->rentalVehicle(); break;
        case 16: *reinterpret_cast<KPublicTransport::Equipment*>(_v) = _t->equipment(); break;
        case 17: *reinterpret_cast<QString*>(_v) = _t->iconName(); break;
        case 18: *reinterpret_cast<QStringList*>(_v) = _t->identifierTypes(); break;
        default: break;
        }
    }
    if (_c == QMetaObject::WriteProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: _t->setType(*reinterpret_cast<enum Type*>(_v)); break;
        case 1: _t->setName(*reinterpret_cast<QString*>(_v)); break;
        case 2: _t->setLatitude(*reinterpret_cast<double*>(_v)); break;
        case 3: _t->setLongitude(*reinterpret_cast<double*>(_v)); break;
        case 4: _t->setStreetAddress(*reinterpret_cast<QString*>(_v)); break;
        case 5: _t->setPostalCode(*reinterpret_cast<QString*>(_v)); break;
        case 6: _t->setLocality(*reinterpret_cast<QString*>(_v)); break;
        case 7: _t->setRegion(*reinterpret_cast<QString*>(_v)); break;
        case 8: _t->setCountry(*reinterpret_cast<QString*>(_v)); break;
        case 10: _t->setFloorLevel(*reinterpret_cast<int*>(_v)); break;
        case 12: _t->setData(*reinterpret_cast<QVariant*>(_v)); break;
        default: break;
        }
    }
}
QT_WARNING_POP
