/****************************************************************************
** Meta object code from reading C++ file 'hafasmgatebackend.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.12.0)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../../kpublictransport-26.07.90/src/lib/backends/hafasmgatebackend.h"
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'hafasmgatebackend.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.12.0. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN16KPublicTransport17HafasMgateBackendE_t {};
} // unnamed namespace

template <> constexpr inline auto KPublicTransport::HafasMgateBackend::qt_create_metaobjectdata<qt_meta_tag_ZN16KPublicTransport17HafasMgateBackendE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "KPublicTransport::HafasMgateBackend",
        "auth",
        "QJsonObject",
        "client",
        "ext",
        "ver",
        "rtMode",
        "micMacSalt",
        "checksumSalt",
        "conGroups",
        "QJsonArray",
        "productNameMappings"
    };

    QtMocHelpers::UintData qt_methods {
    };
    QtMocHelpers::UintData qt_properties {
        // property 'auth'
        QtMocHelpers::PropertyData<QJsonObject>(1, 0x80000000 | 2, QMC::DefaultPropertyFlags | QMC::Writable | QMC::EnumOrFlag),
        // property 'client'
        QtMocHelpers::PropertyData<QJsonObject>(3, 0x80000000 | 2, QMC::DefaultPropertyFlags | QMC::Writable | QMC::EnumOrFlag),
        // property 'ext'
        QtMocHelpers::PropertyData<QString>(4, QMetaType::QString, QMC::DefaultPropertyFlags | QMC::Writable),
        // property 'ver'
        QtMocHelpers::PropertyData<QString>(5, QMetaType::QString, QMC::DefaultPropertyFlags | QMC::Writable),
        // property 'rtMode'
        QtMocHelpers::PropertyData<QString>(6, QMetaType::QString, QMC::DefaultPropertyFlags | QMC::Writable),
        // property 'micMacSalt'
        QtMocHelpers::PropertyData<QString>(7, QMetaType::QString, QMC::Writable | QMC::Designable | QMC::Scriptable | QMC::Stored | QMC::StdCppSet),
        // property 'checksumSalt'
        QtMocHelpers::PropertyData<QString>(8, QMetaType::QString, QMC::Writable | QMC::Designable | QMC::Scriptable | QMC::Stored | QMC::StdCppSet),
        // property 'conGroups'
        QtMocHelpers::PropertyData<QJsonArray>(9, 0x80000000 | 10, QMC::Writable | QMC::Designable | QMC::Scriptable | QMC::Stored | QMC::EnumOrFlag | QMC::StdCppSet),
        // property 'productNameMappings'
        QtMocHelpers::PropertyData<QJsonArray>(11, 0x80000000 | 10, QMC::Writable | QMC::Designable | QMC::Scriptable | QMC::Stored | QMC::EnumOrFlag | QMC::StdCppSet),
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<HafasMgateBackend, qt_meta_tag_ZN16KPublicTransport17HafasMgateBackendE_t>(QMC::PropertyAccessInStaticMetaCall, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject KPublicTransport::HafasMgateBackend::staticMetaObject = { {
    QtPrivate::MetaObjectForType<HafasBackend>::value,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN16KPublicTransport17HafasMgateBackendE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN16KPublicTransport17HafasMgateBackendE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN16KPublicTransport17HafasMgateBackendE_t>.metaTypes,
    nullptr
} };

void KPublicTransport::HafasMgateBackend::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = reinterpret_cast<HafasMgateBackend *>(_o);
    if (_c == QMetaObject::ReadProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: *reinterpret_cast<QJsonObject*>(_v) = _t->m_auth; break;
        case 1: *reinterpret_cast<QJsonObject*>(_v) = _t->m_client; break;
        case 2: *reinterpret_cast<QString*>(_v) = _t->m_extParam; break;
        case 3: *reinterpret_cast<QString*>(_v) = _t->m_version; break;
        case 4: *reinterpret_cast<QString*>(_v) = _t->m_rtMode; break;
        default: break;
        }
    }
    if (_c == QMetaObject::WriteProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: QtMocHelpers::setProperty(_t->m_auth, *reinterpret_cast<QJsonObject*>(_v)); break;
        case 1: QtMocHelpers::setProperty(_t->m_client, *reinterpret_cast<QJsonObject*>(_v)); break;
        case 2: QtMocHelpers::setProperty(_t->m_extParam, *reinterpret_cast<QString*>(_v)); break;
        case 3: QtMocHelpers::setProperty(_t->m_version, *reinterpret_cast<QString*>(_v)); break;
        case 4: QtMocHelpers::setProperty(_t->m_rtMode, *reinterpret_cast<QString*>(_v)); break;
        case 5: _t->setMicMacSalt(*reinterpret_cast<QString*>(_v)); break;
        case 6: _t->setChecksumSalt(*reinterpret_cast<QString*>(_v)); break;
        case 7: _t->setConGroups(*reinterpret_cast<QJsonArray*>(_v)); break;
        case 8: _t->setProductNameMappings(*reinterpret_cast<QJsonArray*>(_v)); break;
        default: break;
        }
    }
}
QT_WARNING_POP
