/****************************************************************************
** Meta object code from reading C++ file 'path.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.12.0)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../../kpublictransport-26.07.90/src/lib/datatypes/path.h"
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'path.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.12.0. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN16KPublicTransport11PathSectionE_t {};
} // unnamed namespace

template <> constexpr inline auto KPublicTransport::PathSection::qt_create_metaobjectdata<qt_meta_tag_ZN16KPublicTransport11PathSectionE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "KPublicTransport::PathSection",
        "maneuverIconName",
        "",
        "KPublicTransport::PathSection::Maneuver",
        "maneuver",
        "path",
        "QPolygonF",
        "description",
        "startPoint",
        "QPointF",
        "endPoint",
        "distance",
        "direction",
        "startFloorLevel",
        "hasStartFloorLevel",
        "floorLevelChange",
        "Maneuver",
        "iconName",
        "Move",
        "Stairs",
        "Elevator",
        "Escalator"
    };

    QtMocHelpers::UintData qt_methods {
        // Method 'maneuverIconName'
        QtMocHelpers::MethodData<QString(KPublicTransport::PathSection::Maneuver)>(1, 2, QMC::AccessPublic, QMetaType::QString, {{
            { 0x80000000 | 3, 4 },
        }}),
    };
    QtMocHelpers::UintData qt_properties {
        // property 'path'
        QtMocHelpers::PropertyData<QPolygonF>(5, 0x80000000 | 6, QMC::DefaultPropertyFlags | QMC::Writable | QMC::EnumOrFlag | QMC::StdCppSet),
        // property 'description'
        QtMocHelpers::PropertyData<QString>(7, QMetaType::QString, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet),
        // property 'startPoint'
        QtMocHelpers::PropertyData<QPointF>(8, 0x80000000 | 9, QMC::Readable | QMC::Designable | QMC::Scriptable | QMC::EnumOrFlag),
        // property 'endPoint'
        QtMocHelpers::PropertyData<QPointF>(10, 0x80000000 | 9, QMC::Readable | QMC::Designable | QMC::Scriptable | QMC::EnumOrFlag),
        // property 'distance'
        QtMocHelpers::PropertyData<int>(11, QMetaType::Int, QMC::Readable | QMC::Designable | QMC::Scriptable),
        // property 'direction'
        QtMocHelpers::PropertyData<int>(12, QMetaType::Int, QMC::Readable | QMC::Designable | QMC::Scriptable),
        // property 'startFloorLevel'
        QtMocHelpers::PropertyData<int>(13, QMetaType::Int, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet),
        // property 'hasStartFloorLevel'
        QtMocHelpers::PropertyData<bool>(14, QMetaType::Bool, QMC::Readable | QMC::Designable | QMC::Scriptable),
        // property 'floorLevelChange'
        QtMocHelpers::PropertyData<int>(15, QMetaType::Int, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet),
        // property 'maneuver'
        QtMocHelpers::PropertyData<enum Maneuver>(4, 0x80000000 | 16, QMC::DefaultPropertyFlags | QMC::Writable | QMC::EnumOrFlag | QMC::StdCppSet),
        // property 'iconName'
        QtMocHelpers::PropertyData<QString>(17, QMetaType::QString, QMC::Readable | QMC::Designable | QMC::Scriptable),
    };
    QtMocHelpers::UintData qt_enums {
        // enum 'Maneuver'
        QtMocHelpers::EnumData<enum Maneuver>(16, 16, QMC::EnumFlags{}).add({
            {   18, Maneuver::Move },
            {   19, Maneuver::Stairs },
            {   20, Maneuver::Elevator },
            {   21, Maneuver::Escalator },
        }),
    };
    return QtMocHelpers::metaObjectData<PathSection, qt_meta_tag_ZN16KPublicTransport11PathSectionE_t>(QMC::PropertyAccessInStaticMetaCall, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject KPublicTransport::PathSection::staticMetaObject = { {
    nullptr,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN16KPublicTransport11PathSectionE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN16KPublicTransport11PathSectionE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN16KPublicTransport11PathSectionE_t>.metaTypes,
    nullptr
} };

void KPublicTransport::PathSection::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = reinterpret_cast<PathSection *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: { QString _r = _t->maneuverIconName((*reinterpret_cast<std::add_pointer_t<KPublicTransport::PathSection::Maneuver>>(_a[1])));
            if (_a[0]) *reinterpret_cast<QString*>(_a[0]) = std::move(_r); }  break;
        default: ;
        }
    }
    if (_c == QMetaObject::ReadProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: *reinterpret_cast<QPolygonF*>(_v) = _t->path(); break;
        case 1: *reinterpret_cast<QString*>(_v) = _t->description(); break;
        case 2: *reinterpret_cast<QPointF*>(_v) = _t->startPoint(); break;
        case 3: *reinterpret_cast<QPointF*>(_v) = _t->endPoint(); break;
        case 4: *reinterpret_cast<int*>(_v) = _t->distance(); break;
        case 5: *reinterpret_cast<int*>(_v) = _t->direction(); break;
        case 6: *reinterpret_cast<int*>(_v) = _t->startFloorLevel(); break;
        case 7: *reinterpret_cast<bool*>(_v) = _t->hasStartFloorLevel(); break;
        case 8: *reinterpret_cast<int*>(_v) = _t->floorLevelChange(); break;
        case 9: *reinterpret_cast<enum Maneuver*>(_v) = _t->maneuver(); break;
        case 10: *reinterpret_cast<QString*>(_v) = _t->iconName(); break;
        default: break;
        }
    }
    if (_c == QMetaObject::WriteProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: _t->setPath(*reinterpret_cast<QPolygonF*>(_v)); break;
        case 1: _t->setDescription(*reinterpret_cast<QString*>(_v)); break;
        case 6: _t->setStartFloorLevel(*reinterpret_cast<int*>(_v)); break;
        case 8: _t->setFloorLevelChange(*reinterpret_cast<int*>(_v)); break;
        case 9: _t->setManeuver(*reinterpret_cast<enum Maneuver*>(_v)); break;
        default: break;
        }
    }
}
namespace {
struct qt_meta_tag_ZN16KPublicTransport4PathE_t {};
} // unnamed namespace

template <> constexpr inline auto KPublicTransport::Path::qt_create_metaobjectdata<qt_meta_tag_ZN16KPublicTransport4PathE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "KPublicTransport::Path",
        "sections",
        "std::vector<KPublicTransport::PathSection>",
        "sectionCount",
        "distance",
        "startPoint",
        "QPointF",
        "endPoint",
        "isEmpty"
    };

    QtMocHelpers::UintData qt_methods {
    };
    QtMocHelpers::UintData qt_properties {
        // property 'sections'
        QtMocHelpers::PropertyData<std::vector<KPublicTransport::PathSection>>(1, 0x80000000 | 2, QMC::DefaultPropertyFlags | QMC::EnumOrFlag),
        // property 'sectionCount'
        QtMocHelpers::PropertyData<int>(3, QMetaType::Int, QMC::Readable | QMC::Designable | QMC::Scriptable),
        // property 'distance'
        QtMocHelpers::PropertyData<int>(4, QMetaType::Int, QMC::Readable | QMC::Designable | QMC::Scriptable),
        // property 'startPoint'
        QtMocHelpers::PropertyData<QPointF>(5, 0x80000000 | 6, QMC::Readable | QMC::Designable | QMC::Scriptable | QMC::EnumOrFlag),
        // property 'endPoint'
        QtMocHelpers::PropertyData<QPointF>(7, 0x80000000 | 6, QMC::Readable | QMC::Designable | QMC::Scriptable | QMC::EnumOrFlag),
        // property 'isEmpty'
        QtMocHelpers::PropertyData<bool>(8, QMetaType::Bool, QMC::Readable | QMC::Designable | QMC::Scriptable),
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<Path, qt_meta_tag_ZN16KPublicTransport4PathE_t>(QMC::PropertyAccessInStaticMetaCall, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject KPublicTransport::Path::staticMetaObject = { {
    nullptr,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN16KPublicTransport4PathE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN16KPublicTransport4PathE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN16KPublicTransport4PathE_t>.metaTypes,
    nullptr
} };

void KPublicTransport::Path::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = reinterpret_cast<Path *>(_o);
    if (_c == QMetaObject::RegisterPropertyMetaType) {
        switch (_id) {
        default: *reinterpret_cast<int*>(_a[0]) = -1; break;
        case 0:
            *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< std::vector<KPublicTransport::PathSection> >(); break;
        }
    }
    if (_c == QMetaObject::ReadProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: *reinterpret_cast<std::vector<KPublicTransport::PathSection>*>(_v) = _t->sections(); break;
        case 1: *reinterpret_cast<int*>(_v) = _t->sectionCount(); break;
        case 2: *reinterpret_cast<int*>(_v) = _t->distance(); break;
        case 3: *reinterpret_cast<QPointF*>(_v) = _t->startPoint(); break;
        case 4: *reinterpret_cast<QPointF*>(_v) = _t->endPoint(); break;
        case 5: *reinterpret_cast<bool*>(_v) = _t->isEmpty(); break;
        default: break;
        }
    }
}
QT_WARNING_POP
