/****************************************************************************
** Meta object code from reading C++ file 'opentripplannergraphqlbackend.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.12.0)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../../kpublictransport-26.07.90/src/lib/backends/opentripplannergraphqlbackend.h"
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'opentripplannergraphqlbackend.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.12.0. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN16KPublicTransport29OpenTripPlannerGraphQLBackendE_t {};
} // unnamed namespace

template <> constexpr inline auto KPublicTransport::OpenTripPlannerGraphQLBackend::qt_create_metaobjectdata<qt_meta_tag_ZN16KPublicTransport29OpenTripPlannerGraphQLBackendE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "KPublicTransport::OpenTripPlannerGraphQLBackend",
        "endpoint",
        "QUrl",
        "apiVersion",
        "supportedTransitModes",
        "supportedRentalModes",
        "extraHttpHeaders",
        "QJsonValue",
        "rentalVehicleNetworks",
        "QJsonObject",
        "ifoptPrefix"
    };

    QtMocHelpers::UintData qt_methods {
    };
    QtMocHelpers::UintData qt_properties {
        // property 'endpoint'
        QtMocHelpers::PropertyData<QUrl>(1, 0x80000000 | 2, QMC::DefaultPropertyFlags | QMC::Writable | QMC::EnumOrFlag),
        // property 'apiVersion'
        QtMocHelpers::PropertyData<QString>(3, QMetaType::QString, QMC::DefaultPropertyFlags | QMC::Writable),
        // property 'supportedTransitModes'
        QtMocHelpers::PropertyData<QStringList>(4, QMetaType::QStringList, QMC::DefaultPropertyFlags | QMC::Writable),
        // property 'supportedRentalModes'
        QtMocHelpers::PropertyData<QStringList>(5, QMetaType::QStringList, QMC::DefaultPropertyFlags | QMC::Writable),
        // property 'extraHttpHeaders'
        QtMocHelpers::PropertyData<QJsonValue>(6, 0x80000000 | 7, QMC::Writable | QMC::Designable | QMC::Scriptable | QMC::Stored | QMC::EnumOrFlag | QMC::StdCppSet),
        // property 'rentalVehicleNetworks'
        QtMocHelpers::PropertyData<QJsonObject>(8, 0x80000000 | 9, QMC::DefaultPropertyFlags | QMC::Writable | QMC::EnumOrFlag),
        // property 'ifoptPrefix'
        QtMocHelpers::PropertyData<QString>(10, QMetaType::QString, QMC::DefaultPropertyFlags | QMC::Writable),
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<OpenTripPlannerGraphQLBackend, qt_meta_tag_ZN16KPublicTransport29OpenTripPlannerGraphQLBackendE_t>(QMC::PropertyAccessInStaticMetaCall, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject KPublicTransport::OpenTripPlannerGraphQLBackend::staticMetaObject = { {
    QtPrivate::MetaObjectForType<AbstractBackend>::value,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN16KPublicTransport29OpenTripPlannerGraphQLBackendE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN16KPublicTransport29OpenTripPlannerGraphQLBackendE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN16KPublicTransport29OpenTripPlannerGraphQLBackendE_t>.metaTypes,
    nullptr
} };

void KPublicTransport::OpenTripPlannerGraphQLBackend::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = reinterpret_cast<OpenTripPlannerGraphQLBackend *>(_o);
    if (_c == QMetaObject::ReadProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: *reinterpret_cast<QUrl*>(_v) = _t->m_endpoint; break;
        case 1: *reinterpret_cast<QString*>(_v) = _t->m_apiVersion; break;
        case 2: *reinterpret_cast<QStringList*>(_v) = _t->m_supportedTransitModes; break;
        case 3: *reinterpret_cast<QStringList*>(_v) = _t->m_supportedRentalModes; break;
        case 5: *reinterpret_cast<QJsonObject*>(_v) = _t->m_rentalNetworks; break;
        case 6: *reinterpret_cast<QString*>(_v) = _t->m_ifoptPrefix; break;
        default: break;
        }
    }
    if (_c == QMetaObject::WriteProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: QtMocHelpers::setProperty(_t->m_endpoint, *reinterpret_cast<QUrl*>(_v)); break;
        case 1: QtMocHelpers::setProperty(_t->m_apiVersion, *reinterpret_cast<QString*>(_v)); break;
        case 2: QtMocHelpers::setProperty(_t->m_supportedTransitModes, *reinterpret_cast<QStringList*>(_v)); break;
        case 3: QtMocHelpers::setProperty(_t->m_supportedRentalModes, *reinterpret_cast<QStringList*>(_v)); break;
        case 4: _t->setExtraHttpHeaders(*reinterpret_cast<QJsonValue*>(_v)); break;
        case 5: QtMocHelpers::setProperty(_t->m_rentalNetworks, *reinterpret_cast<QJsonObject*>(_v)); break;
        case 6: QtMocHelpers::setProperty(_t->m_ifoptPrefix, *reinterpret_cast<QString*>(_v)); break;
        default: break;
        }
    }
}
QT_WARNING_POP
