/****************************************************************************
** Meta object code from reading C++ file 'journeyrequest.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.12.0)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../../kpublictransport-26.07.90/src/lib/journeyrequest.h"
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'journeyrequest.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.12.0. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN16KPublicTransport14JourneyRequestE_t {};
} // unnamed namespace

template <> constexpr inline auto KPublicTransport::JourneyRequest::qt_create_metaobjectdata<qt_meta_tag_ZN16KPublicTransport14JourneyRequestE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "KPublicTransport::JourneyRequest",
        "from",
        "KPublicTransport::Location",
        "to",
        "dateTime",
        "modes",
        "KPublicTransport::JourneySection::Modes",
        "maximumResults",
        "includeIntermediateStops",
        "includePaths",
        "accessModes",
        "QVariantList",
        "egressModes",
        "lineModes",
        "individualTransportModes",
        "dateTimeMode",
        "DateTimeMode",
        "backends",
        "downloadAssets",
        "Arrival",
        "Departure"
    };

    QtMocHelpers::UintData qt_methods {
    };
    QtMocHelpers::UintData qt_properties {
        // property 'from'
        QtMocHelpers::PropertyData<KPublicTransport::Location>(1, 0x80000000 | 2, QMC::DefaultPropertyFlags | QMC::Writable | QMC::EnumOrFlag | QMC::StdCppSet),
        // property 'to'
        QtMocHelpers::PropertyData<KPublicTransport::Location>(3, 0x80000000 | 2, QMC::DefaultPropertyFlags | QMC::Writable | QMC::EnumOrFlag | QMC::StdCppSet),
        // property 'dateTime'
        QtMocHelpers::PropertyData<QDateTime>(4, QMetaType::QDateTime, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet),
        // property 'modes'
        QtMocHelpers::PropertyData<KPublicTransport::JourneySection::Modes>(5, 0x80000000 | 6, QMC::DefaultPropertyFlags | QMC::Writable | QMC::EnumOrFlag | QMC::StdCppSet),
        // property 'maximumResults'
        QtMocHelpers::PropertyData<int>(7, QMetaType::Int, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet),
        // property 'includeIntermediateStops'
        QtMocHelpers::PropertyData<bool>(8, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet),
        // property 'includePaths'
        QtMocHelpers::PropertyData<bool>(9, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet),
        // property 'accessModes'
        QtMocHelpers::PropertyData<QVariantList>(10, 0x80000000 | 11, QMC::DefaultPropertyFlags | QMC::Writable | QMC::EnumOrFlag),
        // property 'egressModes'
        QtMocHelpers::PropertyData<QVariantList>(12, 0x80000000 | 11, QMC::DefaultPropertyFlags | QMC::Writable | QMC::EnumOrFlag),
        // property 'lineModes'
        QtMocHelpers::PropertyData<QVariantList>(13, 0x80000000 | 11, QMC::DefaultPropertyFlags | QMC::Writable | QMC::EnumOrFlag),
        // property 'individualTransportModes'
        QtMocHelpers::PropertyData<QVariantList>(14, 0x80000000 | 11, QMC::DefaultPropertyFlags | QMC::Writable | QMC::EnumOrFlag),
        // property 'dateTimeMode'
        QtMocHelpers::PropertyData<enum DateTimeMode>(15, 0x80000000 | 16, QMC::DefaultPropertyFlags | QMC::Writable | QMC::EnumOrFlag | QMC::StdCppSet),
        // property 'backends'
        QtMocHelpers::PropertyData<QStringList>(17, QMetaType::QStringList, QMC::DefaultPropertyFlags | QMC::Writable),
        // property 'downloadAssets'
        QtMocHelpers::PropertyData<bool>(18, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet),
    };
    QtMocHelpers::UintData qt_enums {
        // enum 'DateTimeMode'
        QtMocHelpers::EnumData<enum DateTimeMode>(16, 16, QMC::EnumFlags{}).add({
            {   19, DateTimeMode::Arrival },
            {   20, DateTimeMode::Departure },
        }),
    };
    return QtMocHelpers::metaObjectData<JourneyRequest, qt_meta_tag_ZN16KPublicTransport14JourneyRequestE_t>(QMC::PropertyAccessInStaticMetaCall, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT static const QMetaObject::SuperData qt_meta_extradata_ZN16KPublicTransport14JourneyRequestE[] = {
    QMetaObject::SuperData::link<KPublicTransport::JourneySection::staticMetaObject>(),
    nullptr
};

Q_CONSTINIT const QMetaObject KPublicTransport::JourneyRequest::staticMetaObject = { {
    nullptr,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN16KPublicTransport14JourneyRequestE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN16KPublicTransport14JourneyRequestE_t>.data,
    qt_static_metacall,
    qt_meta_extradata_ZN16KPublicTransport14JourneyRequestE,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN16KPublicTransport14JourneyRequestE_t>.metaTypes,
    nullptr
} };

void KPublicTransport::JourneyRequest::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = reinterpret_cast<JourneyRequest *>(_o);
    if (_c == QMetaObject::RegisterPropertyMetaType) {
        switch (_id) {
        default: *reinterpret_cast<int*>(_a[0]) = -1; break;
        case 1:
        case 0:
            *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< KPublicTransport::Location >(); break;
        }
    }
    if (_c == QMetaObject::ReadProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: *reinterpret_cast<KPublicTransport::Location*>(_v) = _t->from(); break;
        case 1: *reinterpret_cast<KPublicTransport::Location*>(_v) = _t->to(); break;
        case 2: *reinterpret_cast<QDateTime*>(_v) = _t->dateTime(); break;
        case 3: *reinterpret_cast<KPublicTransport::JourneySection::Modes*>(_v) = _t->modes(); break;
        case 4: *reinterpret_cast<int*>(_v) = _t->maximumResults(); break;
        case 5: *reinterpret_cast<bool*>(_v) = _t->includeIntermediateStops(); break;
        case 6: *reinterpret_cast<bool*>(_v) = _t->includePaths(); break;
        case 7: *reinterpret_cast<QVariantList*>(_v) = _t->accessModesVariant(); break;
        case 8: *reinterpret_cast<QVariantList*>(_v) = _t->egressModesVariant(); break;
        case 9: *reinterpret_cast<QVariantList*>(_v) = _t->lineModesVariant(); break;
        case 10: *reinterpret_cast<QVariantList*>(_v) = _t->individualTransportModesVariant(); break;
        case 11: *reinterpret_cast<enum DateTimeMode*>(_v) = _t->dateTimeMode(); break;
        case 12: *reinterpret_cast<QStringList*>(_v) = _t->backendIds(); break;
        case 13: *reinterpret_cast<bool*>(_v) = _t->downloadAssets(); break;
        default: break;
        }
    }
    if (_c == QMetaObject::WriteProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: _t->setFrom(*reinterpret_cast<KPublicTransport::Location*>(_v)); break;
        case 1: _t->setTo(*reinterpret_cast<KPublicTransport::Location*>(_v)); break;
        case 2: _t->setDateTime(*reinterpret_cast<QDateTime*>(_v)); break;
        case 3: _t->setModes(*reinterpret_cast<KPublicTransport::JourneySection::Modes*>(_v)); break;
        case 4: _t->setMaximumResults(*reinterpret_cast<int*>(_v)); break;
        case 5: _t->setIncludeIntermediateStops(*reinterpret_cast<bool*>(_v)); break;
        case 6: _t->setIncludePaths(*reinterpret_cast<bool*>(_v)); break;
        case 7: _t->setAccessModesVariant(*reinterpret_cast<QVariantList*>(_v)); break;
        case 8: _t->setEgressModesVariant(*reinterpret_cast<QVariantList*>(_v)); break;
        case 9: _t->setLineModesVariant(*reinterpret_cast<QVariantList*>(_v)); break;
        case 10: _t->setIndividualTransportModesVariant(*reinterpret_cast<QVariantList*>(_v)); break;
        case 11: _t->setDateTimeMode(*reinterpret_cast<enum DateTimeMode*>(_v)); break;
        case 12: _t->setBackendIds(*reinterpret_cast<QStringList*>(_v)); break;
        case 13: _t->setDownloadAssets(*reinterpret_cast<bool*>(_v)); break;
        default: break;
        }
    }
}
QT_WARNING_POP
