/****************************************************************************
** Meta object code from reading C++ file 'load.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.12.0)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../../kpublictransport-26.07.90/src/lib/datatypes/load.h"
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'load.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.12.0. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN16KPublicTransport8LoadInfoE_t {};
} // unnamed namespace

template <> constexpr inline auto KPublicTransport::LoadInfo::qt_create_metaobjectdata<qt_meta_tag_ZN16KPublicTransport8LoadInfoE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "KPublicTransport::LoadInfo",
        "load",
        "KPublicTransport::Load::Category",
        "seatingClass"
    };

    QtMocHelpers::UintData qt_methods {
    };
    QtMocHelpers::UintData qt_properties {
        // property 'load'
        QtMocHelpers::PropertyData<KPublicTransport::Load::Category>(1, 0x80000000 | 2, QMC::DefaultPropertyFlags | QMC::Writable | QMC::EnumOrFlag | QMC::StdCppSet),
        // property 'seatingClass'
        QtMocHelpers::PropertyData<QString>(3, QMetaType::QString, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet),
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<LoadInfo, qt_meta_tag_ZN16KPublicTransport8LoadInfoE_t>(QMC::PropertyAccessInStaticMetaCall, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT static const QMetaObject::SuperData qt_meta_extradata_ZN16KPublicTransport8LoadInfoE[] = {
    QMetaObject::SuperData::link<KPublicTransport::Load::staticMetaObject>(),
    nullptr
};

Q_CONSTINIT const QMetaObject KPublicTransport::LoadInfo::staticMetaObject = { {
    nullptr,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN16KPublicTransport8LoadInfoE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN16KPublicTransport8LoadInfoE_t>.data,
    qt_static_metacall,
    qt_meta_extradata_ZN16KPublicTransport8LoadInfoE,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN16KPublicTransport8LoadInfoE_t>.metaTypes,
    nullptr
} };

void KPublicTransport::LoadInfo::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = reinterpret_cast<LoadInfo *>(_o);
    if (_c == QMetaObject::ReadProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: *reinterpret_cast<KPublicTransport::Load::Category*>(_v) = _t->load(); break;
        case 1: *reinterpret_cast<QString*>(_v) = _t->seatingClass(); break;
        default: break;
        }
    }
    if (_c == QMetaObject::WriteProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: _t->setLoad(*reinterpret_cast<KPublicTransport::Load::Category*>(_v)); break;
        case 1: _t->setSeatingClass(*reinterpret_cast<QString*>(_v)); break;
        default: break;
        }
    }
}
namespace {
struct qt_meta_tag_ZN16KPublicTransport4LoadE_t {};
} // unnamed namespace

template <> constexpr inline auto KPublicTransport::Load::qt_create_metaobjectdata<qt_meta_tag_ZN16KPublicTransport4LoadE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "KPublicTransport::Load",
        "Category",
        "Unknown",
        "Low",
        "Medium",
        "High",
        "Full"
    };

    QtMocHelpers::UintData qt_methods {
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
        // enum 'Category'
        QtMocHelpers::EnumData<Category>(1, 1, QMC::EnumFlags{}).add({
            {    2, Category::Unknown },
            {    3, Category::Low },
            {    4, Category::Medium },
            {    5, Category::High },
            {    6, Category::Full },
        }),
    };
    return QtMocHelpers::metaObjectData<void, qt_meta_tag_ZN16KPublicTransport4LoadE_t>(QMC::PropertyAccessInStaticMetaCall, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}

static constexpr auto qt_staticMetaObjectContent_ZN16KPublicTransport4LoadE =
    KPublicTransport::Load::qt_create_metaobjectdata<qt_meta_tag_ZN16KPublicTransport4LoadE_t>();
static constexpr auto qt_staticMetaObjectStaticContent_ZN16KPublicTransport4LoadE =
    qt_staticMetaObjectContent_ZN16KPublicTransport4LoadE.staticData;
static constexpr auto qt_staticMetaObjectRelocatingContent_ZN16KPublicTransport4LoadE =
    qt_staticMetaObjectContent_ZN16KPublicTransport4LoadE.relocatingData;

Q_CONSTINIT const QMetaObject KPublicTransport::Load::staticMetaObject = { {
    nullptr,
    qt_staticMetaObjectStaticContent_ZN16KPublicTransport4LoadE.stringdata,
    qt_staticMetaObjectStaticContent_ZN16KPublicTransport4LoadE.data,
    nullptr,
    nullptr,
    qt_staticMetaObjectRelocatingContent_ZN16KPublicTransport4LoadE.metaTypes,
    nullptr
} };

QT_WARNING_POP
