/****************************************************************************
** Generated QML type registration code
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include <QtQml/qqml.h>
#include <QtQml/qqmlmoduleregistration.h>

#if __has_include(<types.h>)
#  include <types.h>
#endif


#if !defined(QT_STATIC)
#define Q_QMLTYPE_EXPORT Q_DECL_EXPORT
#else
#define Q_QMLTYPE_EXPORT
#endif
Q_QMLTYPE_EXPORT void qml_register_types_org_kde_kpublictransport_onboard()
{
    QT_WARNING_PUSH QT_WARNING_DISABLE_DEPRECATED
    qmlRegisterTypesAndRevisions<OnboardStatusForeign>("org.kde.kpublictransport.onboard", 1);
    QMetaType::fromType<OnboardStatusForeign *>().id();
    qmlRegisterEnum<KPublicTransport::OnboardStatus::Status>("KPublicTransport::OnboardStatus::Status");
    QT_WARNING_POP
    qmlRegisterModule("org.kde.kpublictransport.onboard", 1, 0);
}

static const QQmlModuleRegistration orgkdekpublictransportonboardRegistration("org.kde.kpublictransport.onboard", qml_register_types_org_kde_kpublictransport_onboard);
