/****************************************************************************
** Meta object code from reading C++ file 'stopover.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.12.0)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../../kpublictransport-26.07.90/src/lib/datatypes/stopover.h"
#include <QtCore/qmetatype.h>
#include <QtCore/QList>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'stopover.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.12.0. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN16KPublicTransport8StopoverE_t {};
} // unnamed namespace

template <> constexpr inline auto KPublicTransport::Stopover::qt_create_metaobjectdata<qt_meta_tag_ZN16KPublicTransport8StopoverE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "KPublicTransport::Stopover",
        "scheduledArrivalTime",
        "expectedArrivalTime",
        "hasExpectedArrivalTime",
        "arrivalDelay",
        "scheduledDepartureTime",
        "expectedDepartureTime",
        "hasExpectedDepartureTime",
        "departureDelay",
        "scheduledPlatform",
        "expectedPlatform",
        "hasExpectedPlatform",
        "platformChanged",
        "route",
        "KPublicTransport::Route",
        "stopPoint",
        "KPublicTransport::Location",
        "disruptionEffect",
        "KPublicTransport::Disruption::Effect",
        "notes",
        "loadInformation",
        "QList<KPublicTransport::LoadInfo>",
        "vehicleLayout",
        "KPublicTransport::Vehicle",
        "platformLayout",
        "KPublicTransport::Platform",
        "features",
        "std::vector<KPublicTransport::Feature>",
        "maximumOccupancy",
        "KPublicTransport::Load::Category",
        "aggregatedOccupancy",
        "std::vector<KPublicTransport::LoadInfo>",
        "pickupType",
        "KPublicTransport::PickupDropoff::Type",
        "dropoffType",
        "hasTripIdentifiers"
    };

    QtMocHelpers::UintData qt_methods {
    };
    QtMocHelpers::UintData qt_properties {
        // property 'scheduledArrivalTime'
        QtMocHelpers::PropertyData<QDateTime>(1, QMetaType::QDateTime, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet),
        // property 'expectedArrivalTime'
        QtMocHelpers::PropertyData<QDateTime>(2, QMetaType::QDateTime, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet),
        // property 'hasExpectedArrivalTime'
        QtMocHelpers::PropertyData<bool>(3, QMetaType::Bool, QMC::Readable | QMC::Designable | QMC::Scriptable),
        // property 'arrivalDelay'
        QtMocHelpers::PropertyData<int>(4, QMetaType::Int, QMC::Readable | QMC::Designable | QMC::Scriptable),
        // property 'scheduledDepartureTime'
        QtMocHelpers::PropertyData<QDateTime>(5, QMetaType::QDateTime, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet),
        // property 'expectedDepartureTime'
        QtMocHelpers::PropertyData<QDateTime>(6, QMetaType::QDateTime, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet),
        // property 'hasExpectedDepartureTime'
        QtMocHelpers::PropertyData<bool>(7, QMetaType::Bool, QMC::Readable | QMC::Designable | QMC::Scriptable),
        // property 'departureDelay'
        QtMocHelpers::PropertyData<int>(8, QMetaType::Int, QMC::Readable | QMC::Designable | QMC::Scriptable),
        // property 'scheduledPlatform'
        QtMocHelpers::PropertyData<QString>(9, QMetaType::QString, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet),
        // property 'expectedPlatform'
        QtMocHelpers::PropertyData<QString>(10, QMetaType::QString, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet),
        // property 'hasExpectedPlatform'
        QtMocHelpers::PropertyData<bool>(11, QMetaType::Bool, QMC::Readable | QMC::Designable | QMC::Scriptable),
        // property 'platformChanged'
        QtMocHelpers::PropertyData<bool>(12, QMetaType::Bool, QMC::Readable | QMC::Designable | QMC::Scriptable),
        // property 'route'
        QtMocHelpers::PropertyData<KPublicTransport::Route>(13, 0x80000000 | 14, QMC::DefaultPropertyFlags | QMC::Writable | QMC::EnumOrFlag | QMC::StdCppSet),
        // property 'stopPoint'
        QtMocHelpers::PropertyData<KPublicTransport::Location>(15, 0x80000000 | 16, QMC::DefaultPropertyFlags | QMC::Writable | QMC::EnumOrFlag | QMC::StdCppSet),
        // property 'disruptionEffect'
        QtMocHelpers::PropertyData<KPublicTransport::Disruption::Effect>(17, 0x80000000 | 18, QMC::DefaultPropertyFlags | QMC::Writable | QMC::EnumOrFlag | QMC::StdCppSet),
        // property 'notes'
        QtMocHelpers::PropertyData<QStringList>(19, QMetaType::QStringList, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet),
        // property 'loadInformation'
        QtMocHelpers::PropertyData<QList<KPublicTransport::LoadInfo>>(20, 0x80000000 | 21, QMC::Readable | QMC::Designable | QMC::Scriptable | QMC::EnumOrFlag),
        // property 'vehicleLayout'
        QtMocHelpers::PropertyData<KPublicTransport::Vehicle>(22, 0x80000000 | 23, QMC::DefaultPropertyFlags | QMC::Writable | QMC::EnumOrFlag | QMC::StdCppSet),
        // property 'platformLayout'
        QtMocHelpers::PropertyData<KPublicTransport::Platform>(24, 0x80000000 | 25, QMC::DefaultPropertyFlags | QMC::Writable | QMC::EnumOrFlag | QMC::StdCppSet),
        // property 'features'
        QtMocHelpers::PropertyData<std::vector<KPublicTransport::Feature>>(26, 0x80000000 | 27, QMC::DefaultPropertyFlags | QMC::EnumOrFlag),
        // property 'maximumOccupancy'
        QtMocHelpers::PropertyData<KPublicTransport::Load::Category>(28, 0x80000000 | 29, QMC::Readable | QMC::Designable | QMC::Scriptable | QMC::EnumOrFlag),
        // property 'aggregatedOccupancy'
        QtMocHelpers::PropertyData<std::vector<KPublicTransport::LoadInfo>>(30, 0x80000000 | 31, QMC::Readable | QMC::Designable | QMC::Scriptable | QMC::EnumOrFlag),
        // property 'pickupType'
        QtMocHelpers::PropertyData<KPublicTransport::PickupDropoff::Type>(32, 0x80000000 | 33, QMC::DefaultPropertyFlags | QMC::Writable | QMC::EnumOrFlag | QMC::StdCppSet),
        // property 'dropoffType'
        QtMocHelpers::PropertyData<KPublicTransport::PickupDropoff::Type>(34, 0x80000000 | 33, QMC::DefaultPropertyFlags | QMC::Writable | QMC::EnumOrFlag | QMC::StdCppSet),
        // property 'hasTripIdentifiers'
        QtMocHelpers::PropertyData<bool>(35, QMetaType::Bool, QMC::Readable | QMC::Designable | QMC::Scriptable),
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<Stopover, qt_meta_tag_ZN16KPublicTransport8StopoverE_t>(QMC::PropertyAccessInStaticMetaCall, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT static const QMetaObject::SuperData qt_meta_extradata_ZN16KPublicTransport8StopoverE[] = {
    QMetaObject::SuperData::link<KPublicTransport::Disruption::staticMetaObject>(),
    QMetaObject::SuperData::link<KPublicTransport::Load::staticMetaObject>(),
    QMetaObject::SuperData::link<KPublicTransport::PickupDropoff::staticMetaObject>(),
    nullptr
};

Q_CONSTINIT const QMetaObject KPublicTransport::Stopover::staticMetaObject = { {
    nullptr,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN16KPublicTransport8StopoverE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN16KPublicTransport8StopoverE_t>.data,
    qt_static_metacall,
    qt_meta_extradata_ZN16KPublicTransport8StopoverE,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN16KPublicTransport8StopoverE_t>.metaTypes,
    nullptr
} };

void KPublicTransport::Stopover::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = reinterpret_cast<Stopover *>(_o);
    if (_c == QMetaObject::RegisterPropertyMetaType) {
        switch (_id) {
        default: *reinterpret_cast<int*>(_a[0]) = -1; break;
        case 13:
            *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< KPublicTransport::Location >(); break;
        case 18:
            *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< KPublicTransport::Platform >(); break;
        case 12:
            *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< KPublicTransport::Route >(); break;
        case 17:
            *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< KPublicTransport::Vehicle >(); break;
        case 16:
            *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< QList<KPublicTransport::LoadInfo> >(); break;
        }
    }
    if (_c == QMetaObject::ReadProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: *reinterpret_cast<QDateTime*>(_v) = _t->scheduledArrivalTime(); break;
        case 1: *reinterpret_cast<QDateTime*>(_v) = _t->expectedArrivalTime(); break;
        case 2: *reinterpret_cast<bool*>(_v) = _t->hasExpectedArrivalTime(); break;
        case 3: *reinterpret_cast<int*>(_v) = _t->arrivalDelay(); break;
        case 4: *reinterpret_cast<QDateTime*>(_v) = _t->scheduledDepartureTime(); break;
        case 5: *reinterpret_cast<QDateTime*>(_v) = _t->expectedDepartureTime(); break;
        case 6: *reinterpret_cast<bool*>(_v) = _t->hasExpectedDepartureTime(); break;
        case 7: *reinterpret_cast<int*>(_v) = _t->departureDelay(); break;
        case 8: *reinterpret_cast<QString*>(_v) = _t->scheduledPlatform(); break;
        case 9: *reinterpret_cast<QString*>(_v) = _t->expectedPlatform(); break;
        case 10: *reinterpret_cast<bool*>(_v) = _t->hasExpectedPlatform(); break;
        case 11: *reinterpret_cast<bool*>(_v) = _t->platformChanged(); break;
        case 12: *reinterpret_cast<KPublicTransport::Route*>(_v) = _t->route(); break;
        case 13: *reinterpret_cast<KPublicTransport::Location*>(_v) = _t->stopPoint(); break;
        case 14: *reinterpret_cast<KPublicTransport::Disruption::Effect*>(_v) = _t->disruptionEffect(); break;
        case 15: *reinterpret_cast<QStringList*>(_v) = _t->notes(); break;
        case 16: *reinterpret_cast<QList<KPublicTransport::LoadInfo>*>(_v) = _t->loadInformationList(); break;
        case 17: *reinterpret_cast<KPublicTransport::Vehicle*>(_v) = _t->vehicleLayout(); break;
        case 18: *reinterpret_cast<KPublicTransport::Platform*>(_v) = _t->platformLayout(); break;
        case 19: *reinterpret_cast<std::vector<KPublicTransport::Feature>*>(_v) = _t->features(); break;
        case 20: *reinterpret_cast<KPublicTransport::Load::Category*>(_v) = _t->maximumOccupancy(); break;
        case 21: *reinterpret_cast<std::vector<KPublicTransport::LoadInfo>*>(_v) = _t->aggregatedOccupancy(); break;
        case 22: *reinterpret_cast<KPublicTransport::PickupDropoff::Type*>(_v) = _t->pickupType(); break;
        case 23: *reinterpret_cast<KPublicTransport::PickupDropoff::Type*>(_v) = _t->dropoffType(); break;
        case 24: *reinterpret_cast<bool*>(_v) = _t->hasTripIdentifiers(); break;
        default: break;
        }
    }
    if (_c == QMetaObject::WriteProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: _t->setScheduledArrivalTime(*reinterpret_cast<QDateTime*>(_v)); break;
        case 1: _t->setExpectedArrivalTime(*reinterpret_cast<QDateTime*>(_v)); break;
        case 4: _t->setScheduledDepartureTime(*reinterpret_cast<QDateTime*>(_v)); break;
        case 5: _t->setExpectedDepartureTime(*reinterpret_cast<QDateTime*>(_v)); break;
        case 8: _t->setScheduledPlatform(*reinterpret_cast<QString*>(_v)); break;
        case 9: _t->setExpectedPlatform(*reinterpret_cast<QString*>(_v)); break;
        case 12: _t->setRoute(*reinterpret_cast<KPublicTransport::Route*>(_v)); break;
        case 13: _t->setStopPoint(*reinterpret_cast<KPublicTransport::Location*>(_v)); break;
        case 14: _t->setDisruptionEffect(*reinterpret_cast<KPublicTransport::Disruption::Effect*>(_v)); break;
        case 15: _t->setNotes(*reinterpret_cast<QStringList*>(_v)); break;
        case 17: _t->setVehicleLayout(*reinterpret_cast<KPublicTransport::Vehicle*>(_v)); break;
        case 18: _t->setPlatformLayout(*reinterpret_cast<KPublicTransport::Platform*>(_v)); break;
        case 22: _t->setPickupType(*reinterpret_cast<KPublicTransport::PickupDropoff::Type*>(_v)); break;
        case 23: _t->setDropoffType(*reinterpret_cast<KPublicTransport::PickupDropoff::Type*>(_v)); break;
        default: break;
        }
    }
}
namespace {
struct qt_meta_tag_ZN16KPublicTransport13PickupDropoffE_t {};
} // unnamed namespace

template <> constexpr inline auto KPublicTransport::PickupDropoff::qt_create_metaobjectdata<qt_meta_tag_ZN16KPublicTransport13PickupDropoffE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "KPublicTransport::PickupDropoff",
        "Type",
        "Normal",
        "CoordinateWithDriver",
        "CallAgency",
        "NotAllowed"
    };

    QtMocHelpers::UintData qt_methods {
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
        // enum 'Type'
        QtMocHelpers::EnumData<Type>(1, 1, QMC::EnumFlags{}).add({
            {    2, Type::Normal },
            {    3, Type::CoordinateWithDriver },
            {    4, Type::CallAgency },
            {    5, Type::NotAllowed },
        }),
    };
    return QtMocHelpers::metaObjectData<void, qt_meta_tag_ZN16KPublicTransport13PickupDropoffE_t>(QMC::PropertyAccessInStaticMetaCall, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}

static constexpr auto qt_staticMetaObjectContent_ZN16KPublicTransport13PickupDropoffE =
    KPublicTransport::PickupDropoff::qt_create_metaobjectdata<qt_meta_tag_ZN16KPublicTransport13PickupDropoffE_t>();
static constexpr auto qt_staticMetaObjectStaticContent_ZN16KPublicTransport13PickupDropoffE =
    qt_staticMetaObjectContent_ZN16KPublicTransport13PickupDropoffE.staticData;
static constexpr auto qt_staticMetaObjectRelocatingContent_ZN16KPublicTransport13PickupDropoffE =
    qt_staticMetaObjectContent_ZN16KPublicTransport13PickupDropoffE.relocatingData;

Q_CONSTINIT const QMetaObject KPublicTransport::PickupDropoff::staticMetaObject = { {
    nullptr,
    qt_staticMetaObjectStaticContent_ZN16KPublicTransport13PickupDropoffE.stringdata,
    qt_staticMetaObjectStaticContent_ZN16KPublicTransport13PickupDropoffE.data,
    nullptr,
    nullptr,
    qt_staticMetaObjectRelocatingContent_ZN16KPublicTransport13PickupDropoffE.metaTypes,
    nullptr
} };

QT_WARNING_POP
