/****************************************************************************
** Meta object code from reading C++ file 'journeyquerymodel.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.12.0)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../../kpublictransport-26.07.90/src/lib/models/journeyquerymodel.h"
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'journeyquerymodel.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.12.0. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN16KPublicTransport17JourneyQueryModelE_t {};
} // unnamed namespace

template <> constexpr inline auto KPublicTransport::JourneyQueryModel::qt_create_metaobjectdata<qt_meta_tag_ZN16KPublicTransport17JourneyQueryModelE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "KPublicTransport::JourneyQueryModel",
        "requestChanged",
        "",
        "canQueryPrevNextChanged",
        "queryNext",
        "queryPrevious",
        "request",
        "KPublicTransport::JourneyRequest",
        "canQueryNext",
        "canQueryPrevious",
        "Roles",
        "JourneyRole",
        "ScheduledDepartureTime",
        "ScheduledArrivalTime",
        "ScheduledDepartureDate",
        "ScheduledArrivalDate"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'requestChanged'
        QtMocHelpers::SignalData<void()>(1, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'canQueryPrevNextChanged'
        QtMocHelpers::SignalData<void()>(3, 2, QMC::AccessPublic, QMetaType::Void),
        // Method 'queryNext'
        QtMocHelpers::MethodData<void()>(4, 2, QMC::AccessPublic, QMetaType::Void),
        // Method 'queryPrevious'
        QtMocHelpers::MethodData<void()>(5, 2, QMC::AccessPublic, QMetaType::Void),
    };
    QtMocHelpers::UintData qt_properties {
        // property 'request'
        QtMocHelpers::PropertyData<KPublicTransport::JourneyRequest>(6, 0x80000000 | 7, QMC::DefaultPropertyFlags | QMC::Writable | QMC::EnumOrFlag | QMC::StdCppSet, 0),
        // property 'canQueryNext'
        QtMocHelpers::PropertyData<bool>(8, QMetaType::Bool, QMC::DefaultPropertyFlags, 1),
        // property 'canQueryPrevious'
        QtMocHelpers::PropertyData<bool>(9, QMetaType::Bool, QMC::DefaultPropertyFlags, 1),
    };
    QtMocHelpers::UintData qt_enums {
        // enum 'Roles'
        QtMocHelpers::EnumData<enum Roles>(10, 10, QMC::EnumFlags{}).add({
            {   11, Roles::JourneyRole },
            {   12, Roles::ScheduledDepartureTime },
            {   13, Roles::ScheduledArrivalTime },
            {   14, Roles::ScheduledDepartureDate },
            {   15, Roles::ScheduledArrivalDate },
        }),
    };
    return QtMocHelpers::metaObjectData<JourneyQueryModel, qt_meta_tag_ZN16KPublicTransport17JourneyQueryModelE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject KPublicTransport::JourneyQueryModel::staticMetaObject = { {
    QMetaObject::SuperData::link<AbstractQueryModel::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN16KPublicTransport17JourneyQueryModelE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN16KPublicTransport17JourneyQueryModelE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN16KPublicTransport17JourneyQueryModelE_t>.metaTypes,
    nullptr
} };

void KPublicTransport::JourneyQueryModel::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<JourneyQueryModel *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->requestChanged(); break;
        case 1: _t->canQueryPrevNextChanged(); break;
        case 2: _t->queryNext(); break;
        case 3: _t->queryPrevious(); break;
        default: ;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (JourneyQueryModel::*)()>(_a, &JourneyQueryModel::requestChanged, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (JourneyQueryModel::*)()>(_a, &JourneyQueryModel::canQueryPrevNextChanged, 1))
            return;
    }
    if (_c == QMetaObject::RegisterPropertyMetaType) {
        switch (_id) {
        default: *reinterpret_cast<int*>(_a[0]) = -1; break;
        case 0:
            *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< KPublicTransport::JourneyRequest >(); break;
        }
    }
    if (_c == QMetaObject::ReadProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: *reinterpret_cast<KPublicTransport::JourneyRequest*>(_v) = _t->request(); break;
        case 1: *reinterpret_cast<bool*>(_v) = _t->canQueryNext(); break;
        case 2: *reinterpret_cast<bool*>(_v) = _t->canQueryPrevious(); break;
        default: break;
        }
    }
    if (_c == QMetaObject::WriteProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: _t->setRequest(*reinterpret_cast<KPublicTransport::JourneyRequest*>(_v)); break;
        default: break;
        }
    }
}

const QMetaObject *KPublicTransport::JourneyQueryModel::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *KPublicTransport::JourneyQueryModel::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN16KPublicTransport17JourneyQueryModelE_t>.strings))
        return static_cast<void*>(this);
    return AbstractQueryModel::qt_metacast(_clname);
}

int KPublicTransport::JourneyQueryModel::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = AbstractQueryModel::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 4)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 4;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 4)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 4;
    }
    if (_c == QMetaObject::ReadProperty || _c == QMetaObject::WriteProperty
            || _c == QMetaObject::ResetProperty || _c == QMetaObject::BindableProperty
            || _c == QMetaObject::RegisterPropertyMetaType) {
        qt_static_metacall(this, _c, _id, _a);
        _id -= 3;
    }
    return _id;
}

// SIGNAL 0
void KPublicTransport::JourneyQueryModel::requestChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 0, nullptr);
}

// SIGNAL 1
void KPublicTransport::JourneyQueryModel::canQueryPrevNextChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 1, nullptr);
}
QT_WARNING_POP
