/****************************************************************************
** Meta object code from reading C++ file 'onboardstatus.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.12.0)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../../kpublictransport-26.07.90/src/onboard/onboardstatus.h"
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'onboardstatus.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.12.0. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN16KPublicTransport13OnboardStatusE_t {};
} // unnamed namespace

template <> constexpr inline auto KPublicTransport::OnboardStatus::qt_create_metaobjectdata<qt_meta_tag_ZN16KPublicTransport13OnboardStatusE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "KPublicTransport::OnboardStatus",
        "statusChanged",
        "",
        "positionChanged",
        "supportsPositionChanged",
        "journeyChanged",
        "supportsJourneyChanged",
        "updateIntervalChanged",
        "requestPosition",
        "requestJourney",
        "requestPermissions",
        "status",
        "Status",
        "latitude",
        "longitude",
        "hasPosition",
        "supportsPosition",
        "speed",
        "hasSpeed",
        "heading",
        "hasHeading",
        "altitude",
        "hasAltitude",
        "journey",
        "KPublicTransport::Journey",
        "hasJourney",
        "supportsJourney",
        "positionUpdateInterval",
        "journeyUpdateInterval",
        "NotConnected",
        "Onboard",
        "MissingPermissions",
        "WifiNotEnabled",
        "LocationServiceNotEnabled",
        "NotAvailable"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'statusChanged'
        QtMocHelpers::SignalData<void()>(1, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'positionChanged'
        QtMocHelpers::SignalData<void()>(3, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'supportsPositionChanged'
        QtMocHelpers::SignalData<void()>(4, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'journeyChanged'
        QtMocHelpers::SignalData<void()>(5, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'supportsJourneyChanged'
        QtMocHelpers::SignalData<void()>(6, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'updateIntervalChanged'
        QtMocHelpers::SignalData<void()>(7, 2, QMC::AccessPublic, QMetaType::Void),
        // Method 'requestPosition'
        QtMocHelpers::MethodData<void()>(8, 2, QMC::AccessPublic, QMetaType::Void),
        // Method 'requestJourney'
        QtMocHelpers::MethodData<void()>(9, 2, QMC::AccessPublic, QMetaType::Void),
        // Method 'requestPermissions'
        QtMocHelpers::MethodData<void()>(10, 2, QMC::AccessPublic, QMetaType::Void),
    };
    QtMocHelpers::UintData qt_properties {
        // property 'status'
        QtMocHelpers::PropertyData<enum Status>(11, 0x80000000 | 12, QMC::DefaultPropertyFlags | QMC::EnumOrFlag, 0),
        // property 'latitude'
        QtMocHelpers::PropertyData<float>(13, QMetaType::Float, QMC::DefaultPropertyFlags, 1),
        // property 'longitude'
        QtMocHelpers::PropertyData<float>(14, QMetaType::Float, QMC::DefaultPropertyFlags, 1),
        // property 'hasPosition'
        QtMocHelpers::PropertyData<bool>(15, QMetaType::Bool, QMC::DefaultPropertyFlags, 1),
        // property 'supportsPosition'
        QtMocHelpers::PropertyData<bool>(16, QMetaType::Bool, QMC::DefaultPropertyFlags, 2),
        // property 'speed'
        QtMocHelpers::PropertyData<float>(17, QMetaType::Float, QMC::DefaultPropertyFlags, 1),
        // property 'hasSpeed'
        QtMocHelpers::PropertyData<bool>(18, QMetaType::Bool, QMC::DefaultPropertyFlags, 1),
        // property 'heading'
        QtMocHelpers::PropertyData<float>(19, QMetaType::Float, QMC::DefaultPropertyFlags, 1),
        // property 'hasHeading'
        QtMocHelpers::PropertyData<bool>(20, QMetaType::Bool, QMC::DefaultPropertyFlags, 1),
        // property 'altitude'
        QtMocHelpers::PropertyData<float>(21, QMetaType::Float, QMC::DefaultPropertyFlags, 1),
        // property 'hasAltitude'
        QtMocHelpers::PropertyData<bool>(22, QMetaType::Bool, QMC::DefaultPropertyFlags, 1),
        // property 'journey'
        QtMocHelpers::PropertyData<KPublicTransport::Journey>(23, 0x80000000 | 24, QMC::DefaultPropertyFlags | QMC::EnumOrFlag, 3),
        // property 'hasJourney'
        QtMocHelpers::PropertyData<bool>(25, QMetaType::Bool, QMC::DefaultPropertyFlags, 3),
        // property 'supportsJourney'
        QtMocHelpers::PropertyData<bool>(26, QMetaType::Bool, QMC::DefaultPropertyFlags, 4),
        // property 'positionUpdateInterval'
        QtMocHelpers::PropertyData<int>(27, QMetaType::Int, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 5),
        // property 'journeyUpdateInterval'
        QtMocHelpers::PropertyData<int>(28, QMetaType::Int, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 5),
    };
    QtMocHelpers::UintData qt_enums {
        // enum 'Status'
        QtMocHelpers::EnumData<enum Status>(12, 12, QMC::EnumFlags{}).add({
            {   29, Status::NotConnected },
            {   30, Status::Onboard },
            {   31, Status::MissingPermissions },
            {   32, Status::WifiNotEnabled },
            {   33, Status::LocationServiceNotEnabled },
            {   34, Status::NotAvailable },
        }),
    };
    return QtMocHelpers::metaObjectData<OnboardStatus, qt_meta_tag_ZN16KPublicTransport13OnboardStatusE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject KPublicTransport::OnboardStatus::staticMetaObject = { {
    QMetaObject::SuperData::link<QObject::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN16KPublicTransport13OnboardStatusE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN16KPublicTransport13OnboardStatusE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN16KPublicTransport13OnboardStatusE_t>.metaTypes,
    nullptr
} };

void KPublicTransport::OnboardStatus::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<OnboardStatus *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->statusChanged(); break;
        case 1: _t->positionChanged(); break;
        case 2: _t->supportsPositionChanged(); break;
        case 3: _t->journeyChanged(); break;
        case 4: _t->supportsJourneyChanged(); break;
        case 5: _t->updateIntervalChanged(); break;
        case 6: _t->requestPosition(); break;
        case 7: _t->requestJourney(); break;
        case 8: _t->requestPermissions(); break;
        default: ;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (OnboardStatus::*)()>(_a, &OnboardStatus::statusChanged, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (OnboardStatus::*)()>(_a, &OnboardStatus::positionChanged, 1))
            return;
        if (QtMocHelpers::indexOfMethod<void (OnboardStatus::*)()>(_a, &OnboardStatus::supportsPositionChanged, 2))
            return;
        if (QtMocHelpers::indexOfMethod<void (OnboardStatus::*)()>(_a, &OnboardStatus::journeyChanged, 3))
            return;
        if (QtMocHelpers::indexOfMethod<void (OnboardStatus::*)()>(_a, &OnboardStatus::supportsJourneyChanged, 4))
            return;
        if (QtMocHelpers::indexOfMethod<void (OnboardStatus::*)()>(_a, &OnboardStatus::updateIntervalChanged, 5))
            return;
    }
    if (_c == QMetaObject::ReadProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: *reinterpret_cast<enum Status*>(_v) = _t->status(); break;
        case 1: *reinterpret_cast<float*>(_v) = _t->latitude(); break;
        case 2: *reinterpret_cast<float*>(_v) = _t->longitude(); break;
        case 3: *reinterpret_cast<bool*>(_v) = _t->hasPosition(); break;
        case 4: *reinterpret_cast<bool*>(_v) = _t->supportsPosition(); break;
        case 5: *reinterpret_cast<float*>(_v) = _t->speed(); break;
        case 6: *reinterpret_cast<bool*>(_v) = _t->hasSpeed(); break;
        case 7: *reinterpret_cast<float*>(_v) = _t->heading(); break;
        case 8: *reinterpret_cast<bool*>(_v) = _t->hasHeading(); break;
        case 9: *reinterpret_cast<float*>(_v) = _t->altitude(); break;
        case 10: *reinterpret_cast<bool*>(_v) = _t->hasAltitude(); break;
        case 11: *reinterpret_cast<KPublicTransport::Journey*>(_v) = _t->journey(); break;
        case 12: *reinterpret_cast<bool*>(_v) = _t->hasJourney(); break;
        case 13: *reinterpret_cast<bool*>(_v) = _t->supportsJourney(); break;
        case 14: *reinterpret_cast<int*>(_v) = _t->positionUpdateInterval(); break;
        case 15: *reinterpret_cast<int*>(_v) = _t->journeyUpdateInterval(); break;
        default: break;
        }
    }
    if (_c == QMetaObject::WriteProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 14: _t->setPositionUpdateInterval(*reinterpret_cast<int*>(_v)); break;
        case 15: _t->setJourneyUpdateInterval(*reinterpret_cast<int*>(_v)); break;
        default: break;
        }
    }
}

const QMetaObject *KPublicTransport::OnboardStatus::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *KPublicTransport::OnboardStatus::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN16KPublicTransport13OnboardStatusE_t>.strings))
        return static_cast<void*>(this);
    return QObject::qt_metacast(_clname);
}

int KPublicTransport::OnboardStatus::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QObject::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 9)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 9;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 9)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 9;
    }
    if (_c == QMetaObject::ReadProperty || _c == QMetaObject::WriteProperty
            || _c == QMetaObject::ResetProperty || _c == QMetaObject::BindableProperty
            || _c == QMetaObject::RegisterPropertyMetaType) {
        qt_static_metacall(this, _c, _id, _a);
        _id -= 16;
    }
    return _id;
}

// SIGNAL 0
void KPublicTransport::OnboardStatus::statusChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 0, nullptr);
}

// SIGNAL 1
void KPublicTransport::OnboardStatus::positionChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 1, nullptr);
}

// SIGNAL 2
void KPublicTransport::OnboardStatus::supportsPositionChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 2, nullptr);
}

// SIGNAL 3
void KPublicTransport::OnboardStatus::journeyChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 3, nullptr);
}

// SIGNAL 4
void KPublicTransport::OnboardStatus::supportsJourneyChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 4, nullptr);
}

// SIGNAL 5
void KPublicTransport::OnboardStatus::updateIntervalChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 5, nullptr);
}
QT_WARNING_POP
