/****************************************************************************
** Meta object code from reading C++ file 'line.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.12.0)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../../kpublictransport-26.07.90/src/lib/datatypes/line.h"
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'line.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.12.0. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN16KPublicTransport4LineE_t {};
} // unnamed namespace

template <> constexpr inline auto KPublicTransport::Line::qt_create_metaobjectdata<qt_meta_tag_ZN16KPublicTransport4LineE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "KPublicTransport::Line",
        "modeIconName",
        "",
        "KPublicTransport::Line::Mode",
        "mode",
        "name",
        "color",
        "QColor",
        "hasColor",
        "textColor",
        "hasTextColor",
        "modeString",
        "logo",
        "hasLogo",
        "modeLogo",
        "hasModeLogo",
        "operatorName",
        "operatorUrl",
        "QUrl",
        "iconName",
        "isRailBound",
        "Mode",
        "Unknown",
        "Air",
        "Boat",
        "Bus",
        "Coach",
        "Ferry",
        "Funicular",
        "LocalTrain",
        "LongDistanceTrain",
        "Metro",
        "RailShuttle",
        "RapidTransit",
        "Shuttle",
        "Taxi",
        "Train",
        "Tramway",
        "RideShare",
        "AerialLift"
    };

    QtMocHelpers::UintData qt_methods {
        // Method 'modeIconName'
        QtMocHelpers::MethodData<QString(KPublicTransport::Line::Mode)>(1, 2, QMC::AccessPublic, QMetaType::QString, {{
            { 0x80000000 | 3, 4 },
        }}),
    };
    QtMocHelpers::UintData qt_properties {
        // property 'name'
        QtMocHelpers::PropertyData<QString>(5, QMetaType::QString, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet),
        // property 'color'
        QtMocHelpers::PropertyData<QColor>(6, 0x80000000 | 7, QMC::DefaultPropertyFlags | QMC::Writable | QMC::EnumOrFlag | QMC::StdCppSet),
        // property 'hasColor'
        QtMocHelpers::PropertyData<bool>(8, QMetaType::Bool, QMC::Readable | QMC::Designable | QMC::Scriptable),
        // property 'textColor'
        QtMocHelpers::PropertyData<QColor>(9, 0x80000000 | 7, QMC::DefaultPropertyFlags | QMC::Writable | QMC::EnumOrFlag | QMC::StdCppSet),
        // property 'hasTextColor'
        QtMocHelpers::PropertyData<bool>(10, QMetaType::Bool, QMC::Readable | QMC::Designable | QMC::Scriptable),
        // property 'mode'
        QtMocHelpers::PropertyData<KPublicTransport::Line::Mode>(4, 0x80000000 | 3, QMC::DefaultPropertyFlags | QMC::Writable | QMC::EnumOrFlag | QMC::StdCppSet),
        // property 'modeString'
        QtMocHelpers::PropertyData<QString>(11, QMetaType::QString, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet),
        // property 'logo'
        QtMocHelpers::PropertyData<QString>(12, QMetaType::QString, QMC::Readable | QMC::Designable | QMC::Scriptable),
        // property 'hasLogo'
        QtMocHelpers::PropertyData<bool>(13, QMetaType::Bool, QMC::Readable | QMC::Designable | QMC::Scriptable),
        // property 'modeLogo'
        QtMocHelpers::PropertyData<QString>(14, QMetaType::QString, QMC::Readable | QMC::Designable | QMC::Scriptable),
        // property 'hasModeLogo'
        QtMocHelpers::PropertyData<bool>(15, QMetaType::Bool, QMC::Readable | QMC::Designable | QMC::Scriptable),
        // property 'operatorName'
        QtMocHelpers::PropertyData<QString>(16, QMetaType::QString, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet),
        // property 'operatorUrl'
        QtMocHelpers::PropertyData<QUrl>(17, 0x80000000 | 18, QMC::DefaultPropertyFlags | QMC::Writable | QMC::EnumOrFlag | QMC::StdCppSet),
        // property 'modeIconName'
        QtMocHelpers::PropertyData<QString>(1, QMetaType::QString, QMC::Readable | QMC::Designable | QMC::Scriptable),
        // property 'iconName'
        QtMocHelpers::PropertyData<QString>(19, QMetaType::QString, QMC::Readable | QMC::Designable | QMC::Scriptable),
        // property 'isRailBound'
        QtMocHelpers::PropertyData<bool>(20, QMetaType::Bool, QMC::Readable | QMC::Designable | QMC::Scriptable),
    };
    QtMocHelpers::UintData qt_enums {
        // enum 'Mode'
        QtMocHelpers::EnumData<enum Mode>(21, 21, QMC::EnumFlags{}).add({
            {   22, Mode::Unknown },
            {   23, Mode::Air },
            {   24, Mode::Boat },
            {   25, Mode::Bus },
            {   26, Mode::Coach },
            {   27, Mode::Ferry },
            {   28, Mode::Funicular },
            {   29, Mode::LocalTrain },
            {   30, Mode::LongDistanceTrain },
            {   31, Mode::Metro },
            {   32, Mode::RailShuttle },
            {   33, Mode::RapidTransit },
            {   34, Mode::Shuttle },
            {   35, Mode::Taxi },
            {   36, Mode::Train },
            {   37, Mode::Tramway },
            {   38, Mode::RideShare },
            {   39, Mode::AerialLift },
        }),
    };
    return QtMocHelpers::metaObjectData<Line, qt_meta_tag_ZN16KPublicTransport4LineE_t>(QMC::PropertyAccessInStaticMetaCall, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject KPublicTransport::Line::staticMetaObject = { {
    nullptr,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN16KPublicTransport4LineE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN16KPublicTransport4LineE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN16KPublicTransport4LineE_t>.metaTypes,
    nullptr
} };

void KPublicTransport::Line::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = reinterpret_cast<Line *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: { QString _r = _t->modeIconName((*reinterpret_cast<std::add_pointer_t<KPublicTransport::Line::Mode>>(_a[1])));
            if (_a[0]) *reinterpret_cast<QString*>(_a[0]) = std::move(_r); }  break;
        default: ;
        }
    }
    if (_c == QMetaObject::ReadProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: *reinterpret_cast<QString*>(_v) = _t->name(); break;
        case 1: *reinterpret_cast<QColor*>(_v) = _t->color(); break;
        case 2: *reinterpret_cast<bool*>(_v) = _t->hasColor(); break;
        case 3: *reinterpret_cast<QColor*>(_v) = _t->textColor(); break;
        case 4: *reinterpret_cast<bool*>(_v) = _t->hasTextColor(); break;
        case 5: *reinterpret_cast<KPublicTransport::Line::Mode*>(_v) = _t->mode(); break;
        case 6: *reinterpret_cast<QString*>(_v) = _t->modeString(); break;
        case 7: *reinterpret_cast<QString*>(_v) = _t->logo(); break;
        case 8: *reinterpret_cast<bool*>(_v) = _t->hasLogo(); break;
        case 9: *reinterpret_cast<QString*>(_v) = _t->modeLogo(); break;
        case 10: *reinterpret_cast<bool*>(_v) = _t->hasModeLogo(); break;
        case 11: *reinterpret_cast<QString*>(_v) = _t->operatorName(); break;
        case 12: *reinterpret_cast<QUrl*>(_v) = _t->operatorUrl(); break;
        case 13: *reinterpret_cast<QString*>(_v) = _t->modeIconName(); break;
        case 14: *reinterpret_cast<QString*>(_v) = _t->iconName(); break;
        case 15: *reinterpret_cast<bool*>(_v) = _t->isRailBound(); break;
        default: break;
        }
    }
    if (_c == QMetaObject::WriteProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: _t->setName(*reinterpret_cast<QString*>(_v)); break;
        case 1: _t->setColor(*reinterpret_cast<QColor*>(_v)); break;
        case 3: _t->setTextColor(*reinterpret_cast<QColor*>(_v)); break;
        case 5: _t->setMode(*reinterpret_cast<KPublicTransport::Line::Mode*>(_v)); break;
        case 6: _t->setModeString(*reinterpret_cast<QString*>(_v)); break;
        case 11: _t->setOperatorName(*reinterpret_cast<QString*>(_v)); break;
        case 12: _t->setOperatorUrl(*reinterpret_cast<QUrl*>(_v)); break;
        default: break;
        }
    }
}
namespace {
struct qt_meta_tag_ZN16KPublicTransport5RouteE_t {};
} // unnamed namespace

template <> constexpr inline auto KPublicTransport::Route::qt_create_metaobjectdata<qt_meta_tag_ZN16KPublicTransport5RouteE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "KPublicTransport::Route",
        "line",
        "KPublicTransport::Line",
        "direction",
        "destination",
        "KPublicTransport::Location",
        "name"
    };

    QtMocHelpers::UintData qt_methods {
    };
    QtMocHelpers::UintData qt_properties {
        // property 'line'
        QtMocHelpers::PropertyData<KPublicTransport::Line>(1, 0x80000000 | 2, QMC::DefaultPropertyFlags | QMC::Writable | QMC::EnumOrFlag | QMC::StdCppSet),
        // property 'direction'
        QtMocHelpers::PropertyData<QString>(3, QMetaType::QString, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet),
        // property 'destination'
        QtMocHelpers::PropertyData<KPublicTransport::Location>(4, 0x80000000 | 5, QMC::DefaultPropertyFlags | QMC::Writable | QMC::EnumOrFlag | QMC::StdCppSet),
        // property 'name'
        QtMocHelpers::PropertyData<QString>(6, QMetaType::QString, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet),
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<Route, qt_meta_tag_ZN16KPublicTransport5RouteE_t>(QMC::PropertyAccessInStaticMetaCall, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject KPublicTransport::Route::staticMetaObject = { {
    nullptr,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN16KPublicTransport5RouteE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN16KPublicTransport5RouteE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN16KPublicTransport5RouteE_t>.metaTypes,
    nullptr
} };

void KPublicTransport::Route::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = reinterpret_cast<Route *>(_o);
    if (_c == QMetaObject::RegisterPropertyMetaType) {
        switch (_id) {
        default: *reinterpret_cast<int*>(_a[0]) = -1; break;
        case 0:
            *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< KPublicTransport::Line >(); break;
        case 2:
            *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< KPublicTransport::Location >(); break;
        }
    }
    if (_c == QMetaObject::ReadProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: *reinterpret_cast<KPublicTransport::Line*>(_v) = _t->line(); break;
        case 1: *reinterpret_cast<QString*>(_v) = _t->direction(); break;
        case 2: *reinterpret_cast<KPublicTransport::Location*>(_v) = _t->destination(); break;
        case 3: *reinterpret_cast<QString*>(_v) = _t->name(); break;
        default: break;
        }
    }
    if (_c == QMetaObject::WriteProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: _t->setLine(*reinterpret_cast<KPublicTransport::Line*>(_v)); break;
        case 1: _t->setDirection(*reinterpret_cast<QString*>(_v)); break;
        case 2: _t->setDestination(*reinterpret_cast<KPublicTransport::Location*>(_v)); break;
        case 3: _t->setName(*reinterpret_cast<QString*>(_v)); break;
        default: break;
        }
    }
}
QT_WARNING_POP
