/****************************************************************************
** Meta object code from reading C++ file 'feature.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.12.0)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../../kpublictransport-26.07.90/src/lib/datatypes/feature.h"
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'feature.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.12.0. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN16KPublicTransport7FeatureE_t {};
} // unnamed namespace

template <> constexpr inline auto KPublicTransport::Feature::qt_create_metaobjectdata<qt_meta_tag_ZN16KPublicTransport7FeatureE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "KPublicTransport::Feature",
        "name",
        "displayName",
        "description",
        "type",
        "Type",
        "availability",
        "Availability",
        "disruptionEffect",
        "KPublicTransport::Disruption::Effect",
        "quantity",
        "typeIconName",
        "NoFeature",
        "AirConditioning",
        "Restaurant",
        "ToddlerArea",
        "FamilyArea",
        "WheelchairAccessible",
        "SilentArea",
        "BusinessArea",
        "BikeStorage",
        "Toilet",
        "WheelchairAccessibleToilet",
        "InformationPoint",
        "WiFi",
        "PowerSockets",
        "SleeperCompartment",
        "Other",
        "Unknown",
        "Available",
        "Unavailable",
        "Limited",
        "Conditional"
    };

    QtMocHelpers::UintData qt_methods {
    };
    QtMocHelpers::UintData qt_properties {
        // property 'name'
        QtMocHelpers::PropertyData<QString>(1, QMetaType::QString, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet),
        // property 'displayName'
        QtMocHelpers::PropertyData<QString>(2, QMetaType::QString, QMC::Readable | QMC::Designable | QMC::Scriptable),
        // property 'description'
        QtMocHelpers::PropertyData<QString>(3, QMetaType::QString, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet),
        // property 'type'
        QtMocHelpers::PropertyData<enum Type>(4, 0x80000000 | 5, QMC::DefaultPropertyFlags | QMC::Writable | QMC::EnumOrFlag | QMC::StdCppSet),
        // property 'availability'
        QtMocHelpers::PropertyData<enum Availability>(6, 0x80000000 | 7, QMC::DefaultPropertyFlags | QMC::Writable | QMC::EnumOrFlag | QMC::StdCppSet),
        // property 'disruptionEffect'
        QtMocHelpers::PropertyData<KPublicTransport::Disruption::Effect>(8, 0x80000000 | 9, QMC::DefaultPropertyFlags | QMC::Writable | QMC::EnumOrFlag | QMC::StdCppSet),
        // property 'quantity'
        QtMocHelpers::PropertyData<int>(10, QMetaType::Int, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet),
        // property 'typeIconName'
        QtMocHelpers::PropertyData<QString>(11, QMetaType::QString, QMC::Readable | QMC::Designable | QMC::Scriptable),
    };
    QtMocHelpers::UintData qt_enums {
        // enum 'Type'
        QtMocHelpers::EnumData<enum Type>(5, 5, QMC::EnumFlags{}).add({
            {   12, Type::NoFeature },
            {   13, Type::AirConditioning },
            {   14, Type::Restaurant },
            {   15, Type::ToddlerArea },
            {   16, Type::FamilyArea },
            {   17, Type::WheelchairAccessible },
            {   18, Type::SilentArea },
            {   19, Type::BusinessArea },
            {   20, Type::BikeStorage },
            {   21, Type::Toilet },
            {   22, Type::WheelchairAccessibleToilet },
            {   23, Type::InformationPoint },
            {   24, Type::WiFi },
            {   25, Type::PowerSockets },
            {   26, Type::SleeperCompartment },
            {   27, Type::Other },
        }),
        // enum 'Availability'
        QtMocHelpers::EnumData<enum Availability>(7, 7, QMC::EnumFlags{}).add({
            {   28, Availability::Unknown },
            {   29, Availability::Available },
            {   30, Availability::Unavailable },
            {   31, Availability::Limited },
            {   32, Availability::Conditional },
        }),
    };
    return QtMocHelpers::metaObjectData<Feature, qt_meta_tag_ZN16KPublicTransport7FeatureE_t>(QMC::PropertyAccessInStaticMetaCall, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT static const QMetaObject::SuperData qt_meta_extradata_ZN16KPublicTransport7FeatureE[] = {
    QMetaObject::SuperData::link<KPublicTransport::Disruption::staticMetaObject>(),
    nullptr
};

Q_CONSTINIT const QMetaObject KPublicTransport::Feature::staticMetaObject = { {
    nullptr,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN16KPublicTransport7FeatureE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN16KPublicTransport7FeatureE_t>.data,
    qt_static_metacall,
    qt_meta_extradata_ZN16KPublicTransport7FeatureE,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN16KPublicTransport7FeatureE_t>.metaTypes,
    nullptr
} };

void KPublicTransport::Feature::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = reinterpret_cast<Feature *>(_o);
    if (_c == QMetaObject::ReadProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: *reinterpret_cast<QString*>(_v) = _t->name(); break;
        case 1: *reinterpret_cast<QString*>(_v) = _t->displayName(); break;
        case 2: *reinterpret_cast<QString*>(_v) = _t->description(); break;
        case 3: *reinterpret_cast<enum Type*>(_v) = _t->type(); break;
        case 4: *reinterpret_cast<enum Availability*>(_v) = _t->availability(); break;
        case 5: *reinterpret_cast<KPublicTransport::Disruption::Effect*>(_v) = _t->disruptionEffect(); break;
        case 6: *reinterpret_cast<int*>(_v) = _t->quantity(); break;
        case 7: *reinterpret_cast<QString*>(_v) = _t->typeIconName(); break;
        default: break;
        }
    }
    if (_c == QMetaObject::WriteProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: _t->setName(*reinterpret_cast<QString*>(_v)); break;
        case 2: _t->setDescription(*reinterpret_cast<QString*>(_v)); break;
        case 3: _t->setType(*reinterpret_cast<enum Type*>(_v)); break;
        case 4: _t->setAvailability(*reinterpret_cast<enum Availability*>(_v)); break;
        case 5: _t->setDisruptionEffect(*reinterpret_cast<KPublicTransport::Disruption::Effect*>(_v)); break;
        case 6: _t->setQuantity(*reinterpret_cast<int*>(_v)); break;
        default: break;
        }
    }
}
QT_WARNING_POP
