/****************************************************************************
** Resource object code
**
** Created by: The Resource Compiler for Qt version 6.12.0
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#ifdef _MSC_VER
// disable informational message "function ... selected for automatic inline expansion"
#pragma warning (disable: 4711)
#endif

static const unsigned char qt_resource_data[] = {
  // asset-attributions.json
  0x0,0x0,0x0,0xad,
  0x28,
  0xb5,0x2f,0xfd,0x60,0x33,0x2,0x1d,0x5,0x0,0x32,0x87,0x19,0x19,0x60,0xd7,0x3,
  0x4c,0x5b,0xb1,0x1b,0x95,0x82,0x66,0x5,0xff,0xac,0x24,0xe,0xc5,0xff,0xd2,0xc8,
  0x9a,0xef,0x90,0x2c,0xd,0x60,0xaf,0x79,0x82,0x67,0xfd,0x9b,0x63,0x5b,0x6f,0x86,
  0x9c,0xab,0x12,0x64,0x30,0xc,0x40,0x17,0xdd,0xeb,0x96,0x9a,0xe3,0xfb,0x31,0x6b,
  0xd5,0xd7,0x49,0x30,0x9,0x69,0x20,0x72,0x39,0x24,0xa5,0x1b,0xff,0x63,0x29,0x8f,
  0x74,0x9e,0xd9,0x7c,0xdc,0x8b,0x5d,0x59,0x96,0x44,0xe9,0xb,0x88,0x1b,0xe7,0x7b,
  0x33,0x85,0xd5,0x42,0x7f,0xed,0x64,0x95,0x8,0x8b,0xf8,0xb7,0xe2,0x8,0x1f,0x7,
  0x1f,0x13,0x17,0x20,0x80,0x62,0x5a,0x1e,0x4f,0xdb,0x87,0x0,0x46,0x93,0x9c,0xd3,
  0x97,0x4a,0x41,0x9c,0xa0,0xe0,0x4d,0x8f,0x44,0xd9,0x8d,0x2e,0x35,0x84,0xb6,0x0,
  0xd1,0x90,0xcb,0xdd,0xac,0x89,0x6b,0x5e,0xdd,0x35,0x65,0xe2,0x5c,0x85,0xc2,0xf5,
  0x45,0x70,0x61,0xce,0x11,0x6,0xe8,0xed,0xce,0x6,0x70,0x87,
  
};

static const unsigned char qt_resource_name[] = {
  // org.kde.kpublictransport
  0x0,0x18,
  0x9,0x54,0x97,0xd4,
  0x0,0x6f,
  0x0,0x72,0x0,0x67,0x0,0x2e,0x0,0x6b,0x0,0x64,0x0,0x65,0x0,0x2e,0x0,0x6b,0x0,0x70,0x0,0x75,0x0,0x62,0x0,0x6c,0x0,0x69,0x0,0x63,0x0,0x74,0x0,0x72,
  0x0,0x61,0x0,0x6e,0x0,0x73,0x0,0x70,0x0,0x6f,0x0,0x72,0x0,0x74,
    // assets
  0x0,0x6,
  0x6,0x8a,0x9c,0xb3,
  0x0,0x61,
  0x0,0x73,0x0,0x73,0x0,0x65,0x0,0x74,0x0,0x73,
    // asset-attributions.json
  0x0,0x17,
  0x5,0xfa,0x1a,0x9e,
  0x0,0x61,
  0x0,0x73,0x0,0x73,0x0,0x65,0x0,0x74,0x0,0x2d,0x0,0x61,0x0,0x74,0x0,0x74,0x0,0x72,0x0,0x69,0x0,0x62,0x0,0x75,0x0,0x74,0x0,0x69,0x0,0x6f,0x0,0x6e,
  0x0,0x73,0x0,0x2e,0x0,0x6a,0x0,0x73,0x0,0x6f,0x0,0x6e,
  
};

static const unsigned char qt_resource_struct[] = {
  // :
  0x0,0x0,0x0,0x0,0x0,0x2,0x0,0x0,0x0,0x1,0x0,0x0,0x0,0x1,
0x0,0x0,0x1,0x9f,0xb7,0x6a,0xce,0x50,
  // :/org.kde.kpublictransport
  0x0,0x0,0x0,0x0,0x0,0x2,0x0,0x0,0x0,0x1,0x0,0x0,0x0,0x2,
0x0,0x0,0x1,0x9f,0xb7,0x6a,0xce,0x50,
  // :/org.kde.kpublictransport/assets
  0x0,0x0,0x0,0x36,0x0,0x2,0x0,0x0,0x0,0x1,0x0,0x0,0x0,0x3,
0x0,0x0,0x1,0x9f,0xb7,0x6a,0xce,0x50,
  // :/org.kde.kpublictransport/assets/asset-attributions.json
  0x0,0x0,0x0,0x48,0x0,0x4,0x0,0x0,0x0,0x1,0x0,0x0,0x0,0x0,
0x0,0x0,0x1,0x9f,0xb7,0x6a,0xce,0x50,

};

#ifdef QT_NAMESPACE
#  define QT_RCC_PREPEND_NAMESPACE(name) ::QT_NAMESPACE::name
#  define QT_RCC_MANGLE_NAMESPACE0(x) x
#  define QT_RCC_MANGLE_NAMESPACE1(a, b) a##_##b
#  define QT_RCC_MANGLE_NAMESPACE2(a, b) QT_RCC_MANGLE_NAMESPACE1(a,b)
#  define QT_RCC_MANGLE_NAMESPACE(name) QT_RCC_MANGLE_NAMESPACE2( \
        QT_RCC_MANGLE_NAMESPACE0(name), QT_RCC_MANGLE_NAMESPACE0(QT_NAMESPACE))
#else
#   define QT_RCC_PREPEND_NAMESPACE(name) name
#   define QT_RCC_MANGLE_NAMESPACE(name) name
#endif

#if defined(QT_INLINE_NAMESPACE)
inline namespace QT_NAMESPACE {
#elif defined(QT_NAMESPACE)
namespace QT_NAMESPACE {
#endif

bool qRegisterResourceData(int, const unsigned char *, const unsigned char *, const unsigned char *);
bool qUnregisterResourceData(int, const unsigned char *, const unsigned char *, const unsigned char *);

#if defined(__ELF__) || defined(__APPLE__)
static inline unsigned char qResourceFeatureZstd()
{
    extern const unsigned char qt_resourceFeatureZstd;
    return qt_resourceFeatureZstd;
}
#else
unsigned char qResourceFeatureZstd();
#endif

#ifdef QT_NAMESPACE
}
#endif

int QT_RCC_MANGLE_NAMESPACE(qInitResources_asset_attributions)();
int QT_RCC_MANGLE_NAMESPACE(qInitResources_asset_attributions)()
{
    int version = 3;
    QT_RCC_PREPEND_NAMESPACE(qRegisterResourceData)
        (version, qt_resource_struct, qt_resource_name, qt_resource_data);
    return 1;
}

int QT_RCC_MANGLE_NAMESPACE(qCleanupResources_asset_attributions)();
int QT_RCC_MANGLE_NAMESPACE(qCleanupResources_asset_attributions)()
{
    int version = 3;
    version += QT_RCC_PREPEND_NAMESPACE(qResourceFeatureZstd());
    QT_RCC_PREPEND_NAMESPACE(qUnregisterResourceData)
       (version, qt_resource_struct, qt_resource_name, qt_resource_data);
    return 1;
}

#ifdef __clang__
#   pragma clang diagnostic push
#   pragma clang diagnostic ignored "-Wexit-time-destructors"
#endif

namespace {
   struct initializer {
       initializer() { QT_RCC_MANGLE_NAMESPACE(qInitResources_asset_attributions)(); }
       ~initializer() { QT_RCC_MANGLE_NAMESPACE(qCleanupResources_asset_attributions)(); }
   } dummy;
}

#ifdef __clang__
#   pragma clang diagnostic pop
#endif
