/****************************************************************************
** Meta object code from reading C++ file 'stopoverrequest.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.12.0)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../../kpublictransport-26.07.90/src/lib/stopoverrequest.h"
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'stopoverrequest.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.12.0. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN16KPublicTransport15StopoverRequestE_t {};
} // unnamed namespace

template <> constexpr inline auto KPublicTransport::StopoverRequest::qt_create_metaobjectdata<qt_meta_tag_ZN16KPublicTransport15StopoverRequestE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "KPublicTransport::StopoverRequest",
        "stop",
        "KPublicTransport::Location",
        "dateTime",
        "lineModes",
        "QVariantList",
        "mode",
        "Mode",
        "backends",
        "downloadAssets",
        "maximumResults",
        "QueryArrival",
        "QueryDeparture"
    };

    QtMocHelpers::UintData qt_methods {
    };
    QtMocHelpers::UintData qt_properties {
        // property 'stop'
        QtMocHelpers::PropertyData<KPublicTransport::Location>(1, 0x80000000 | 2, QMC::DefaultPropertyFlags | QMC::Writable | QMC::EnumOrFlag | QMC::StdCppSet),
        // property 'dateTime'
        QtMocHelpers::PropertyData<QDateTime>(3, QMetaType::QDateTime, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet),
        // property 'lineModes'
        QtMocHelpers::PropertyData<QVariantList>(4, 0x80000000 | 5, QMC::DefaultPropertyFlags | QMC::Writable | QMC::EnumOrFlag),
        // property 'mode'
        QtMocHelpers::PropertyData<enum Mode>(6, 0x80000000 | 7, QMC::DefaultPropertyFlags | QMC::Writable | QMC::EnumOrFlag | QMC::StdCppSet),
        // property 'backends'
        QtMocHelpers::PropertyData<QStringList>(8, QMetaType::QStringList, QMC::DefaultPropertyFlags | QMC::Writable),
        // property 'downloadAssets'
        QtMocHelpers::PropertyData<bool>(9, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet),
        // property 'maximumResults'
        QtMocHelpers::PropertyData<int>(10, QMetaType::Int, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet),
    };
    QtMocHelpers::UintData qt_enums {
        // enum 'Mode'
        QtMocHelpers::EnumData<enum Mode>(7, 7, QMC::EnumFlags{}).add({
            {   11, Mode::QueryArrival },
            {   12, Mode::QueryDeparture },
        }),
    };
    return QtMocHelpers::metaObjectData<StopoverRequest, qt_meta_tag_ZN16KPublicTransport15StopoverRequestE_t>(QMC::PropertyAccessInStaticMetaCall, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject KPublicTransport::StopoverRequest::staticMetaObject = { {
    nullptr,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN16KPublicTransport15StopoverRequestE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN16KPublicTransport15StopoverRequestE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN16KPublicTransport15StopoverRequestE_t>.metaTypes,
    nullptr
} };

void KPublicTransport::StopoverRequest::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = reinterpret_cast<StopoverRequest *>(_o);
    if (_c == QMetaObject::RegisterPropertyMetaType) {
        switch (_id) {
        default: *reinterpret_cast<int*>(_a[0]) = -1; break;
        case 0:
            *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< KPublicTransport::Location >(); break;
        }
    }
    if (_c == QMetaObject::ReadProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: *reinterpret_cast<KPublicTransport::Location*>(_v) = _t->stop(); break;
        case 1: *reinterpret_cast<QDateTime*>(_v) = _t->dateTime(); break;
        case 2: *reinterpret_cast<QVariantList*>(_v) = _t->lineModesVariant(); break;
        case 3: *reinterpret_cast<enum Mode*>(_v) = _t->mode(); break;
        case 4: *reinterpret_cast<QStringList*>(_v) = _t->backendIds(); break;
        case 5: *reinterpret_cast<bool*>(_v) = _t->downloadAssets(); break;
        case 6: *reinterpret_cast<int*>(_v) = _t->maximumResults(); break;
        default: break;
        }
    }
    if (_c == QMetaObject::WriteProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: _t->setStop(*reinterpret_cast<KPublicTransport::Location*>(_v)); break;
        case 1: _t->setDateTime(*reinterpret_cast<QDateTime*>(_v)); break;
        case 2: _t->setLineModesVariant(*reinterpret_cast<QVariantList*>(_v)); break;
        case 3: _t->setMode(*reinterpret_cast<enum Mode*>(_v)); break;
        case 4: _t->setBackendIds(*reinterpret_cast<QStringList*>(_v)); break;
        case 5: _t->setDownloadAssets(*reinterpret_cast<bool*>(_v)); break;
        case 6: _t->setMaximumResults(*reinterpret_cast<int*>(_v)); break;
        default: break;
        }
    }
}
QT_WARNING_POP
