/****************************************************************************
** Meta object code from reading C++ file 'styledframesvgitem.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.12.0)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../../kpublictransport-26.07.90/src/quick/styledframesvgitem.h"
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'styledframesvgitem.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.12.0. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN16KPublicTransport18StyledFrameSvgItemE_t {};
} // unnamed namespace

template <> constexpr inline auto KPublicTransport::StyledFrameSvgItem::qt_create_metaobjectdata<qt_meta_tag_ZN16KPublicTransport18StyledFrameSvgItemE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "KPublicTransport::StyledFrameSvgItem",
        "QML.Element",
        "auto",
        "borderTopChanged",
        "",
        "borderBottomChanged",
        "borderLeftChanged",
        "borderRightChanged",
        "colorChanged",
        "sourceChanged",
        "borderTop",
        "borderBottom",
        "borderLeft",
        "borderRight",
        "lineColor",
        "QColor",
        "backgroundColor",
        "source"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'borderTopChanged'
        QtMocHelpers::SignalData<void()>(3, 4, QMC::AccessPublic, QMetaType::Void),
        // Signal 'borderBottomChanged'
        QtMocHelpers::SignalData<void()>(5, 4, QMC::AccessPublic, QMetaType::Void),
        // Signal 'borderLeftChanged'
        QtMocHelpers::SignalData<void()>(6, 4, QMC::AccessPublic, QMetaType::Void),
        // Signal 'borderRightChanged'
        QtMocHelpers::SignalData<void()>(7, 4, QMC::AccessPublic, QMetaType::Void),
        // Signal 'colorChanged'
        QtMocHelpers::SignalData<void()>(8, 4, QMC::AccessPublic, QMetaType::Void),
        // Signal 'sourceChanged'
        QtMocHelpers::SignalData<void()>(9, 4, QMC::AccessPublic, QMetaType::Void),
    };
    QtMocHelpers::UintData qt_properties {
        // property 'borderTop'
        QtMocHelpers::PropertyData<double>(10, QMetaType::Double, QMC::DefaultPropertyFlags | QMC::Writable, 0),
        // property 'borderBottom'
        QtMocHelpers::PropertyData<double>(11, QMetaType::Double, QMC::DefaultPropertyFlags | QMC::Writable, 1),
        // property 'borderLeft'
        QtMocHelpers::PropertyData<double>(12, QMetaType::Double, QMC::DefaultPropertyFlags | QMC::Writable, 2),
        // property 'borderRight'
        QtMocHelpers::PropertyData<double>(13, QMetaType::Double, QMC::DefaultPropertyFlags | QMC::Writable, 3),
        // property 'lineColor'
        QtMocHelpers::PropertyData<QColor>(14, 0x80000000 | 15, QMC::DefaultPropertyFlags | QMC::Writable | QMC::EnumOrFlag, 4),
        // property 'backgroundColor'
        QtMocHelpers::PropertyData<QColor>(16, 0x80000000 | 15, QMC::DefaultPropertyFlags | QMC::Writable | QMC::EnumOrFlag, 4),
        // property 'source'
        QtMocHelpers::PropertyData<QString>(17, QMetaType::QString, QMC::DefaultPropertyFlags | QMC::Writable, 5),
    };
    QtMocHelpers::UintData qt_enums {
    };
    QtMocHelpers::UintData qt_constructors {};
    QtMocHelpers::ClassInfos qt_classinfo({
            {    1,    2 },
    });
    return QtMocHelpers::metaObjectData<StyledFrameSvgItem, void>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums, qt_constructors, qt_classinfo);
}
Q_CONSTINIT const QMetaObject KPublicTransport::StyledFrameSvgItem::staticMetaObject = { {
    QMetaObject::SuperData::link<QQuickPaintedItem::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN16KPublicTransport18StyledFrameSvgItemE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN16KPublicTransport18StyledFrameSvgItemE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN16KPublicTransport18StyledFrameSvgItemE_t>.metaTypes,
    nullptr
} };

void KPublicTransport::StyledFrameSvgItem::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<StyledFrameSvgItem *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->borderTopChanged(); break;
        case 1: _t->borderBottomChanged(); break;
        case 2: _t->borderLeftChanged(); break;
        case 3: _t->borderRightChanged(); break;
        case 4: _t->colorChanged(); break;
        case 5: _t->sourceChanged(); break;
        default: ;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (StyledFrameSvgItem::*)()>(_a, &StyledFrameSvgItem::borderTopChanged, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (StyledFrameSvgItem::*)()>(_a, &StyledFrameSvgItem::borderBottomChanged, 1))
            return;
        if (QtMocHelpers::indexOfMethod<void (StyledFrameSvgItem::*)()>(_a, &StyledFrameSvgItem::borderLeftChanged, 2))
            return;
        if (QtMocHelpers::indexOfMethod<void (StyledFrameSvgItem::*)()>(_a, &StyledFrameSvgItem::borderRightChanged, 3))
            return;
        if (QtMocHelpers::indexOfMethod<void (StyledFrameSvgItem::*)()>(_a, &StyledFrameSvgItem::colorChanged, 4))
            return;
        if (QtMocHelpers::indexOfMethod<void (StyledFrameSvgItem::*)()>(_a, &StyledFrameSvgItem::sourceChanged, 5))
            return;
    }
    if (_c == QMetaObject::ReadProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: *reinterpret_cast<double*>(_v) = _t->m_borderTop; break;
        case 1: *reinterpret_cast<double*>(_v) = _t->m_borderBottom; break;
        case 2: *reinterpret_cast<double*>(_v) = _t->m_borderLeft; break;
        case 3: *reinterpret_cast<double*>(_v) = _t->m_borderRight; break;
        case 4: *reinterpret_cast<QColor*>(_v) = _t->m_lineColor; break;
        case 5: *reinterpret_cast<QColor*>(_v) = _t->m_fillColor; break;
        case 6: *reinterpret_cast<QString*>(_v) = _t->m_source; break;
        default: break;
        }
    }
    if (_c == QMetaObject::WriteProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0:
            if (QtMocHelpers::setProperty(_t->m_borderTop, *reinterpret_cast<double*>(_v)))
                Q_EMIT _t->borderTopChanged();
            break;
        case 1:
            if (QtMocHelpers::setProperty(_t->m_borderBottom, *reinterpret_cast<double*>(_v)))
                Q_EMIT _t->borderBottomChanged();
            break;
        case 2:
            if (QtMocHelpers::setProperty(_t->m_borderLeft, *reinterpret_cast<double*>(_v)))
                Q_EMIT _t->borderLeftChanged();
            break;
        case 3:
            if (QtMocHelpers::setProperty(_t->m_borderRight, *reinterpret_cast<double*>(_v)))
                Q_EMIT _t->borderRightChanged();
            break;
        case 4:
            if (QtMocHelpers::setProperty(_t->m_lineColor, *reinterpret_cast<QColor*>(_v)))
                Q_EMIT _t->colorChanged();
            break;
        case 5:
            if (QtMocHelpers::setProperty(_t->m_fillColor, *reinterpret_cast<QColor*>(_v)))
                Q_EMIT _t->colorChanged();
            break;
        case 6:
            if (QtMocHelpers::setProperty(_t->m_source, *reinterpret_cast<QString*>(_v)))
                Q_EMIT _t->sourceChanged();
            break;
        default: break;
        }
    }
}

const QMetaObject *KPublicTransport::StyledFrameSvgItem::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *KPublicTransport::StyledFrameSvgItem::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN16KPublicTransport18StyledFrameSvgItemE_t>.strings))
        return static_cast<void*>(this);
    return QQuickPaintedItem::qt_metacast(_clname);
}

int KPublicTransport::StyledFrameSvgItem::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QQuickPaintedItem::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 6)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 6;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 6)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 6;
    }
    if (_c == QMetaObject::ReadProperty || _c == QMetaObject::WriteProperty
            || _c == QMetaObject::ResetProperty || _c == QMetaObject::BindableProperty
            || _c == QMetaObject::RegisterPropertyMetaType) {
        qt_static_metacall(this, _c, _id, _a);
        _id -= 7;
    }
    return _id;
}

// SIGNAL 0
void KPublicTransport::StyledFrameSvgItem::borderTopChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 0, nullptr);
}

// SIGNAL 1
void KPublicTransport::StyledFrameSvgItem::borderBottomChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 1, nullptr);
}

// SIGNAL 2
void KPublicTransport::StyledFrameSvgItem::borderLeftChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 2, nullptr);
}

// SIGNAL 3
void KPublicTransport::StyledFrameSvgItem::borderRightChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 3, nullptr);
}

// SIGNAL 4
void KPublicTransport::StyledFrameSvgItem::colorChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 4, nullptr);
}

// SIGNAL 5
void KPublicTransport::StyledFrameSvgItem::sourceChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 5, nullptr);
}
QT_WARNING_POP
