/****************************************************************************
** Meta object code from reading C++ file 'journey.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.12.0)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../../kpublictransport-26.07.90/src/lib/datatypes/journey.h"
#include <QtCore/qmetatype.h>
#include <QtCore/QList>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'journey.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.12.0. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN16KPublicTransport14JourneySectionE_t {};
} // unnamed namespace

template <> constexpr inline auto KPublicTransport::JourneySection::qt_create_metaobjectdata<qt_meta_tag_ZN16KPublicTransport14JourneySectionE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "KPublicTransport::JourneySection",
        "modeIconName",
        "",
        "KPublicTransport::JourneySection::Mode",
        "mode",
        "stopover",
        "KPublicTransport::Stopover",
        "qsizetype",
        "idx",
        "Mode",
        "scheduledDepartureTime",
        "expectedDepartureTime",
        "hasExpectedDepartureTime",
        "departureDelay",
        "scheduledArrivalTime",
        "expectedArrivalTime",
        "hasExpectedArrivalTime",
        "arrivalDelay",
        "duration",
        "distance",
        "from",
        "KPublicTransport::Location",
        "to",
        "route",
        "KPublicTransport::Route",
        "scheduledDeparturePlatform",
        "expectedDeparturePlatform",
        "hasExpectedDeparturePlatform",
        "departurePlatformChanged",
        "scheduledArrivalPlatform",
        "expectedArrivalPlatform",
        "hasExpectedArrivalPlatform",
        "arrivalPlatformChanged",
        "disruptionEffect",
        "KPublicTransport::Disruption::Effect",
        "notes",
        "intermediateStops",
        "QVariantList",
        "departure",
        "arrival",
        "co2Emission",
        "loadInformation",
        "QList<KPublicTransport::LoadInfo>",
        "rentalVehicle",
        "KPublicTransport::RentalVehicle",
        "path",
        "KPublicTransport::Path",
        "departureVehicleLayout",
        "KPublicTransport::Vehicle",
        "departurePlatformLayout",
        "KPublicTransport::Platform",
        "arrivalVehicleLayout",
        "arrivalPlatformLayout",
        "individualTransport",
        "KPublicTransport::IndividualTransport",
        "features",
        "std::vector<KPublicTransport::Feature>",
        "iconName",
        "label",
        "maximumOccupancy",
        "KPublicTransport::Load::Category",
        "bookingUrl",
        "QUrl",
        "Invalid",
        "PublicTransport",
        "Transfer",
        "Walking",
        "Waiting",
        "RentedVehicle",
        "IndividualTransport",
        "Modes"
    };

    QtMocHelpers::UintData qt_methods {
        // Method 'modeIconName'
        QtMocHelpers::MethodData<QString(KPublicTransport::JourneySection::Mode)>(1, 2, QMC::AccessPublic, QMetaType::QString, {{
            { 0x80000000 | 3, 4 },
        }}),
        // Method 'stopover'
        QtMocHelpers::MethodData<KPublicTransport::Stopover(qsizetype) const>(5, 2, QMC::AccessPublic, 0x80000000 | 6, {{
            { 0x80000000 | 7, 8 },
        }}),
    };
    QtMocHelpers::UintData qt_properties {
        // property 'mode'
        QtMocHelpers::PropertyData<enum Mode>(4, 0x80000000 | 9, QMC::DefaultPropertyFlags | QMC::Writable | QMC::EnumOrFlag | QMC::StdCppSet),
        // property 'scheduledDepartureTime'
        QtMocHelpers::PropertyData<QDateTime>(10, QMetaType::QDateTime, QMC::Readable | QMC::Writable | QMC::Designable | QMC::Scriptable | QMC::StdCppSet),
        // property 'expectedDepartureTime'
        QtMocHelpers::PropertyData<QDateTime>(11, QMetaType::QDateTime, QMC::Readable | QMC::Writable | QMC::Designable | QMC::Scriptable | QMC::StdCppSet),
        // property 'hasExpectedDepartureTime'
        QtMocHelpers::PropertyData<bool>(12, QMetaType::Bool, QMC::Readable | QMC::Designable | QMC::Scriptable),
        // property 'departureDelay'
        QtMocHelpers::PropertyData<int>(13, QMetaType::Int, QMC::Readable | QMC::Designable | QMC::Scriptable),
        // property 'scheduledArrivalTime'
        QtMocHelpers::PropertyData<QDateTime>(14, QMetaType::QDateTime, QMC::Readable | QMC::Writable | QMC::Designable | QMC::Scriptable | QMC::StdCppSet),
        // property 'expectedArrivalTime'
        QtMocHelpers::PropertyData<QDateTime>(15, QMetaType::QDateTime, QMC::Readable | QMC::Writable | QMC::Designable | QMC::Scriptable | QMC::StdCppSet),
        // property 'hasExpectedArrivalTime'
        QtMocHelpers::PropertyData<bool>(16, QMetaType::Bool, QMC::Readable | QMC::Designable | QMC::Scriptable),
        // property 'arrivalDelay'
        QtMocHelpers::PropertyData<int>(17, QMetaType::Int, QMC::Readable | QMC::Designable | QMC::Scriptable),
        // property 'duration'
        QtMocHelpers::PropertyData<int>(18, QMetaType::Int, QMC::Readable | QMC::Designable | QMC::Scriptable),
        // property 'distance'
        QtMocHelpers::PropertyData<int>(19, QMetaType::Int, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet),
        // property 'from'
        QtMocHelpers::PropertyData<KPublicTransport::Location>(20, 0x80000000 | 21, QMC::DefaultPropertyFlags | QMC::Writable | QMC::EnumOrFlag | QMC::StdCppSet),
        // property 'to'
        QtMocHelpers::PropertyData<KPublicTransport::Location>(22, 0x80000000 | 21, QMC::DefaultPropertyFlags | QMC::Writable | QMC::EnumOrFlag | QMC::StdCppSet),
        // property 'route'
        QtMocHelpers::PropertyData<KPublicTransport::Route>(23, 0x80000000 | 24, QMC::DefaultPropertyFlags | QMC::Writable | QMC::EnumOrFlag | QMC::StdCppSet),
        // property 'scheduledDeparturePlatform'
        QtMocHelpers::PropertyData<QString>(25, QMetaType::QString, QMC::Readable | QMC::Writable | QMC::Designable | QMC::Scriptable | QMC::StdCppSet),
        // property 'expectedDeparturePlatform'
        QtMocHelpers::PropertyData<QString>(26, QMetaType::QString, QMC::Readable | QMC::Writable | QMC::Designable | QMC::Scriptable | QMC::StdCppSet),
        // property 'hasExpectedDeparturePlatform'
        QtMocHelpers::PropertyData<bool>(27, QMetaType::Bool, QMC::Readable | QMC::Designable | QMC::Scriptable),
        // property 'departurePlatformChanged'
        QtMocHelpers::PropertyData<bool>(28, QMetaType::Bool, QMC::Readable | QMC::Designable | QMC::Scriptable),
        // property 'scheduledArrivalPlatform'
        QtMocHelpers::PropertyData<QString>(29, QMetaType::QString, QMC::Readable | QMC::Writable | QMC::Designable | QMC::Scriptable | QMC::StdCppSet),
        // property 'expectedArrivalPlatform'
        QtMocHelpers::PropertyData<QString>(30, QMetaType::QString, QMC::Readable | QMC::Writable | QMC::Designable | QMC::Scriptable | QMC::StdCppSet),
        // property 'hasExpectedArrivalPlatform'
        QtMocHelpers::PropertyData<bool>(31, QMetaType::Bool, QMC::Readable | QMC::Designable | QMC::Scriptable),
        // property 'arrivalPlatformChanged'
        QtMocHelpers::PropertyData<bool>(32, QMetaType::Bool, QMC::Readable | QMC::Designable | QMC::Scriptable),
        // property 'disruptionEffect'
        QtMocHelpers::PropertyData<KPublicTransport::Disruption::Effect>(33, 0x80000000 | 34, QMC::DefaultPropertyFlags | QMC::Writable | QMC::EnumOrFlag | QMC::StdCppSet),
        // property 'notes'
        QtMocHelpers::PropertyData<QStringList>(35, QMetaType::QStringList, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet),
        // property 'intermediateStops'
        QtMocHelpers::PropertyData<QVariantList>(36, 0x80000000 | 37, QMC::DefaultPropertyFlags | QMC::EnumOrFlag),
        // property 'departure'
        QtMocHelpers::PropertyData<KPublicTransport::Stopover>(38, 0x80000000 | 6, QMC::DefaultPropertyFlags | QMC::Writable | QMC::EnumOrFlag | QMC::StdCppSet),
        // property 'arrival'
        QtMocHelpers::PropertyData<KPublicTransport::Stopover>(39, 0x80000000 | 6, QMC::DefaultPropertyFlags | QMC::Writable | QMC::EnumOrFlag | QMC::StdCppSet),
        // property 'co2Emission'
        QtMocHelpers::PropertyData<int>(40, QMetaType::Int, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet),
        // property 'loadInformation'
        QtMocHelpers::PropertyData<QList<KPublicTransport::LoadInfo>>(41, 0x80000000 | 42, QMC::Readable | QMC::Writable | QMC::Designable | QMC::Scriptable | QMC::EnumOrFlag),
        // property 'rentalVehicle'
        QtMocHelpers::PropertyData<KPublicTransport::RentalVehicle>(43, 0x80000000 | 44, QMC::DefaultPropertyFlags | QMC::Writable | QMC::EnumOrFlag | QMC::StdCppSet),
        // property 'path'
        QtMocHelpers::PropertyData<KPublicTransport::Path>(45, 0x80000000 | 46, QMC::DefaultPropertyFlags | QMC::Writable | QMC::EnumOrFlag | QMC::StdCppSet),
        // property 'departureVehicleLayout'
        QtMocHelpers::PropertyData<KPublicTransport::Vehicle>(47, 0x80000000 | 48, QMC::DefaultPropertyFlags | QMC::Writable | QMC::EnumOrFlag | QMC::StdCppSet),
        // property 'departurePlatformLayout'
        QtMocHelpers::PropertyData<KPublicTransport::Platform>(49, 0x80000000 | 50, QMC::DefaultPropertyFlags | QMC::Writable | QMC::EnumOrFlag | QMC::StdCppSet),
        // property 'arrivalVehicleLayout'
        QtMocHelpers::PropertyData<KPublicTransport::Vehicle>(51, 0x80000000 | 48, QMC::DefaultPropertyFlags | QMC::Writable | QMC::EnumOrFlag | QMC::StdCppSet),
        // property 'arrivalPlatformLayout'
        QtMocHelpers::PropertyData<KPublicTransport::Platform>(52, 0x80000000 | 50, QMC::DefaultPropertyFlags | QMC::Writable | QMC::EnumOrFlag | QMC::StdCppSet),
        // property 'individualTransport'
        QtMocHelpers::PropertyData<KPublicTransport::IndividualTransport>(53, 0x80000000 | 54, QMC::DefaultPropertyFlags | QMC::Writable | QMC::EnumOrFlag | QMC::StdCppSet),
        // property 'features'
        QtMocHelpers::PropertyData<std::vector<KPublicTransport::Feature>>(55, 0x80000000 | 56, QMC::DefaultPropertyFlags | QMC::EnumOrFlag),
        // property 'iconName'
        QtMocHelpers::PropertyData<QString>(57, QMetaType::QString, QMC::Readable | QMC::Designable | QMC::Scriptable),
        // property 'label'
        QtMocHelpers::PropertyData<QString>(58, QMetaType::QString, QMC::Readable | QMC::Designable | QMC::Scriptable),
        // property 'maximumOccupancy'
        QtMocHelpers::PropertyData<KPublicTransport::Load::Category>(59, 0x80000000 | 60, QMC::Readable | QMC::Designable | QMC::Scriptable | QMC::EnumOrFlag),
        // property 'bookingUrl'
        QtMocHelpers::PropertyData<QUrl>(61, 0x80000000 | 62, QMC::DefaultPropertyFlags | QMC::Writable | QMC::EnumOrFlag | QMC::StdCppSet),
    };
    QtMocHelpers::UintData qt_enums {
        // enum 'Mode'
        QtMocHelpers::EnumData<enum Mode>(9, 9, QMC::EnumFlags{}).add({
            {   63, Mode::Invalid },
            {   64, Mode::PublicTransport },
            {   65, Mode::Transfer },
            {   66, Mode::Walking },
            {   67, Mode::Waiting },
            {   68, Mode::RentedVehicle },
            {   69, Mode::IndividualTransport },
        }),
        // flag 'Modes'
        QtMocHelpers::EnumData<Modes>(70, 9, QMC::EnumIsFlag).add({
            {   63, Mode::Invalid },
            {   64, Mode::PublicTransport },
            {   65, Mode::Transfer },
            {   66, Mode::Walking },
            {   67, Mode::Waiting },
            {   68, Mode::RentedVehicle },
            {   69, Mode::IndividualTransport },
        }),
    };
    return QtMocHelpers::metaObjectData<JourneySection, qt_meta_tag_ZN16KPublicTransport14JourneySectionE_t>(QMC::PropertyAccessInStaticMetaCall, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT static const QMetaObject::SuperData qt_meta_extradata_ZN16KPublicTransport14JourneySectionE[] = {
    QMetaObject::SuperData::link<KPublicTransport::Disruption::staticMetaObject>(),
    QMetaObject::SuperData::link<KPublicTransport::Load::staticMetaObject>(),
    nullptr
};

Q_CONSTINIT const QMetaObject KPublicTransport::JourneySection::staticMetaObject = { {
    nullptr,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN16KPublicTransport14JourneySectionE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN16KPublicTransport14JourneySectionE_t>.data,
    qt_static_metacall,
    qt_meta_extradata_ZN16KPublicTransport14JourneySectionE,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN16KPublicTransport14JourneySectionE_t>.metaTypes,
    nullptr
} };

void KPublicTransport::JourneySection::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = reinterpret_cast<JourneySection *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: { QString _r = _t->modeIconName((*reinterpret_cast<std::add_pointer_t<KPublicTransport::JourneySection::Mode>>(_a[1])));
            if (_a[0]) *reinterpret_cast<QString*>(_a[0]) = std::move(_r); }  break;
        case 1: { KPublicTransport::Stopover _r = _t->stopover((*reinterpret_cast<std::add_pointer_t<qsizetype>>(_a[1])));
            if (_a[0]) *reinterpret_cast<KPublicTransport::Stopover*>(_a[0]) = std::move(_r); }  break;
        default: ;
        }
    }
    if (_c == QMetaObject::RegisterPropertyMetaType) {
        switch (_id) {
        default: *reinterpret_cast<int*>(_a[0]) = -1; break;
        case 35:
            *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< KPublicTransport::IndividualTransport >(); break;
        case 12:
        case 11:
            *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< KPublicTransport::Location >(); break;
        case 30:
            *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< KPublicTransport::Path >(); break;
        case 34:
        case 32:
            *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< KPublicTransport::Platform >(); break;
        case 13:
            *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< KPublicTransport::Route >(); break;
        case 33:
        case 31:
            *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< KPublicTransport::Vehicle >(); break;
        case 28:
            *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< QList<KPublicTransport::LoadInfo> >(); break;
        }
    }
    if (_c == QMetaObject::ReadProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: *reinterpret_cast<enum Mode*>(_v) = _t->mode(); break;
        case 1: *reinterpret_cast<QDateTime*>(_v) = _t->scheduledDepartureTime(); break;
        case 2: *reinterpret_cast<QDateTime*>(_v) = _t->expectedDepartureTime(); break;
        case 3: *reinterpret_cast<bool*>(_v) = _t->hasExpectedDepartureTime(); break;
        case 4: *reinterpret_cast<int*>(_v) = _t->departureDelay(); break;
        case 5: *reinterpret_cast<QDateTime*>(_v) = _t->scheduledArrivalTime(); break;
        case 6: *reinterpret_cast<QDateTime*>(_v) = _t->expectedArrivalTime(); break;
        case 7: *reinterpret_cast<bool*>(_v) = _t->hasExpectedArrivalTime(); break;
        case 8: *reinterpret_cast<int*>(_v) = _t->arrivalDelay(); break;
        case 9: *reinterpret_cast<int*>(_v) = _t->duration(); break;
        case 10: *reinterpret_cast<int*>(_v) = _t->distance(); break;
        case 11: *reinterpret_cast<KPublicTransport::Location*>(_v) = _t->from(); break;
        case 12: *reinterpret_cast<KPublicTransport::Location*>(_v) = _t->to(); break;
        case 13: *reinterpret_cast<KPublicTransport::Route*>(_v) = _t->route(); break;
        case 14: *reinterpret_cast<QString*>(_v) = _t->scheduledDeparturePlatform(); break;
        case 15: *reinterpret_cast<QString*>(_v) = _t->expectedDeparturePlatform(); break;
        case 16: *reinterpret_cast<bool*>(_v) = _t->hasExpectedDeparturePlatform(); break;
        case 17: *reinterpret_cast<bool*>(_v) = _t->departurePlatformChanged(); break;
        case 18: *reinterpret_cast<QString*>(_v) = _t->scheduledArrivalPlatform(); break;
        case 19: *reinterpret_cast<QString*>(_v) = _t->expectedArrivalPlatform(); break;
        case 20: *reinterpret_cast<bool*>(_v) = _t->hasExpectedArrivalPlatform(); break;
        case 21: *reinterpret_cast<bool*>(_v) = _t->arrivalPlatformChanged(); break;
        case 22: *reinterpret_cast<KPublicTransport::Disruption::Effect*>(_v) = _t->disruptionEffect(); break;
        case 23: *reinterpret_cast<QStringList*>(_v) = _t->notes(); break;
        case 24: *reinterpret_cast<QVariantList*>(_v) = _t->intermediateStopsVariant(); break;
        case 25: *reinterpret_cast<KPublicTransport::Stopover*>(_v) = _t->departure(); break;
        case 26: *reinterpret_cast<KPublicTransport::Stopover*>(_v) = _t->arrival(); break;
        case 27: *reinterpret_cast<int*>(_v) = _t->co2Emission(); break;
        case 28: *reinterpret_cast<QList<KPublicTransport::LoadInfo>*>(_v) = _t->loadInformationList(); break;
        case 29: *reinterpret_cast<KPublicTransport::RentalVehicle*>(_v) = _t->rentalVehicle(); break;
        case 30: *reinterpret_cast<KPublicTransport::Path*>(_v) = _t->path(); break;
        case 31: *reinterpret_cast<KPublicTransport::Vehicle*>(_v) = _t->departureVehicleLayout(); break;
        case 32: *reinterpret_cast<KPublicTransport::Platform*>(_v) = _t->departurePlatformLayout(); break;
        case 33: *reinterpret_cast<KPublicTransport::Vehicle*>(_v) = _t->arrivalVehicleLayout(); break;
        case 34: *reinterpret_cast<KPublicTransport::Platform*>(_v) = _t->arrivalPlatformLayout(); break;
        case 35: *reinterpret_cast<KPublicTransport::IndividualTransport*>(_v) = _t->individualTransport(); break;
        case 36: *reinterpret_cast<std::vector<KPublicTransport::Feature>*>(_v) = _t->features(); break;
        case 37: *reinterpret_cast<QString*>(_v) = _t->iconName(); break;
        case 38: *reinterpret_cast<QString*>(_v) = _t->label(); break;
        case 39: *reinterpret_cast<KPublicTransport::Load::Category*>(_v) = _t->maximumOccupancy(); break;
        case 40: *reinterpret_cast<QUrl*>(_v) = _t->bookingUrl(); break;
        default: break;
        }
    }
    if (_c == QMetaObject::WriteProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: _t->setMode(*reinterpret_cast<enum Mode*>(_v)); break;
        case 1: _t->setScheduledDepartureTime(*reinterpret_cast<QDateTime*>(_v)); break;
        case 2: _t->setExpectedDepartureTime(*reinterpret_cast<QDateTime*>(_v)); break;
        case 5: _t->setScheduledArrivalTime(*reinterpret_cast<QDateTime*>(_v)); break;
        case 6: _t->setExpectedArrivalTime(*reinterpret_cast<QDateTime*>(_v)); break;
        case 10: _t->setDistance(*reinterpret_cast<int*>(_v)); break;
        case 11: _t->setFrom(*reinterpret_cast<KPublicTransport::Location*>(_v)); break;
        case 12: _t->setTo(*reinterpret_cast<KPublicTransport::Location*>(_v)); break;
        case 13: _t->setRoute(*reinterpret_cast<KPublicTransport::Route*>(_v)); break;
        case 14: _t->setScheduledDeparturePlatform(*reinterpret_cast<QString*>(_v)); break;
        case 15: _t->setExpectedDeparturePlatform(*reinterpret_cast<QString*>(_v)); break;
        case 18: _t->setScheduledArrivalPlatform(*reinterpret_cast<QString*>(_v)); break;
        case 19: _t->setExpectedArrivalPlatform(*reinterpret_cast<QString*>(_v)); break;
        case 22: _t->setDisruptionEffect(*reinterpret_cast<KPublicTransport::Disruption::Effect*>(_v)); break;
        case 23: _t->setNotes(*reinterpret_cast<QStringList*>(_v)); break;
        case 25: _t->setDeparture(*reinterpret_cast<KPublicTransport::Stopover*>(_v)); break;
        case 26: _t->setArrival(*reinterpret_cast<KPublicTransport::Stopover*>(_v)); break;
        case 27: _t->setCo2Emission(*reinterpret_cast<int*>(_v)); break;
        case 28: _t->setLoadInformationList(*reinterpret_cast<QList<KPublicTransport::LoadInfo>*>(_v)); break;
        case 29: _t->setRentalVehicle(*reinterpret_cast<KPublicTransport::RentalVehicle*>(_v)); break;
        case 30: _t->setPath(*reinterpret_cast<KPublicTransport::Path*>(_v)); break;
        case 31: _t->setDepartureVehicleLayout(*reinterpret_cast<KPublicTransport::Vehicle*>(_v)); break;
        case 32: _t->setDeparturePlatformLayout(*reinterpret_cast<KPublicTransport::Platform*>(_v)); break;
        case 33: _t->setArrivalVehicleLayout(*reinterpret_cast<KPublicTransport::Vehicle*>(_v)); break;
        case 34: _t->setArrivalPlatformLayout(*reinterpret_cast<KPublicTransport::Platform*>(_v)); break;
        case 35: _t->setIndividualTransport(*reinterpret_cast<KPublicTransport::IndividualTransport*>(_v)); break;
        case 40: _t->setBookingUrl(*reinterpret_cast<QUrl*>(_v)); break;
        default: break;
        }
    }
}
namespace {
struct qt_meta_tag_ZN16KPublicTransport7JourneyE_t {};
} // unnamed namespace

template <> constexpr inline auto KPublicTransport::Journey::qt_create_metaobjectdata<qt_meta_tag_ZN16KPublicTransport7JourneyE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "KPublicTransport::Journey",
        "sections",
        "QList<KPublicTransport::JourneySection>",
        "scheduledDepartureTime",
        "hasExpectedDepartureTime",
        "expectedDepartureTime",
        "departureDelay",
        "scheduledArrivalTime",
        "hasExpectedArrivalTime",
        "expectedArrivalTime",
        "arrivalDelay",
        "duration",
        "numberOfChanges",
        "disruptionEffect",
        "KPublicTransport::Disruption::Effect",
        "distance",
        "co2Emission",
        "maximumOccupancy",
        "KPublicTransport::Load::Category",
        "bookingUrl",
        "QUrl"
    };

    QtMocHelpers::UintData qt_methods {
    };
    QtMocHelpers::UintData qt_properties {
        // property 'sections'
        QtMocHelpers::PropertyData<QList<KPublicTransport::JourneySection>>(1, 0x80000000 | 2, QMC::DefaultPropertyFlags | QMC::Writable | QMC::EnumOrFlag),
        // property 'scheduledDepartureTime'
        QtMocHelpers::PropertyData<QDateTime>(3, QMetaType::QDateTime, QMC::Readable | QMC::Designable | QMC::Scriptable),
        // property 'hasExpectedDepartureTime'
        QtMocHelpers::PropertyData<bool>(4, QMetaType::Bool, QMC::Readable | QMC::Designable | QMC::Scriptable),
        // property 'expectedDepartureTime'
        QtMocHelpers::PropertyData<QDateTime>(5, QMetaType::QDateTime, QMC::Readable | QMC::Designable | QMC::Scriptable),
        // property 'departureDelay'
        QtMocHelpers::PropertyData<int>(6, QMetaType::Int, QMC::Readable | QMC::Designable | QMC::Scriptable),
        // property 'scheduledArrivalTime'
        QtMocHelpers::PropertyData<QDateTime>(7, QMetaType::QDateTime, QMC::Readable | QMC::Designable | QMC::Scriptable),
        // property 'hasExpectedArrivalTime'
        QtMocHelpers::PropertyData<bool>(8, QMetaType::Bool, QMC::Readable | QMC::Designable | QMC::Scriptable),
        // property 'expectedArrivalTime'
        QtMocHelpers::PropertyData<QDateTime>(9, QMetaType::QDateTime, QMC::Readable | QMC::Designable | QMC::Scriptable),
        // property 'arrivalDelay'
        QtMocHelpers::PropertyData<int>(10, QMetaType::Int, QMC::Readable | QMC::Designable | QMC::Scriptable),
        // property 'duration'
        QtMocHelpers::PropertyData<int>(11, QMetaType::Int, QMC::Readable | QMC::Designable | QMC::Scriptable),
        // property 'numberOfChanges'
        QtMocHelpers::PropertyData<int>(12, QMetaType::Int, QMC::Readable | QMC::Designable | QMC::Scriptable),
        // property 'disruptionEffect'
        QtMocHelpers::PropertyData<KPublicTransport::Disruption::Effect>(13, 0x80000000 | 14, QMC::Readable | QMC::Designable | QMC::Scriptable | QMC::EnumOrFlag),
        // property 'distance'
        QtMocHelpers::PropertyData<int>(15, QMetaType::Int, QMC::Readable | QMC::Designable | QMC::Scriptable),
        // property 'co2Emission'
        QtMocHelpers::PropertyData<int>(16, QMetaType::Int, QMC::Readable | QMC::Designable | QMC::Scriptable),
        // property 'maximumOccupancy'
        QtMocHelpers::PropertyData<KPublicTransport::Load::Category>(17, 0x80000000 | 18, QMC::Readable | QMC::Designable | QMC::Scriptable | QMC::EnumOrFlag),
        // property 'bookingUrl'
        QtMocHelpers::PropertyData<QUrl>(19, 0x80000000 | 20, QMC::DefaultPropertyFlags | QMC::Writable | QMC::EnumOrFlag | QMC::StdCppSet),
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<Journey, qt_meta_tag_ZN16KPublicTransport7JourneyE_t>(QMC::PropertyAccessInStaticMetaCall, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT static const QMetaObject::SuperData qt_meta_extradata_ZN16KPublicTransport7JourneyE[] = {
    QMetaObject::SuperData::link<KPublicTransport::Disruption::staticMetaObject>(),
    QMetaObject::SuperData::link<KPublicTransport::Load::staticMetaObject>(),
    nullptr
};

Q_CONSTINIT const QMetaObject KPublicTransport::Journey::staticMetaObject = { {
    nullptr,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN16KPublicTransport7JourneyE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN16KPublicTransport7JourneyE_t>.data,
    qt_static_metacall,
    qt_meta_extradata_ZN16KPublicTransport7JourneyE,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN16KPublicTransport7JourneyE_t>.metaTypes,
    nullptr
} };

void KPublicTransport::Journey::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = reinterpret_cast<Journey *>(_o);
    if (_c == QMetaObject::RegisterPropertyMetaType) {
        switch (_id) {
        default: *reinterpret_cast<int*>(_a[0]) = -1; break;
        case 0:
            *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< QList<KPublicTransport::JourneySection> >(); break;
        }
    }
    if (_c == QMetaObject::ReadProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: *reinterpret_cast<QList<KPublicTransport::JourneySection>*>(_v) = _t->sectionsList(); break;
        case 1: *reinterpret_cast<QDateTime*>(_v) = _t->scheduledDepartureTime(); break;
        case 2: *reinterpret_cast<bool*>(_v) = _t->hasExpectedDepartureTime(); break;
        case 3: *reinterpret_cast<QDateTime*>(_v) = _t->expectedDepartureTime(); break;
        case 4: *reinterpret_cast<int*>(_v) = _t->departureDelay(); break;
        case 5: *reinterpret_cast<QDateTime*>(_v) = _t->scheduledArrivalTime(); break;
        case 6: *reinterpret_cast<bool*>(_v) = _t->hasExpectedArrivalTime(); break;
        case 7: *reinterpret_cast<QDateTime*>(_v) = _t->expectedArrivalTime(); break;
        case 8: *reinterpret_cast<int*>(_v) = _t->arrivalDelay(); break;
        case 9: *reinterpret_cast<int*>(_v) = _t->duration(); break;
        case 10: *reinterpret_cast<int*>(_v) = _t->numberOfChanges(); break;
        case 11: *reinterpret_cast<KPublicTransport::Disruption::Effect*>(_v) = _t->disruptionEffect(); break;
        case 12: *reinterpret_cast<int*>(_v) = _t->distance(); break;
        case 13: *reinterpret_cast<int*>(_v) = _t->co2Emission(); break;
        case 14: *reinterpret_cast<KPublicTransport::Load::Category*>(_v) = _t->maximumOccupancy(); break;
        case 15: *reinterpret_cast<QUrl*>(_v) = _t->bookingUrl(); break;
        default: break;
        }
    }
    if (_c == QMetaObject::WriteProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: _t->setSectionsList(*reinterpret_cast<QList<KPublicTransport::JourneySection>*>(_v)); break;
        case 15: _t->setBookingUrl(*reinterpret_cast<QUrl*>(_v)); break;
        default: break;
        }
    }
}
QT_WARNING_POP
