/****************************************************************************
** Meta object code from reading C++ file 'updateresult.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.12.0)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../../kpublictransport-26.07.90/src/lib/update/updateresult.h"
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'updateresult.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.12.0. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN16KPublicTransport12UpdateResultE_t {};
} // unnamed namespace

template <> constexpr inline auto KPublicTransport::UpdateResult::qt_create_metaobjectdata<qt_meta_tag_ZN16KPublicTransport12UpdateResultE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "KPublicTransport::UpdateResult",
        "Type",
        "NoError",
        "NoUpdate",
        "UpdateSuccessful",
        "NetworkError",
        "FilesystemError",
        "IncompatibleVersion",
        "FileFormatError",
        "UpdatesDisabled",
        "InProgress"
    };

    QtMocHelpers::UintData qt_methods {
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
        // enum 'Type'
        QtMocHelpers::EnumData<Type>(1, 1, QMC::EnumFlags{}).add({
            {    2, Type::NoError },
            {    3, Type::NoUpdate },
            {    4, Type::UpdateSuccessful },
            {    5, Type::NetworkError },
            {    6, Type::FilesystemError },
            {    7, Type::IncompatibleVersion },
            {    8, Type::FileFormatError },
            {    9, Type::UpdatesDisabled },
            {   10, Type::InProgress },
        }),
    };
    return QtMocHelpers::metaObjectData<void, qt_meta_tag_ZN16KPublicTransport12UpdateResultE_t>(QMC::PropertyAccessInStaticMetaCall, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}

static constexpr auto qt_staticMetaObjectContent_ZN16KPublicTransport12UpdateResultE =
    KPublicTransport::UpdateResult::qt_create_metaobjectdata<qt_meta_tag_ZN16KPublicTransport12UpdateResultE_t>();
static constexpr auto qt_staticMetaObjectStaticContent_ZN16KPublicTransport12UpdateResultE =
    qt_staticMetaObjectContent_ZN16KPublicTransport12UpdateResultE.staticData;
static constexpr auto qt_staticMetaObjectRelocatingContent_ZN16KPublicTransport12UpdateResultE =
    qt_staticMetaObjectContent_ZN16KPublicTransport12UpdateResultE.relocatingData;

Q_CONSTINIT const QMetaObject KPublicTransport::UpdateResult::staticMetaObject = { {
    nullptr,
    qt_staticMetaObjectStaticContent_ZN16KPublicTransport12UpdateResultE.stringdata,
    qt_staticMetaObjectStaticContent_ZN16KPublicTransport12UpdateResultE.data,
    nullptr,
    nullptr,
    qt_staticMetaObjectRelocatingContent_ZN16KPublicTransport12UpdateResultE.metaTypes,
    nullptr
} };

QT_WARNING_POP
