// This file is autogenerated. Changes will be overwritten.
#include "FVSNT77ZGO/moc_abstractonboardbackend_p.cpp"
#include "FVSNT77ZGO/moc_restonboardbackend_p.cpp"
#include "FVSNT77ZGO/moc_scriptedrestonboardbackend_p.cpp"
#include "EWIEGA46WW/moc_onboardstatusmanager_p.cpp"
#include "EWIEGA46WW/moc_wifimonitor_p.cpp"
