/****************************************************************************
** Meta object code from reading C++ file 'equipment.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.12.0)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../../kpublictransport-26.07.90/src/lib/datatypes/equipment.h"
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'equipment.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.12.0. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN16KPublicTransport9EquipmentE_t {};
} // unnamed namespace

template <> constexpr inline auto KPublicTransport::Equipment::qt_create_metaobjectdata<qt_meta_tag_ZN16KPublicTransport9EquipmentE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "KPublicTransport::Equipment",
        "type",
        "Type",
        "disruptionEffect",
        "KPublicTransport::Disruption::Effect",
        "notes",
        "iconName",
        "Unknown",
        "Elevator",
        "Escalator"
    };

    QtMocHelpers::UintData qt_methods {
    };
    QtMocHelpers::UintData qt_properties {
        // property 'type'
        QtMocHelpers::PropertyData<enum Type>(1, 0x80000000 | 2, QMC::DefaultPropertyFlags | QMC::Writable | QMC::EnumOrFlag | QMC::StdCppSet),
        // property 'disruptionEffect'
        QtMocHelpers::PropertyData<KPublicTransport::Disruption::Effect>(3, 0x80000000 | 4, QMC::DefaultPropertyFlags | QMC::Writable | QMC::EnumOrFlag | QMC::StdCppSet),
        // property 'notes'
        QtMocHelpers::PropertyData<QStringList>(5, QMetaType::QStringList, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet),
        // property 'iconName'
        QtMocHelpers::PropertyData<QString>(6, QMetaType::QString, QMC::Readable | QMC::Designable | QMC::Scriptable),
    };
    QtMocHelpers::UintData qt_enums {
        // enum 'Type'
        QtMocHelpers::EnumData<enum Type>(2, 2, QMC::EnumFlags{}).add({
            {    7, Type::Unknown },
            {    8, Type::Elevator },
            {    9, Type::Escalator },
        }),
    };
    return QtMocHelpers::metaObjectData<Equipment, qt_meta_tag_ZN16KPublicTransport9EquipmentE_t>(QMC::PropertyAccessInStaticMetaCall, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT static const QMetaObject::SuperData qt_meta_extradata_ZN16KPublicTransport9EquipmentE[] = {
    QMetaObject::SuperData::link<KPublicTransport::Disruption::staticMetaObject>(),
    nullptr
};

Q_CONSTINIT const QMetaObject KPublicTransport::Equipment::staticMetaObject = { {
    nullptr,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN16KPublicTransport9EquipmentE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN16KPublicTransport9EquipmentE_t>.data,
    qt_static_metacall,
    qt_meta_extradata_ZN16KPublicTransport9EquipmentE,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN16KPublicTransport9EquipmentE_t>.metaTypes,
    nullptr
} };

void KPublicTransport::Equipment::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = reinterpret_cast<Equipment *>(_o);
    if (_c == QMetaObject::ReadProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: *reinterpret_cast<enum Type*>(_v) = _t->type(); break;
        case 1: *reinterpret_cast<KPublicTransport::Disruption::Effect*>(_v) = _t->disruptionEffect(); break;
        case 2: *reinterpret_cast<QStringList*>(_v) = _t->notes(); break;
        case 3: *reinterpret_cast<QString*>(_v) = _t->iconName(); break;
        default: break;
        }
    }
    if (_c == QMetaObject::WriteProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: _t->setType(*reinterpret_cast<enum Type*>(_v)); break;
        case 1: _t->setDisruptionEffect(*reinterpret_cast<KPublicTransport::Disruption::Effect*>(_v)); break;
        case 2: _t->setNotes(*reinterpret_cast<QStringList*>(_v)); break;
        default: break;
        }
    }
}
QT_WARNING_POP
