/****************************************************************************
** Meta object code from reading C++ file 'manager.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.12.0)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../../kpublictransport-26.07.90/src/lib/manager.h"
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'manager.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.12.0. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN16KPublicTransport7ManagerE_t {};
} // unnamed namespace

template <> constexpr inline auto KPublicTransport::Manager::qt_create_metaobjectdata<qt_meta_tag_ZN16KPublicTransport7ManagerE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "KPublicTransport::Manager",
        "attributionsChanged",
        "",
        "configurationChanged",
        "backendsChanged",
        "updateResultChanged",
        "reload",
        "queryTrip",
        "KPublicTransport::TripReply*",
        "TripRequest",
        "req",
        "isBackendEnabled",
        "backendId",
        "checkForUpdates",
        "force",
        "attributions",
        "QVariantList",
        "allowInsecureBackends",
        "enabledBackends",
        "disabledBackends",
        "backendsEnabledByDefault",
        "updateResult",
        "KPublicTransport::UpdateResult::Type"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'attributionsChanged'
        QtMocHelpers::SignalData<void()>(1, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'configurationChanged'
        QtMocHelpers::SignalData<void()>(3, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'backendsChanged'
        QtMocHelpers::SignalData<void()>(4, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'updateResultChanged'
        QtMocHelpers::SignalData<void()>(5, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'reload'
        QtMocHelpers::SlotData<void()>(6, 2, QMC::AccessPublic, QMetaType::Void),
        // Method 'queryTrip'
        QtMocHelpers::MethodData<KPublicTransport::TripReply *(const TripRequest &) const>(7, 2, QMC::AccessPublic, 0x80000000 | 8, {{
            { 0x80000000 | 9, 10 },
        }}),
        // Method 'isBackendEnabled'
        QtMocHelpers::MethodData<bool(const QString &) const>(11, 2, QMC::AccessPublic, QMetaType::Bool, {{
            { QMetaType::QString, 12 },
        }}),
        // Method 'checkForUpdates'
        QtMocHelpers::MethodData<void(bool)>(13, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 14 },
        }}),
        // Method 'checkForUpdates'
        QtMocHelpers::MethodData<void()>(13, 2, QMC::AccessPublic | QMC::MethodCloned, QMetaType::Void),
    };
    QtMocHelpers::UintData qt_properties {
        // property 'attributions'
        QtMocHelpers::PropertyData<QVariantList>(15, 0x80000000 | 16, QMC::DefaultPropertyFlags | QMC::EnumOrFlag, 0),
        // property 'allowInsecureBackends'
        QtMocHelpers::PropertyData<bool>(17, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 1),
        // property 'enabledBackends'
        QtMocHelpers::PropertyData<QStringList>(18, QMetaType::QStringList, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 1),
        // property 'disabledBackends'
        QtMocHelpers::PropertyData<QStringList>(19, QMetaType::QStringList, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 1),
        // property 'backendsEnabledByDefault'
        QtMocHelpers::PropertyData<bool>(20, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 1),
        // property 'updateResult'
        QtMocHelpers::PropertyData<KPublicTransport::UpdateResult::Type>(21, 0x80000000 | 22, QMC::DefaultPropertyFlags | QMC::EnumOrFlag, 3),
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<Manager, qt_meta_tag_ZN16KPublicTransport7ManagerE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT static const QMetaObject::SuperData qt_meta_extradata_ZN16KPublicTransport7ManagerE[] = {
    QMetaObject::SuperData::link<KPublicTransport::UpdateResult::staticMetaObject>(),
    nullptr
};

Q_CONSTINIT const QMetaObject KPublicTransport::Manager::staticMetaObject = { {
    QMetaObject::SuperData::link<QObject::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN16KPublicTransport7ManagerE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN16KPublicTransport7ManagerE_t>.data,
    qt_static_metacall,
    qt_meta_extradata_ZN16KPublicTransport7ManagerE,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN16KPublicTransport7ManagerE_t>.metaTypes,
    nullptr
} };

void KPublicTransport::Manager::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<Manager *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->attributionsChanged(); break;
        case 1: _t->configurationChanged(); break;
        case 2: _t->backendsChanged(); break;
        case 3: _t->updateResultChanged(); break;
        case 4: _t->reload(); break;
        case 5: { KPublicTransport::TripReply* _r = _t->queryTrip((*reinterpret_cast<std::add_pointer_t<TripRequest>>(_a[1])));
            if (_a[0]) *reinterpret_cast<KPublicTransport::TripReply**>(_a[0]) = std::move(_r); }  break;
        case 6: { bool _r = _t->isBackendEnabled((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])));
            if (_a[0]) *reinterpret_cast<bool*>(_a[0]) = std::move(_r); }  break;
        case 7: _t->checkForUpdates((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 8: _t->checkForUpdates(); break;
        default: ;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (Manager::*)()>(_a, &Manager::attributionsChanged, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (Manager::*)()>(_a, &Manager::configurationChanged, 1))
            return;
        if (QtMocHelpers::indexOfMethod<void (Manager::*)()>(_a, &Manager::backendsChanged, 2))
            return;
        if (QtMocHelpers::indexOfMethod<void (Manager::*)()>(_a, &Manager::updateResultChanged, 3))
            return;
    }
    if (_c == QMetaObject::ReadProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: *reinterpret_cast<QVariantList*>(_v) = _t->attributionsVariant(); break;
        case 1: *reinterpret_cast<bool*>(_v) = _t->allowInsecureBackends(); break;
        case 2: *reinterpret_cast<QStringList*>(_v) = _t->enabledBackends(); break;
        case 3: *reinterpret_cast<QStringList*>(_v) = _t->disabledBackends(); break;
        case 4: *reinterpret_cast<bool*>(_v) = _t->backendsEnabledByDefault(); break;
        case 5: *reinterpret_cast<KPublicTransport::UpdateResult::Type*>(_v) = _t->updateResult(); break;
        default: break;
        }
    }
    if (_c == QMetaObject::WriteProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 1: _t->setAllowInsecureBackends(*reinterpret_cast<bool*>(_v)); break;
        case 2: _t->setEnabledBackends(*reinterpret_cast<QStringList*>(_v)); break;
        case 3: _t->setDisabledBackends(*reinterpret_cast<QStringList*>(_v)); break;
        case 4: _t->setBackendsEnabledByDefault(*reinterpret_cast<bool*>(_v)); break;
        default: break;
        }
    }
}

const QMetaObject *KPublicTransport::Manager::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *KPublicTransport::Manager::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN16KPublicTransport7ManagerE_t>.strings))
        return static_cast<void*>(this);
    return QObject::qt_metacast(_clname);
}

int KPublicTransport::Manager::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QObject::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 9)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 9;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 9)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 9;
    }
    if (_c == QMetaObject::ReadProperty || _c == QMetaObject::WriteProperty
            || _c == QMetaObject::ResetProperty || _c == QMetaObject::BindableProperty
            || _c == QMetaObject::RegisterPropertyMetaType) {
        qt_static_metacall(this, _c, _id, _a);
        _id -= 6;
    }
    return _id;
}

// SIGNAL 0
void KPublicTransport::Manager::attributionsChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 0, nullptr);
}

// SIGNAL 1
void KPublicTransport::Manager::configurationChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 1, nullptr);
}

// SIGNAL 2
void KPublicTransport::Manager::backendsChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 2, nullptr);
}

// SIGNAL 3
void KPublicTransport::Manager::updateResultChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 3, nullptr);
}
QT_WARNING_POP
