/****************************************************************************
** Meta object code from reading C++ file 'coveragearea.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.12.0)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../../kpublictransport-26.07.90/src/lib/datatypes/coveragearea.h"
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'coveragearea.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.12.0. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN16KPublicTransport12CoverageAreaE_t {};
} // unnamed namespace

template <> constexpr inline auto KPublicTransport::CoverageArea::qt_create_metaobjectdata<qt_meta_tag_ZN16KPublicTransport12CoverageAreaE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "KPublicTransport::CoverageArea",
        "type",
        "Type",
        "regions",
        "uicCompanyCodes",
        "vdvOrganizationIds",
        "Realtime",
        "Regular",
        "Any"
    };

    QtMocHelpers::UintData qt_methods {
    };
    QtMocHelpers::UintData qt_properties {
        // property 'type'
        QtMocHelpers::PropertyData<enum Type>(1, 0x80000000 | 2, QMC::DefaultPropertyFlags | QMC::Writable | QMC::EnumOrFlag | QMC::StdCppSet),
        // property 'regions'
        QtMocHelpers::PropertyData<QStringList>(3, QMetaType::QStringList, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet),
        // property 'uicCompanyCodes'
        QtMocHelpers::PropertyData<QStringList>(4, QMetaType::QStringList, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet),
        // property 'vdvOrganizationIds'
        QtMocHelpers::PropertyData<QStringList>(5, QMetaType::QStringList, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet),
    };
    QtMocHelpers::UintData qt_enums {
        // enum 'Type'
        QtMocHelpers::EnumData<enum Type>(2, 2, QMC::EnumFlags{}).add({
            {    6, Type::Realtime },
            {    7, Type::Regular },
            {    8, Type::Any },
        }),
    };
    return QtMocHelpers::metaObjectData<CoverageArea, qt_meta_tag_ZN16KPublicTransport12CoverageAreaE_t>(QMC::PropertyAccessInStaticMetaCall, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject KPublicTransport::CoverageArea::staticMetaObject = { {
    nullptr,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN16KPublicTransport12CoverageAreaE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN16KPublicTransport12CoverageAreaE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN16KPublicTransport12CoverageAreaE_t>.metaTypes,
    nullptr
} };

void KPublicTransport::CoverageArea::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = reinterpret_cast<CoverageArea *>(_o);
    if (_c == QMetaObject::ReadProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: *reinterpret_cast<enum Type*>(_v) = _t->type(); break;
        case 1: *reinterpret_cast<QStringList*>(_v) = _t->regions(); break;
        case 2: *reinterpret_cast<QStringList*>(_v) = _t->uicCompanyCodes(); break;
        case 3: *reinterpret_cast<QStringList*>(_v) = _t->vdvOrganizationIds(); break;
        default: break;
        }
    }
    if (_c == QMetaObject::WriteProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: _t->setType(*reinterpret_cast<enum Type*>(_v)); break;
        case 1: _t->setRegions(*reinterpret_cast<QStringList*>(_v)); break;
        case 2: _t->setUicCompanyCodes(*reinterpret_cast<QStringList*>(_v)); break;
        case 3: _t->setVdvOrganizationIds(*reinterpret_cast<QStringList*>(_v)); break;
        default: break;
        }
    }
}
QT_WARNING_POP
