/****************************************************************************
** Meta object code from reading C++ file 'maputils.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.12.0)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../../kpublictransport-26.07.90/src/quick/maputils.h"
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'maputils.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.12.0. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN16KPublicTransport10CoordinateE_t {};
} // unnamed namespace

template <> constexpr inline auto KPublicTransport::Coordinate::qt_create_metaobjectdata<qt_meta_tag_ZN16KPublicTransport10CoordinateE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "KPublicTransport::Coordinate",
        "QML.Element",
        "anonymous",
        "latitude",
        "longitude"
    };

    QtMocHelpers::UintData qt_methods {
    };
    QtMocHelpers::UintData qt_properties {
        // property 'latitude'
        QtMocHelpers::PropertyData<double>(3, QMetaType::Double, QMC::DefaultPropertyFlags | QMC::Writable),
        // property 'longitude'
        QtMocHelpers::PropertyData<double>(4, QMetaType::Double, QMC::DefaultPropertyFlags | QMC::Writable),
    };
    QtMocHelpers::UintData qt_enums {
    };
    QtMocHelpers::UintData qt_constructors {};
    QtMocHelpers::ClassInfos qt_classinfo({
            {    1,    2 },
    });
    return QtMocHelpers::metaObjectData<Coordinate, void>(QMC::PropertyAccessInStaticMetaCall, qt_stringData,
            qt_methods, qt_properties, qt_enums, qt_constructors, qt_classinfo);
}
Q_CONSTINIT const QMetaObject KPublicTransport::Coordinate::staticMetaObject = { {
    nullptr,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN16KPublicTransport10CoordinateE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN16KPublicTransport10CoordinateE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN16KPublicTransport10CoordinateE_t>.metaTypes,
    nullptr
} };

void KPublicTransport::Coordinate::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = reinterpret_cast<Coordinate *>(_o);
    if (_c == QMetaObject::ReadProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: *reinterpret_cast<double*>(_v) = _t->latitude; break;
        case 1: *reinterpret_cast<double*>(_v) = _t->longitude; break;
        default: break;
        }
    }
    if (_c == QMetaObject::WriteProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: QtMocHelpers::setProperty(_t->latitude, *reinterpret_cast<double*>(_v)); break;
        case 1: QtMocHelpers::setProperty(_t->longitude, *reinterpret_cast<double*>(_v)); break;
        default: break;
        }
    }
}
namespace {
struct qt_meta_tag_ZN16KPublicTransport8MapUtilsE_t {};
} // unnamed namespace

template <> constexpr inline auto KPublicTransport::MapUtils::qt_create_metaobjectdata<qt_meta_tag_ZN16KPublicTransport8MapUtilsE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "KPublicTransport::MapUtils",
        "polyline",
        "QJSValue",
        "",
        "KPublicTransport::JourneySection",
        "jny",
        "KPublicTransport::Path",
        "path",
        "KPublicTransport::PathSection",
        "pathSection",
        "boundingBox",
        "QRectF",
        "KPublicTransport::Journey",
        "boundingBoxForCountry",
        "countryCode",
        "center",
        "bbox",
        "zoomLevel",
        "width",
        "height"
    };

    QtMocHelpers::UintData qt_methods {
        // Method 'polyline'
        QtMocHelpers::MethodData<QJSValue(const KPublicTransport::JourneySection &) const>(1, 3, QMC::AccessPublic, 0x80000000 | 2, {{
            { 0x80000000 | 4, 5 },
        }}),
        // Method 'polyline'
        QtMocHelpers::MethodData<QJSValue(const KPublicTransport::Path &) const>(1, 3, QMC::AccessPublic, 0x80000000 | 2, {{
            { 0x80000000 | 6, 7 },
        }}),
        // Method 'polyline'
        QtMocHelpers::MethodData<QJSValue(const KPublicTransport::PathSection &) const>(1, 3, QMC::AccessPublic, 0x80000000 | 2, {{
            { 0x80000000 | 8, 9 },
        }}),
        // Method 'boundingBox'
        QtMocHelpers::MethodData<QRectF(const KPublicTransport::Journey &)>(10, 3, QMC::AccessPublic, 0x80000000 | 11, {{
            { 0x80000000 | 12, 5 },
        }}),
        // Method 'boundingBox'
        QtMocHelpers::MethodData<QRectF(const KPublicTransport::JourneySection &)>(10, 3, QMC::AccessPublic, 0x80000000 | 11, {{
            { 0x80000000 | 4, 5 },
        }}),
        // Method 'boundingBox'
        QtMocHelpers::MethodData<QRectF(const KPublicTransport::Path &)>(10, 3, QMC::AccessPublic, 0x80000000 | 11, {{
            { 0x80000000 | 6, 7 },
        }}),
        // Method 'boundingBox'
        QtMocHelpers::MethodData<QRectF(const KPublicTransport::PathSection &)>(10, 3, QMC::AccessPublic, 0x80000000 | 11, {{
            { 0x80000000 | 8, 9 },
        }}),
        // Method 'boundingBoxForCountry'
        QtMocHelpers::MethodData<QRectF(const QString &)>(13, 3, QMC::AccessPublic, 0x80000000 | 11, {{
            { QMetaType::QString, 14 },
        }}),
        // Method 'center'
        QtMocHelpers::MethodData<QJSValue(const QRectF &) const>(15, 3, QMC::AccessPublic, 0x80000000 | 2, {{
            { 0x80000000 | 11, 16 },
        }}),
        // Method 'zoomLevel'
        QtMocHelpers::MethodData<double(const QRectF &, double, double)>(17, 3, QMC::AccessPublic, QMetaType::Double, {{
            { 0x80000000 | 11, 16 }, { QMetaType::Double, 18 }, { QMetaType::Double, 19 },
        }}),
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<MapUtils, qt_meta_tag_ZN16KPublicTransport8MapUtilsE_t>(QMC::PropertyAccessInStaticMetaCall, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject KPublicTransport::MapUtils::staticMetaObject = { {
    nullptr,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN16KPublicTransport8MapUtilsE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN16KPublicTransport8MapUtilsE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN16KPublicTransport8MapUtilsE_t>.metaTypes,
    nullptr
} };

void KPublicTransport::MapUtils::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = reinterpret_cast<MapUtils *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: { QJSValue _r = _t->polyline((*reinterpret_cast<std::add_pointer_t<KPublicTransport::JourneySection>>(_a[1])));
            if (_a[0]) *reinterpret_cast<QJSValue*>(_a[0]) = std::move(_r); }  break;
        case 1: { QJSValue _r = _t->polyline((*reinterpret_cast<std::add_pointer_t<KPublicTransport::Path>>(_a[1])));
            if (_a[0]) *reinterpret_cast<QJSValue*>(_a[0]) = std::move(_r); }  break;
        case 2: { QJSValue _r = _t->polyline((*reinterpret_cast<std::add_pointer_t<KPublicTransport::PathSection>>(_a[1])));
            if (_a[0]) *reinterpret_cast<QJSValue*>(_a[0]) = std::move(_r); }  break;
        case 3: { QRectF _r = _t->boundingBox((*reinterpret_cast<std::add_pointer_t<KPublicTransport::Journey>>(_a[1])));
            if (_a[0]) *reinterpret_cast<QRectF*>(_a[0]) = std::move(_r); }  break;
        case 4: { QRectF _r = _t->boundingBox((*reinterpret_cast<std::add_pointer_t<KPublicTransport::JourneySection>>(_a[1])));
            if (_a[0]) *reinterpret_cast<QRectF*>(_a[0]) = std::move(_r); }  break;
        case 5: { QRectF _r = _t->boundingBox((*reinterpret_cast<std::add_pointer_t<KPublicTransport::Path>>(_a[1])));
            if (_a[0]) *reinterpret_cast<QRectF*>(_a[0]) = std::move(_r); }  break;
        case 6: { QRectF _r = _t->boundingBox((*reinterpret_cast<std::add_pointer_t<KPublicTransport::PathSection>>(_a[1])));
            if (_a[0]) *reinterpret_cast<QRectF*>(_a[0]) = std::move(_r); }  break;
        case 7: { QRectF _r = _t->boundingBoxForCountry((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])));
            if (_a[0]) *reinterpret_cast<QRectF*>(_a[0]) = std::move(_r); }  break;
        case 8: { QJSValue _r = _t->center((*reinterpret_cast<std::add_pointer_t<QRectF>>(_a[1])));
            if (_a[0]) *reinterpret_cast<QJSValue*>(_a[0]) = std::move(_r); }  break;
        case 9: { double _r = _t->zoomLevel((*reinterpret_cast<std::add_pointer_t<QRectF>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<double>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<double>>(_a[3])));
            if (_a[0]) *reinterpret_cast<double*>(_a[0]) = std::move(_r); }  break;
        default: ;
        }
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        switch (_id) {
        default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
        case 0:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< KPublicTransport::JourneySection >(); break;
            }
            break;
        case 1:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< KPublicTransport::Path >(); break;
            }
            break;
        case 2:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< KPublicTransport::PathSection >(); break;
            }
            break;
        case 3:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< KPublicTransport::Journey >(); break;
            }
            break;
        case 4:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< KPublicTransport::JourneySection >(); break;
            }
            break;
        case 5:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< KPublicTransport::Path >(); break;
            }
            break;
        case 6:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< KPublicTransport::PathSection >(); break;
            }
            break;
        }
    }
}
QT_WARNING_POP
