/****************************************************************************
** Meta object code from reading C++ file 'rentalvehicle.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.12.0)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../../kpublictransport-26.07.90/src/lib/datatypes/rentalvehicle.h"
#include <QtCore/qmetatype.h>
#include <QtCore/QList>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'rentalvehicle.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.12.0. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN16KPublicTransport13RentalVehicleE_t {};
} // unnamed namespace

template <> constexpr inline auto KPublicTransport::RentalVehicle::qt_create_metaobjectdata<qt_meta_tag_ZN16KPublicTransport13RentalVehicleE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "KPublicTransport::RentalVehicle",
        "type",
        "VehicleType",
        "network",
        "KPublicTransport::RentalVehicleNetwork",
        "vehicleType",
        "KPublicTransport::RentalVehicleType",
        "remainingRange",
        "vehicleTypeIconName",
        "webBookingUrl",
        "QUrl",
        "appBookingUrl",
        "label",
        "Unknown",
        "Bicycle",
        "Pedelec",
        "ElectricKickScooter",
        "ElectricMoped",
        "Car",
        "VehicleTypes"
    };

    QtMocHelpers::UintData qt_methods {
    };
    QtMocHelpers::UintData qt_properties {
        // property 'type'
        QtMocHelpers::PropertyData<enum VehicleType>(1, 0x80000000 | 2, QMC::Readable | QMC::Designable | QMC::Scriptable | QMC::EnumOrFlag),
        // property 'network'
        QtMocHelpers::PropertyData<KPublicTransport::RentalVehicleNetwork>(3, 0x80000000 | 4, QMC::DefaultPropertyFlags | QMC::Writable | QMC::EnumOrFlag | QMC::StdCppSet),
        // property 'vehicleType'
        QtMocHelpers::PropertyData<KPublicTransport::RentalVehicleType>(5, 0x80000000 | 6, QMC::DefaultPropertyFlags | QMC::Writable | QMC::EnumOrFlag | QMC::StdCppSet),
        // property 'remainingRange'
        QtMocHelpers::PropertyData<int>(7, QMetaType::Int, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet),
        // property 'vehicleTypeIconName'
        QtMocHelpers::PropertyData<QString>(8, QMetaType::QString, QMC::DefaultPropertyFlags),
        // property 'webBookingUrl'
        QtMocHelpers::PropertyData<QUrl>(9, 0x80000000 | 10, QMC::DefaultPropertyFlags | QMC::Writable | QMC::EnumOrFlag | QMC::StdCppSet),
        // property 'appBookingUrl'
        QtMocHelpers::PropertyData<QUrl>(11, 0x80000000 | 10, QMC::DefaultPropertyFlags | QMC::Writable | QMC::EnumOrFlag | QMC::StdCppSet),
        // property 'label'
        QtMocHelpers::PropertyData<QString>(12, QMetaType::QString, QMC::Readable | QMC::Designable | QMC::Scriptable),
    };
    QtMocHelpers::UintData qt_enums {
        // enum 'VehicleType'
        QtMocHelpers::EnumData<enum VehicleType>(2, 2, QMC::EnumFlags{}).add({
            {   13, VehicleType::Unknown },
            {   14, VehicleType::Bicycle },
            {   15, VehicleType::Pedelec },
            {   16, VehicleType::ElectricKickScooter },
            {   17, VehicleType::ElectricMoped },
            {   18, VehicleType::Car },
        }),
        // flag 'VehicleTypes'
        QtMocHelpers::EnumData<VehicleTypes>(19, 2, QMC::EnumIsFlag).add({
            {   13, VehicleType::Unknown },
            {   14, VehicleType::Bicycle },
            {   15, VehicleType::Pedelec },
            {   16, VehicleType::ElectricKickScooter },
            {   17, VehicleType::ElectricMoped },
            {   18, VehicleType::Car },
        }),
    };
    return QtMocHelpers::metaObjectData<RentalVehicle, qt_meta_tag_ZN16KPublicTransport13RentalVehicleE_t>(QMC::PropertyAccessInStaticMetaCall, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject KPublicTransport::RentalVehicle::staticMetaObject = { {
    nullptr,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN16KPublicTransport13RentalVehicleE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN16KPublicTransport13RentalVehicleE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN16KPublicTransport13RentalVehicleE_t>.metaTypes,
    nullptr
} };

void KPublicTransport::RentalVehicle::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = reinterpret_cast<RentalVehicle *>(_o);
    if (_c == QMetaObject::RegisterPropertyMetaType) {
        switch (_id) {
        default: *reinterpret_cast<int*>(_a[0]) = -1; break;
        case 1:
            *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< KPublicTransport::RentalVehicleNetwork >(); break;
        case 2:
            *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< KPublicTransport::RentalVehicleType >(); break;
        }
    }
    if (_c == QMetaObject::ReadProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: *reinterpret_cast<enum VehicleType*>(_v) = _t->type(); break;
        case 1: *reinterpret_cast<KPublicTransport::RentalVehicleNetwork*>(_v) = _t->network(); break;
        case 2: *reinterpret_cast<KPublicTransport::RentalVehicleType*>(_v) = _t->vehicleType(); break;
        case 3: *reinterpret_cast<int*>(_v) = _t->remainingRange(); break;
        case 4: *reinterpret_cast<QString*>(_v) = _t->vehicleTypeIconName(); break;
        case 5: *reinterpret_cast<QUrl*>(_v) = _t->webBookingUrl(); break;
        case 6: *reinterpret_cast<QUrl*>(_v) = _t->appBookingUrl(); break;
        case 7: *reinterpret_cast<QString*>(_v) = _t->label(); break;
        default: break;
        }
    }
    if (_c == QMetaObject::WriteProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 1: _t->setNetwork(*reinterpret_cast<KPublicTransport::RentalVehicleNetwork*>(_v)); break;
        case 2: _t->setVehicleType(*reinterpret_cast<KPublicTransport::RentalVehicleType*>(_v)); break;
        case 3: _t->setRemainingRange(*reinterpret_cast<int*>(_v)); break;
        case 5: _t->setWebBookingUrl(*reinterpret_cast<QUrl*>(_v)); break;
        case 6: _t->setAppBookingUrl(*reinterpret_cast<QUrl*>(_v)); break;
        default: break;
        }
    }
}
namespace {
struct qt_meta_tag_ZN16KPublicTransport17RentalVehicleTypeE_t {};
} // unnamed namespace

template <> constexpr inline auto KPublicTransport::RentalVehicleType::qt_create_metaobjectdata<qt_meta_tag_ZN16KPublicTransport17RentalVehicleTypeE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "KPublicTransport::RentalVehicleType",
        "RegisterEnumClassesUnscoped",
        "false",
        "typeIconName",
        "",
        "KPublicTransport::RentalVehicleType::FormFactor",
        "formFactor",
        "KPublicTransport::RentalVehicleType::PropulsionType",
        "propulsionType",
        "id",
        "name",
        "FormFactor",
        "PropulsionType",
        "maxRangeMeters",
        "riderCapacity",
        "co2EmissionPerKm",
        "returnConstraint",
        "ReturnConstraint",
        "label",
        "Undefined",
        "Bicycle",
        "CargoBicycle",
        "Car",
        "Moped",
        "ScooterStanding",
        "ScooterSeated",
        "Other",
        "Human",
        "ElectricAssist",
        "Electric",
        "Combustion",
        "CombustionDiesel",
        "Hybrid",
        "PlugInHybrid",
        "HydrogenFuelCell",
        "FreeFloating",
        "RoundtripStation",
        "AnyStation"
    };

    QtMocHelpers::UintData qt_methods {
        // Method 'typeIconName'
        QtMocHelpers::MethodData<QString(KPublicTransport::RentalVehicleType::FormFactor, KPublicTransport::RentalVehicleType::PropulsionType)>(3, 4, QMC::AccessPublic, QMetaType::QString, {{
            { 0x80000000 | 5, 6 }, { 0x80000000 | 7, 8 },
        }}),
    };
    QtMocHelpers::UintData qt_properties {
        // property 'id'
        QtMocHelpers::PropertyData<QString>(9, QMetaType::QString, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet),
        // property 'name'
        QtMocHelpers::PropertyData<QString>(10, QMetaType::QString, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet),
        // property 'formFactor'
        QtMocHelpers::PropertyData<enum FormFactor>(6, 0x80000000 | 11, QMC::DefaultPropertyFlags | QMC::Writable | QMC::EnumOrFlag | QMC::StdCppSet),
        // property 'propulsionType'
        QtMocHelpers::PropertyData<enum PropulsionType>(8, 0x80000000 | 12, QMC::DefaultPropertyFlags | QMC::Writable | QMC::EnumOrFlag | QMC::StdCppSet),
        // property 'maxRangeMeters'
        QtMocHelpers::PropertyData<double>(13, QMetaType::Double, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet),
        // property 'riderCapacity'
        QtMocHelpers::PropertyData<int>(14, QMetaType::Int, QMC::DefaultPropertyFlags | QMC::Writable),
        // property 'co2EmissionPerKm'
        QtMocHelpers::PropertyData<double>(15, QMetaType::Double, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet),
        // property 'returnConstraint'
        QtMocHelpers::PropertyData<enum ReturnConstraint>(16, 0x80000000 | 17, QMC::DefaultPropertyFlags | QMC::Writable | QMC::EnumOrFlag | QMC::StdCppSet),
        // property 'typeIconName'
        QtMocHelpers::PropertyData<QString>(3, QMetaType::QString, QMC::Readable | QMC::Designable | QMC::Scriptable),
        // property 'label'
        QtMocHelpers::PropertyData<QString>(18, QMetaType::QString, QMC::Readable | QMC::Designable | QMC::Scriptable),
    };
    QtMocHelpers::UintData qt_enums {
        // enum 'FormFactor'
        QtMocHelpers::EnumData<enum FormFactor>(11, 11, QMC::EnumIsScoped).add({
            {   19, FormFactor::Undefined },
            {   20, FormFactor::Bicycle },
            {   21, FormFactor::CargoBicycle },
            {   22, FormFactor::Car },
            {   23, FormFactor::Moped },
            {   24, FormFactor::ScooterStanding },
            {   25, FormFactor::ScooterSeated },
            {   26, FormFactor::Other },
        }),
        // enum 'PropulsionType'
        QtMocHelpers::EnumData<enum PropulsionType>(12, 12, QMC::EnumIsScoped).add({
            {   19, PropulsionType::Undefined },
            {   27, PropulsionType::Human },
            {   28, PropulsionType::ElectricAssist },
            {   29, PropulsionType::Electric },
            {   30, PropulsionType::Combustion },
            {   31, PropulsionType::CombustionDiesel },
            {   32, PropulsionType::Hybrid },
            {   33, PropulsionType::PlugInHybrid },
            {   34, PropulsionType::HydrogenFuelCell },
        }),
        // enum 'ReturnConstraint'
        QtMocHelpers::EnumData<enum ReturnConstraint>(17, 17, QMC::EnumIsScoped).add({
            {   19, ReturnConstraint::Undefined },
            {   35, ReturnConstraint::FreeFloating },
            {   36, ReturnConstraint::RoundtripStation },
            {   37, ReturnConstraint::AnyStation },
            {   32, ReturnConstraint::Hybrid },
        }),
    };
    QtMocHelpers::UintData qt_constructors {};
    QtMocHelpers::ClassInfos qt_classinfo({
            {    1,    2 },
    });
    return QtMocHelpers::metaObjectData<RentalVehicleType, qt_meta_tag_ZN16KPublicTransport17RentalVehicleTypeE_t>(QMC::PropertyAccessInStaticMetaCall, qt_stringData,
            qt_methods, qt_properties, qt_enums, qt_constructors, qt_classinfo);
}
Q_CONSTINIT const QMetaObject KPublicTransport::RentalVehicleType::staticMetaObject = { {
    nullptr,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN16KPublicTransport17RentalVehicleTypeE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN16KPublicTransport17RentalVehicleTypeE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN16KPublicTransport17RentalVehicleTypeE_t>.metaTypes,
    nullptr
} };

void KPublicTransport::RentalVehicleType::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = reinterpret_cast<RentalVehicleType *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: { QString _r = _t->typeIconName((*reinterpret_cast<std::add_pointer_t<KPublicTransport::RentalVehicleType::FormFactor>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<KPublicTransport::RentalVehicleType::PropulsionType>>(_a[2])));
            if (_a[0]) *reinterpret_cast<QString*>(_a[0]) = std::move(_r); }  break;
        default: ;
        }
    }
    if (_c == QMetaObject::ReadProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: *reinterpret_cast<QString*>(_v) = _t->id(); break;
        case 1: *reinterpret_cast<QString*>(_v) = _t->name(); break;
        case 2: *reinterpret_cast<enum FormFactor*>(_v) = _t->formFactor(); break;
        case 3: *reinterpret_cast<enum PropulsionType*>(_v) = _t->propulsionType(); break;
        case 4: *reinterpret_cast<double*>(_v) = _t->maxRangeMeters(); break;
        case 5: *reinterpret_cast<int*>(_v) = _t->riderCapacity(); break;
        case 6: *reinterpret_cast<double*>(_v) = _t->co2EmissionPerKm(); break;
        case 7: *reinterpret_cast<enum ReturnConstraint*>(_v) = _t->returnConstraint(); break;
        case 8: *reinterpret_cast<QString*>(_v) = _t->typeIconName(); break;
        case 9: *reinterpret_cast<QString*>(_v) = _t->label(); break;
        default: break;
        }
    }
    if (_c == QMetaObject::WriteProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: _t->setId(*reinterpret_cast<QString*>(_v)); break;
        case 1: _t->setName(*reinterpret_cast<QString*>(_v)); break;
        case 2: _t->setFormFactor(*reinterpret_cast<enum FormFactor*>(_v)); break;
        case 3: _t->setPropulsionType(*reinterpret_cast<enum PropulsionType*>(_v)); break;
        case 4: _t->setMaxRangeMeters(*reinterpret_cast<double*>(_v)); break;
        case 5: _t->setRiderCapcatiry(*reinterpret_cast<int*>(_v)); break;
        case 6: _t->setCo2EmissionPerKm(*reinterpret_cast<double*>(_v)); break;
        case 7: _t->setReturnConstraint(*reinterpret_cast<enum ReturnConstraint*>(_v)); break;
        default: break;
        }
    }
}
namespace {
struct qt_meta_tag_ZN16KPublicTransport20RentalVehicleStationE_t {};
} // unnamed namespace

template <> constexpr inline auto KPublicTransport::RentalVehicleStation::qt_create_metaobjectdata<qt_meta_tag_ZN16KPublicTransport20RentalVehicleStationE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "KPublicTransport::RentalVehicleStation",
        "capacityByType",
        "",
        "KPublicTransport::RentalVehicleType",
        "type",
        "availableVehiclesByType",
        "availableVehicles",
        "capacity",
        "network",
        "KPublicTransport::RentalVehicleNetwork",
        "isValid",
        "supportedVehicleTypes",
        "QList<KPublicTransport::RentalVehicleType>",
        "availableVehicleTypes",
        "webBookingUrl",
        "QUrl",
        "appBookingUrl",
        "openingHours",
        "iconName"
    };

    QtMocHelpers::UintData qt_methods {
        // Method 'capacityByType'
        QtMocHelpers::MethodData<int(const KPublicTransport::RentalVehicleType &) const>(1, 2, QMC::AccessPublic, QMetaType::Int, {{
            { 0x80000000 | 3, 4 },
        }}),
        // Method 'availableVehiclesByType'
        QtMocHelpers::MethodData<int(const KPublicTransport::RentalVehicleType &) const>(5, 2, QMC::AccessPublic, QMetaType::Int, {{
            { 0x80000000 | 3, 4 },
        }}),
    };
    QtMocHelpers::UintData qt_properties {
        // property 'availableVehicles'
        QtMocHelpers::PropertyData<int>(6, QMetaType::Int, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet),
        // property 'capacity'
        QtMocHelpers::PropertyData<int>(7, QMetaType::Int, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet),
        // property 'network'
        QtMocHelpers::PropertyData<KPublicTransport::RentalVehicleNetwork>(8, 0x80000000 | 9, QMC::DefaultPropertyFlags | QMC::Writable | QMC::EnumOrFlag | QMC::StdCppSet),
        // property 'isValid'
        QtMocHelpers::PropertyData<bool>(10, QMetaType::Bool, QMC::Readable | QMC::Designable | QMC::Scriptable),
        // property 'supportedVehicleTypes'
        QtMocHelpers::PropertyData<QList<KPublicTransport::RentalVehicleType>>(11, 0x80000000 | 12, QMC::Readable | QMC::Designable | QMC::Scriptable | QMC::EnumOrFlag),
        // property 'availableVehicleTypes'
        QtMocHelpers::PropertyData<QList<KPublicTransport::RentalVehicleType>>(13, 0x80000000 | 12, QMC::Readable | QMC::Designable | QMC::Scriptable | QMC::EnumOrFlag),
        // property 'webBookingUrl'
        QtMocHelpers::PropertyData<QUrl>(14, 0x80000000 | 15, QMC::DefaultPropertyFlags | QMC::Writable | QMC::EnumOrFlag | QMC::StdCppSet),
        // property 'appBookingUrl'
        QtMocHelpers::PropertyData<QUrl>(16, 0x80000000 | 15, QMC::DefaultPropertyFlags | QMC::Writable | QMC::EnumOrFlag | QMC::StdCppSet),
        // property 'openingHours'
        QtMocHelpers::PropertyData<QString>(17, QMetaType::QString, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet),
        // property 'iconName'
        QtMocHelpers::PropertyData<QString>(18, QMetaType::QString, QMC::Readable | QMC::Designable | QMC::Scriptable),
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<RentalVehicleStation, qt_meta_tag_ZN16KPublicTransport20RentalVehicleStationE_t>(QMC::PropertyAccessInStaticMetaCall, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject KPublicTransport::RentalVehicleStation::staticMetaObject = { {
    nullptr,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN16KPublicTransport20RentalVehicleStationE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN16KPublicTransport20RentalVehicleStationE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN16KPublicTransport20RentalVehicleStationE_t>.metaTypes,
    nullptr
} };

void KPublicTransport::RentalVehicleStation::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = reinterpret_cast<RentalVehicleStation *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: { int _r = _t->capacityByType((*reinterpret_cast<std::add_pointer_t<KPublicTransport::RentalVehicleType>>(_a[1])));
            if (_a[0]) *reinterpret_cast<int*>(_a[0]) = std::move(_r); }  break;
        case 1: { int _r = _t->availableVehiclesByType((*reinterpret_cast<std::add_pointer_t<KPublicTransport::RentalVehicleType>>(_a[1])));
            if (_a[0]) *reinterpret_cast<int*>(_a[0]) = std::move(_r); }  break;
        default: ;
        }
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        switch (_id) {
        default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
        case 0:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< KPublicTransport::RentalVehicleType >(); break;
            }
            break;
        case 1:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< KPublicTransport::RentalVehicleType >(); break;
            }
            break;
        }
    }
    if (_c == QMetaObject::RegisterPropertyMetaType) {
        switch (_id) {
        default: *reinterpret_cast<int*>(_a[0]) = -1; break;
        case 2:
            *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< KPublicTransport::RentalVehicleNetwork >(); break;
        case 5:
        case 4:
            *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< QList<KPublicTransport::RentalVehicleType> >(); break;
        }
    }
    if (_c == QMetaObject::ReadProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: *reinterpret_cast<int*>(_v) = _t->availableVehicles(); break;
        case 1: *reinterpret_cast<int*>(_v) = _t->capacity(); break;
        case 2: *reinterpret_cast<KPublicTransport::RentalVehicleNetwork*>(_v) = _t->network(); break;
        case 3: *reinterpret_cast<bool*>(_v) = _t->isValid(); break;
        case 4: *reinterpret_cast<QList<KPublicTransport::RentalVehicleType>*>(_v) = _t->supportedVehicleTypes(); break;
        case 5: *reinterpret_cast<QList<KPublicTransport::RentalVehicleType>*>(_v) = _t->availableVehicleTypes(); break;
        case 6: *reinterpret_cast<QUrl*>(_v) = _t->webBookingUrl(); break;
        case 7: *reinterpret_cast<QUrl*>(_v) = _t->appBookingUrl(); break;
        case 8: *reinterpret_cast<QString*>(_v) = _t->openingHours(); break;
        case 9: *reinterpret_cast<QString*>(_v) = _t->iconName(); break;
        default: break;
        }
    }
    if (_c == QMetaObject::WriteProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: _t->setAvailableVehicles(*reinterpret_cast<int*>(_v)); break;
        case 1: _t->setCapacity(*reinterpret_cast<int*>(_v)); break;
        case 2: _t->setNetwork(*reinterpret_cast<KPublicTransport::RentalVehicleNetwork*>(_v)); break;
        case 6: _t->setWebBookingUrl(*reinterpret_cast<QUrl*>(_v)); break;
        case 7: _t->setAppBookingUrl(*reinterpret_cast<QUrl*>(_v)); break;
        case 8: _t->setOpeningHours(*reinterpret_cast<QString*>(_v)); break;
        default: break;
        }
    }
}
namespace {
struct qt_meta_tag_ZN16KPublicTransport20RentalVehicleNetworkE_t {};
} // unnamed namespace

template <> constexpr inline auto KPublicTransport::RentalVehicleNetwork::qt_create_metaobjectdata<qt_meta_tag_ZN16KPublicTransport20RentalVehicleNetworkE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "KPublicTransport::RentalVehicleNetwork",
        "name",
        "url",
        "QUrl",
        "brandColor",
        "QColor",
        "hasBrandColor",
        "openingHours",
        "isValid"
    };

    QtMocHelpers::UintData qt_methods {
    };
    QtMocHelpers::UintData qt_properties {
        // property 'name'
        QtMocHelpers::PropertyData<QString>(1, QMetaType::QString, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet),
        // property 'url'
        QtMocHelpers::PropertyData<QUrl>(2, 0x80000000 | 3, QMC::DefaultPropertyFlags | QMC::Writable | QMC::EnumOrFlag | QMC::StdCppSet),
        // property 'brandColor'
        QtMocHelpers::PropertyData<QColor>(4, 0x80000000 | 5, QMC::DefaultPropertyFlags | QMC::Writable | QMC::EnumOrFlag | QMC::StdCppSet),
        // property 'hasBrandColor'
        QtMocHelpers::PropertyData<bool>(6, QMetaType::Bool, QMC::Readable | QMC::Designable | QMC::Scriptable),
        // property 'openingHours'
        QtMocHelpers::PropertyData<QString>(7, QMetaType::QString, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet),
        // property 'isValid'
        QtMocHelpers::PropertyData<bool>(8, QMetaType::Bool, QMC::Readable | QMC::Designable | QMC::Scriptable),
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<RentalVehicleNetwork, qt_meta_tag_ZN16KPublicTransport20RentalVehicleNetworkE_t>(QMC::PropertyAccessInStaticMetaCall, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject KPublicTransport::RentalVehicleNetwork::staticMetaObject = { {
    nullptr,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN16KPublicTransport20RentalVehicleNetworkE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN16KPublicTransport20RentalVehicleNetworkE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN16KPublicTransport20RentalVehicleNetworkE_t>.metaTypes,
    nullptr
} };

void KPublicTransport::RentalVehicleNetwork::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = reinterpret_cast<RentalVehicleNetwork *>(_o);
    if (_c == QMetaObject::ReadProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: *reinterpret_cast<QString*>(_v) = _t->name(); break;
        case 1: *reinterpret_cast<QUrl*>(_v) = _t->url(); break;
        case 2: *reinterpret_cast<QColor*>(_v) = _t->brandColor(); break;
        case 3: *reinterpret_cast<bool*>(_v) = _t->hasBrandColor(); break;
        case 4: *reinterpret_cast<QString*>(_v) = _t->openingHours(); break;
        case 5: *reinterpret_cast<bool*>(_v) = _t->isValid(); break;
        default: break;
        }
    }
    if (_c == QMetaObject::WriteProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: _t->setName(*reinterpret_cast<QString*>(_v)); break;
        case 1: _t->setUrl(*reinterpret_cast<QUrl*>(_v)); break;
        case 2: _t->setBrandColor(*reinterpret_cast<QColor*>(_v)); break;
        case 4: _t->setOpeningHours(*reinterpret_cast<QString*>(_v)); break;
        default: break;
        }
    }
}
QT_WARNING_POP
