// This file was generated by ecm_qt_declare_logging_category(): DO NOT EDIT!

#include "logging.h"

 namespace KPublicTransport {
Q_LOGGING_CATEGORY(Log, "org.kde.kpublictransport.onboard", QtInfoMsg)
} 
