/****************************************************************************
** Generated QML type registration code
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include <QtQml/qqml.h>
#include <QtQml/qqmlmoduleregistration.h>

#if __has_include(<kpublictransportqmlplugin.h>)
#  include <kpublictransportqmlplugin.h>
#endif


#if !defined(QT_STATIC)
#define Q_QMLTYPE_EXPORT Q_DECL_EXPORT
#else
#define Q_QMLTYPE_EXPORT
#endif
Q_QMLTYPE_EXPORT void qml_register_types_org_kde_kpublictransport()
{
    QT_WARNING_PUSH QT_WARNING_DISABLE_DEPRECATED
    qmlRegisterTypesAndRevisions<AttributionForeign>("org.kde.kpublictransport", 1);
    QMetaType::fromType<AttributionForeign *>().id();
    qmlRegisterTypesAndRevisions<BackendForeign>("org.kde.kpublictransport", 1);
    QMetaType::fromType<BackendForeign *>().id();
    qmlRegisterTypesAndRevisions<BackendModelForeign>("org.kde.kpublictransport", 1);
    QMetaType::fromType<BackendModelForeign *>().id();
    qmlRegisterEnum<KPublicTransport::BackendModel::Mode>("KPublicTransport::BackendModel::Mode");
    qmlRegisterTypesAndRevisions<CoverageArea>("org.kde.kpublictransport", 1);
    QMetaType::fromType<CoverageArea *>().id();
    qmlRegisterEnum<KPublicTransport::CoverageArea::Type>("KPublicTransport::CoverageArea::Type");
    QMetaType::fromType<CoverageAreaDerived>().id();
    qmlRegisterNamespaceAndRevisions(&CoverageAreaDerived::staticMetaObject, "org.kde.kpublictransport", 1, nullptr, &CoverageAreaDerivedForeign::staticMetaObject, nullptr);
    qmlRegisterTypesAndRevisions<CoverageCountryModelForeign>("org.kde.kpublictransport", 1);
    QMetaType::fromType<CoverageCountryModelForeign *>().id();
    qmlRegisterEnum<KPublicTransport::CoverageCountryModel::Roles>("KPublicTransport::CoverageCountryModel::Roles");
    {
        Q_CONSTINIT static auto metaType = QQmlPrivate::metaTypeForNamespace(
            [](const QtPrivate::QMetaTypeInterface *) {return &KPublicTransport::Disruption::staticMetaObject;},
            "KPublicTransport::Disruption");
        QMetaType(&metaType).id();
    }
    qmlRegisterNamespaceAndRevisions(&KPublicTransport::Disruption::staticMetaObject, "org.kde.kpublictransport", 1, nullptr, &DisruptionForeign::staticMetaObject, nullptr);
    qmlRegisterEnum<KPublicTransport::Disruption::Effect>("KPublicTransport::Disruption::Effect");
    QMetaType::fromType<EquipmentDerived>().id();
    qmlRegisterNamespaceAndRevisions(&EquipmentDerived::staticMetaObject, "org.kde.kpublictransport", 1, nullptr, &EquipmentDerivedForeign::staticMetaObject, nullptr);
    qmlRegisterTypesAndRevisions<EquipmentForeign>("org.kde.kpublictransport", 1);
    QMetaType::fromType<EquipmentForeign *>().id();
    qmlRegisterEnum<KPublicTransport::Equipment::Type>("KPublicTransport::Equipment::Type");
    QMetaType::fromType<FeatureDerived>().id();
    qmlRegisterNamespaceAndRevisions(&FeatureDerived::staticMetaObject, "org.kde.kpublictransport", 1, nullptr, &FeatureDerivedForeign::staticMetaObject, nullptr);
    qmlRegisterTypesAndRevisions<FeatureForeign>("org.kde.kpublictransport", 1);
    QMetaType::fromType<FeatureForeign *>().id();
    qmlRegisterEnum<KPublicTransport::Feature::Type>("KPublicTransport::Feature::Type");
    qmlRegisterEnum<KPublicTransport::Feature::Availability>("KPublicTransport::Feature::Availability");
    qmlRegisterTypesAndRevisions<FeatureType>("org.kde.kpublictransport", 1);
    QMetaType::fromType<FeatureType *>().id();
    QMetaType::fromType<IndividualTransportDerived>().id();
    qmlRegisterNamespaceAndRevisions(&IndividualTransportDerived::staticMetaObject, "org.kde.kpublictransport", 1, nullptr, &IndividualTransportDerivedForeign::staticMetaObject, nullptr);
    qmlRegisterTypesAndRevisions<IndividualTransportForeign>("org.kde.kpublictransport", 1);
    QMetaType::fromType<IndividualTransportForeign *>().id();
    qmlRegisterEnum<KPublicTransport::IndividualTransport::Mode>("KPublicTransport::IndividualTransport::Mode");
    qmlRegisterEnum<KPublicTransport::IndividualTransport::Qualifier>("KPublicTransport::IndividualTransport::Qualifier");
    qmlRegisterTypesAndRevisions<JourneyForeign>("org.kde.kpublictransport", 1);
    QMetaType::fromType<JourneyForeign *>().id();
    qmlRegisterTypesAndRevisions<JourneyQueryModelForeign>("org.kde.kpublictransport", 1);
    QMetaType::fromType<JourneyQueryModelForeign *>().id();
    qmlRegisterEnum<KPublicTransport::JourneyQueryModel::Roles>("KPublicTransport::JourneyQueryModel::Roles");
    QMetaType::fromType<JourneyRequestDerived>().id();
    qmlRegisterNamespaceAndRevisions(&JourneyRequestDerived::staticMetaObject, "org.kde.kpublictransport", 1, nullptr, &JourneyRequestDerivedForeign::staticMetaObject, nullptr);
    qmlRegisterTypesAndRevisions<JourneyRequestForeign>("org.kde.kpublictransport", 1);
    QMetaType::fromType<JourneyRequestForeign *>().id();
    qmlRegisterEnum<KPublicTransport::JourneyRequest::DateTimeMode>("KPublicTransport::JourneyRequest::DateTimeMode");
    QMetaType::fromType<JourneySectionDerived>().id();
    qmlRegisterNamespaceAndRevisions(&JourneySectionDerived::staticMetaObject, "org.kde.kpublictransport", 1, nullptr, &JourneySectionDerivedForeign::staticMetaObject, nullptr);
    qmlRegisterTypesAndRevisions<JourneySectionForeign>("org.kde.kpublictransport", 1);
    QMetaType::fromType<JourneySectionForeign *>().id();
    qmlRegisterEnum<KPublicTransport::JourneySection::Mode>("KPublicTransport::JourneySection::Mode");
    qmlRegisterEnum<KPublicTransport::JourneySection::Modes>("KPublicTransport::JourneySection::Modes");
    qmlRegisterEnum<KPublicTransport::JourneySection::Mode>("KPublicTransport::JourneySection::Mode");
    QMetaType::fromType<KPublicTransport::AbstractQueryModel *>().id();
    QMetaType::fromType<LineDerived>().id();
    qmlRegisterNamespaceAndRevisions(&LineDerived::staticMetaObject, "org.kde.kpublictransport", 1, nullptr, &LineDerivedForeign::staticMetaObject, nullptr);
    qmlRegisterTypesAndRevisions<LineForeign>("org.kde.kpublictransport", 1);
    QMetaType::fromType<LineForeign *>().id();
    qmlRegisterEnum<KPublicTransport::Line::Mode>("KPublicTransport::Line::Mode");
    qmlRegisterTypesAndRevisions<LineMode>("org.kde.kpublictransport", 1);
    QMetaType::fromType<LineMode *>().id();
    {
        Q_CONSTINIT static auto metaType = QQmlPrivate::metaTypeForNamespace(
            [](const QtPrivate::QMetaTypeInterface *) {return &KPublicTransport::Load::staticMetaObject;},
            "KPublicTransport::Load");
        QMetaType(&metaType).id();
    }
    qmlRegisterNamespaceAndRevisions(&KPublicTransport::Load::staticMetaObject, "org.kde.kpublictransport", 1, nullptr, &LoadForeign::staticMetaObject, nullptr);
    qmlRegisterEnum<KPublicTransport::Load::Category>("KPublicTransport::Load::Category");
    qmlRegisterTypesAndRevisions<LoadInfoForeign>("org.kde.kpublictransport", 1);
    QMetaType::fromType<LoadInfoForeign *>().id();
    QMetaType::fromType<LocationDerived>().id();
    qmlRegisterNamespaceAndRevisions(&LocationDerived::staticMetaObject, "org.kde.kpublictransport", 1, nullptr, &LocationDerivedForeign::staticMetaObject, nullptr);
    qmlRegisterTypesAndRevisions<LocationForeign>("org.kde.kpublictransport", 1);
    QMetaType::fromType<LocationForeign *>().id();
    qmlRegisterEnum<KPublicTransport::Location::Type>("KPublicTransport::Location::Type");
    qmlRegisterEnum<KPublicTransport::Location::Types>("KPublicTransport::Location::Types");
    qmlRegisterEnum<KPublicTransport::Location::Type>("KPublicTransport::Location::Type");
    qmlRegisterTypesAndRevisions<LocationHistoryModelForeign>("org.kde.kpublictransport", 1);
    QMetaType::fromType<LocationHistoryModelForeign *>().id();
    qmlRegisterEnum<KPublicTransport::LocationHistoryModel::Role>("KPublicTransport::LocationHistoryModel::Role");
    qmlRegisterTypesAndRevisions<LocationQueryModelForeign>("org.kde.kpublictransport", 1);
    QMetaType::fromType<LocationQueryModelForeign *>().id();
    qmlRegisterEnum<KPublicTransport::LocationQueryModel::Roles>("KPublicTransport::LocationQueryModel::Roles");
    QMetaType::fromType<LocationRequestDerived>().id();
    qmlRegisterNamespaceAndRevisions(&LocationRequestDerived::staticMetaObject, "org.kde.kpublictransport", 1, nullptr, &LocationRequestDerivedForeign::staticMetaObject, nullptr);
    qmlRegisterTypesAndRevisions<LocationRequestForeign>("org.kde.kpublictransport", 1);
    QMetaType::fromType<LocationRequestForeign *>().id();
    qmlRegisterTypesAndRevisions<ManagerForeign>("org.kde.kpublictransport", 1);
    QMetaType::fromType<ManagerForeign *>().id();
    qmlRegisterTypesAndRevisions<PathForeign>("org.kde.kpublictransport", 1);
    QMetaType::fromType<PathForeign *>().id();
    qmlRegisterTypesAndRevisions<PathModelForeign>("org.kde.kpublictransport", 1);
    QMetaType::fromType<PathModelForeign *>().id();
    QMetaType::fromType<PathSectionDerived>().id();
    qmlRegisterNamespaceAndRevisions(&PathSectionDerived::staticMetaObject, "org.kde.kpublictransport", 1, nullptr, &PathSectionDerivedForeign::staticMetaObject, nullptr);
    qmlRegisterTypesAndRevisions<PathSectionForeign>("org.kde.kpublictransport", 1);
    QMetaType::fromType<PathSectionForeign *>().id();
    qmlRegisterEnum<KPublicTransport::PathSection::Maneuver>("KPublicTransport::PathSection::Maneuver");
    {
        Q_CONSTINIT static auto metaType = QQmlPrivate::metaTypeForNamespace(
            [](const QtPrivate::QMetaTypeInterface *) {return &KPublicTransport::PickupDropoff::staticMetaObject;},
            "KPublicTransport::PickupDropoff");
        QMetaType(&metaType).id();
    }
    qmlRegisterNamespaceAndRevisions(&KPublicTransport::PickupDropoff::staticMetaObject, "org.kde.kpublictransport", 1, nullptr, &PickupDropoffForeign::staticMetaObject, nullptr);
    qmlRegisterEnum<KPublicTransport::PickupDropoff::Type>("KPublicTransport::PickupDropoff::Type");
    qmlRegisterTypesAndRevisions<PlatformForeign>("org.kde.kpublictransport", 1);
    QMetaType::fromType<PlatformForeign *>().id();
    qmlRegisterTypesAndRevisions<PlatformSectionForeign>("org.kde.kpublictransport", 1);
    QMetaType::fromType<PlatformSectionForeign *>().id();
    QMetaType::fromType<QAbstractItemModel *>().id();
    qmlRegisterEnum<QAbstractItemModel::LayoutChangeHint>("QAbstractItemModel::LayoutChangeHint");
    qmlRegisterEnum<QAbstractItemModel::CheckIndexOption>("QAbstractItemModel::CheckIndexOption");
    QMetaType::fromType<QAbstractListModel *>().id();
    QMetaType::fromType<RentalVehicleDerived>().id();
    qmlRegisterNamespaceAndRevisions(&RentalVehicleDerived::staticMetaObject, "org.kde.kpublictransport", 1, nullptr, &RentalVehicleDerivedForeign::staticMetaObject, nullptr);
    qmlRegisterTypesAndRevisions<RentalVehicleForeign>("org.kde.kpublictransport", 1);
    QMetaType::fromType<RentalVehicleForeign *>().id();
    qmlRegisterEnum<KPublicTransport::RentalVehicle::VehicleType>("KPublicTransport::RentalVehicle::VehicleType");
    qmlRegisterEnum<KPublicTransport::RentalVehicle::VehicleTypes>("KPublicTransport::RentalVehicle::VehicleTypes");
    qmlRegisterEnum<KPublicTransport::RentalVehicle::VehicleType>("KPublicTransport::RentalVehicle::VehicleType");
    qmlRegisterTypesAndRevisions<RentalVehicleNetworkForeign>("org.kde.kpublictransport", 1);
    QMetaType::fromType<RentalVehicleNetworkForeign *>().id();
    qmlRegisterTypesAndRevisions<RentalVehicleStationForeign>("org.kde.kpublictransport", 1);
    QMetaType::fromType<RentalVehicleStationForeign *>().id();
    QMetaType::fromType<RentalVehicleTypeDerived>().id();
    qmlRegisterNamespaceAndRevisions(&RentalVehicleTypeDerived::staticMetaObject, "org.kde.kpublictransport", 1, nullptr, &RentalVehicleTypeDerivedForeign::staticMetaObject, nullptr);
    qmlRegisterTypesAndRevisions<RentalVehicleTypeForeign>("org.kde.kpublictransport", 1);
    QMetaType::fromType<RentalVehicleTypeForeign *>().id();
    qmlRegisterEnum<KPublicTransport::RentalVehicleType::FormFactor>("KPublicTransport::RentalVehicleType::FormFactor");
    qmlRegisterEnum<KPublicTransport::RentalVehicleType::PropulsionType>("KPublicTransport::RentalVehicleType::PropulsionType");
    qmlRegisterEnum<KPublicTransport::RentalVehicleType::ReturnConstraint>("KPublicTransport::RentalVehicleType::ReturnConstraint");
    qmlRegisterTypesAndRevisions<ReplyForeign>("org.kde.kpublictransport", 1);
    QMetaType::fromType<ReplyForeign *>().id();
    qmlRegisterEnum<KPublicTransport::Reply::Error>("KPublicTransport::Reply::Error");
    qmlRegisterTypesAndRevisions<RouteForeign>("org.kde.kpublictransport", 1);
    QMetaType::fromType<RouteForeign *>().id();
    qmlRegisterTypesAndRevisions<StopInformationForeign>("org.kde.kpublictransport", 1);
    QMetaType::fromType<StopInformationForeign *>().id();
    qmlRegisterTypesAndRevisions<StopoverForeign>("org.kde.kpublictransport", 1);
    QMetaType::fromType<StopoverForeign *>().id();
    qmlRegisterTypesAndRevisions<StopoverQueryModelForeign>("org.kde.kpublictransport", 1);
    QMetaType::fromType<StopoverQueryModelForeign *>().id();
    qmlRegisterEnum<KPublicTransport::StopoverQueryModel::Roles>("KPublicTransport::StopoverQueryModel::Roles");
    QMetaType::fromType<StopoverRequestDerived>().id();
    qmlRegisterNamespaceAndRevisions(&StopoverRequestDerived::staticMetaObject, "org.kde.kpublictransport", 1, nullptr, &StopoverRequestDerivedForeign::staticMetaObject, nullptr);
    qmlRegisterTypesAndRevisions<StopoverRequestForeign>("org.kde.kpublictransport", 1);
    QMetaType::fromType<StopoverRequestForeign *>().id();
    qmlRegisterEnum<KPublicTransport::StopoverRequest::Mode>("KPublicTransport::StopoverRequest::Mode");
    qmlRegisterTypesAndRevisions<TripRequestForeign>("org.kde.kpublictransport", 1);
    QMetaType::fromType<TripRequestForeign *>().id();
    {
        Q_CONSTINIT static auto metaType = QQmlPrivate::metaTypeForNamespace(
            [](const QtPrivate::QMetaTypeInterface *) {return &KPublicTransport::UpdateResult::staticMetaObject;},
            "KPublicTransport::UpdateResult");
        QMetaType(&metaType).id();
    }
    qmlRegisterNamespaceAndRevisions(&KPublicTransport::UpdateResult::staticMetaObject, "org.kde.kpublictransport", 1, nullptr, &UpdateResultForeign::staticMetaObject, nullptr);
    qmlRegisterEnum<KPublicTransport::UpdateResult::Type>("KPublicTransport::UpdateResult::Type");
    QMetaType::fromType<VehicleDerived>().id();
    qmlRegisterNamespaceAndRevisions(&VehicleDerived::staticMetaObject, "org.kde.kpublictransport", 1, nullptr, &VehicleDerivedForeign::staticMetaObject, nullptr);
    qmlRegisterTypesAndRevisions<VehicleForeign>("org.kde.kpublictransport", 1);
    QMetaType::fromType<VehicleForeign *>().id();
    qmlRegisterEnum<KPublicTransport::Vehicle::Direction>("KPublicTransport::Vehicle::Direction");
    qmlRegisterTypesAndRevisions<VehicleLayoutQueryModelForeign>("org.kde.kpublictransport", 1);
    QMetaType::fromType<VehicleLayoutQueryModelForeign *>().id();
    qmlRegisterEnum<KPublicTransport::VehicleLayoutQueryModel::Roles>("KPublicTransport::VehicleLayoutQueryModel::Roles");
    QMetaType::fromType<VehicleLayoutRequestDerived>().id();
    qmlRegisterNamespaceAndRevisions(&VehicleLayoutRequestDerived::staticMetaObject, "org.kde.kpublictransport", 1, nullptr, &VehicleLayoutRequestDerivedForeign::staticMetaObject, nullptr);
    qmlRegisterTypesAndRevisions<VehicleLayoutRequestForeign>("org.kde.kpublictransport", 1);
    QMetaType::fromType<VehicleLayoutRequestForeign *>().id();
    QMetaType::fromType<VehicleSectionDerived>().id();
    qmlRegisterNamespaceAndRevisions(&VehicleSectionDerived::staticMetaObject, "org.kde.kpublictransport", 1, nullptr, &VehicleSectionDerivedForeign::staticMetaObject, nullptr);
    qmlRegisterTypesAndRevisions<VehicleSectionForeign>("org.kde.kpublictransport", 1);
    QMetaType::fromType<VehicleSectionForeign *>().id();
    qmlRegisterEnum<KPublicTransport::VehicleSection::Type>("KPublicTransport::VehicleSection::Type");
    qmlRegisterEnum<KPublicTransport::VehicleSection::Classes>("KPublicTransport::VehicleSection::Classes");
    qmlRegisterEnum<KPublicTransport::VehicleSection::Class>("KPublicTransport::VehicleSection::Class");
    qmlRegisterEnum<KPublicTransport::VehicleSection::Sides>("KPublicTransport::VehicleSection::Sides");
    qmlRegisterEnum<KPublicTransport::VehicleSection::Side>("KPublicTransport::VehicleSection::Side");
    QT_WARNING_POP
    qmlRegisterModule("org.kde.kpublictransport", 1, 0);
}

static const QQmlModuleRegistration orgkdekpublictransportRegistration("org.kde.kpublictransport", qml_register_types_org_kde_kpublictransport);
