/****************************************************************************
** Meta object code from reading C++ file 'mode.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.12.0)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../../kpublictransport-26.07.90/src/lib/siri/mode.h"
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'mode.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.12.0. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN16KPublicTransport4Siri4ModeE_t {};
} // unnamed namespace

template <> constexpr inline auto KPublicTransport::Siri::Mode::qt_create_metaobjectdata<qt_meta_tag_ZN16KPublicTransport4Siri4ModeE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "KPublicTransport::Siri::Mode",
        "VehicleMode",
        "air",
        "bus",
        "cableway",
        "water",
        "funicular",
        "lift",
        "rail",
        "snowAndIce",
        "metro",
        "taxi",
        "tram",
        "trolleybus",
        "monorail",
        "coach",
        "other",
        "unknown",
        "AirSubmode",
        "internationalFlight",
        "domesticFlight",
        "intercontinentalFlight",
        "domesticScheduledFlight",
        "shuttleFlight",
        "intercontinentalCharterFlight",
        "internationalCharterFlight",
        "roundTripCharterFlight",
        "sightseeingFlight",
        "helicopterService",
        "domesticCharterFlight",
        "SchengenAreaFlight",
        "airshipService",
        "shortHaulInternationalFlight",
        "BusSubmode",
        "localBus",
        "regionalBus",
        "expressBus",
        "nightBus",
        "postBus",
        "specialNeedsBus",
        "mobilityBus",
        "mobilityBusForRegisteredDisabled",
        "sightseeingBus",
        "shuttleBus",
        "highFrequencyBus",
        "dedicatedLaneBus",
        "schoolBus",
        "schoolAndPublicServiceBus",
        "railReplacementBus",
        "demandAndResponseBus",
        "airportLinkBus",
        "CoachSubmode",
        "internationalCoach",
        "nationalCoach",
        "shuttleCoach",
        "regionalCoach",
        "specialCoach",
        "schoolCoach",
        "sightseeingCoach",
        "touristCoach",
        "commuterCoach",
        "MetroSubmode",
        "tube",
        "urbanRailway",
        "RailSubmode",
        "local",
        "highSpeedRail",
        "suburbanRailway",
        "regionalRail",
        "interregionalRail",
        "longDistance",
        "international",
        "sleeperRailService",
        "nightRail",
        "carTransportRailService",
        "touristRailway",
        "airportLinkRail",
        "railShuttle",
        "replacementRailService",
        "specialTrain",
        "crossCountryRail",
        "rackAndPinionRailway",
        "TramSubmode",
        "cityTram",
        "localTram",
        "regionalTram",
        "sightseeingTram",
        "shuttleTram",
        "trainTram",
        "WaterSubmode",
        "internationalCarFerry",
        "nationalCarFerry",
        "regionalCarFerry",
        "localCarFerry",
        "internationalPassengerFerry",
        "nationalPassengerFerry",
        "regionalPassengerFerry",
        "localPassengerFerry",
        "postBoat",
        "trainFerry",
        "roadFerryLink",
        "airportBoatLink",
        "highSpeedVehicleService",
        "highSpeedPassengerService",
        "sightseeingService",
        "schoolBoat",
        "cableFerry",
        "riverBus",
        "scheduledFerry",
        "shuttleFerryService",
        "canalBarge",
        "TelecabinSubmode",
        "telecabin",
        "cableCar",
        "chairLift",
        "dragLift",
        "telecabinLink",
        "FunicularSubmode",
        "streetCableCar",
        "TaxiSubmode",
        "communalTaxi",
        "charterTaxi",
        "waterTaxi",
        "railTaxi",
        "bikeTaxi",
        "blackCab",
        "miniCab"
    };

    QtMocHelpers::UintData qt_methods {
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
        // enum 'VehicleMode'
        QtMocHelpers::EnumData<enum VehicleMode>(1, 1, QMC::EnumIsScoped).add({
            {    2, VehicleMode::air },
            {    3, VehicleMode::bus },
            {    4, VehicleMode::cableway },
            {    5, VehicleMode::water },
            {    6, VehicleMode::funicular },
            {    7, VehicleMode::lift },
            {    8, VehicleMode::rail },
            {    9, VehicleMode::snowAndIce },
            {   10, VehicleMode::metro },
            {   11, VehicleMode::taxi },
            {   12, VehicleMode::tram },
            {   13, VehicleMode::trolleybus },
            {   14, VehicleMode::monorail },
            {   15, VehicleMode::coach },
            {   16, VehicleMode::other },
            {   17, VehicleMode::unknown },
        }),
        // enum 'AirSubmode'
        QtMocHelpers::EnumData<enum AirSubmode>(18, 18, QMC::EnumIsScoped).add({
            {   19, AirSubmode::internationalFlight },
            {   20, AirSubmode::domesticFlight },
            {   21, AirSubmode::intercontinentalFlight },
            {   22, AirSubmode::domesticScheduledFlight },
            {   23, AirSubmode::shuttleFlight },
            {   24, AirSubmode::intercontinentalCharterFlight },
            {   25, AirSubmode::internationalCharterFlight },
            {   26, AirSubmode::roundTripCharterFlight },
            {   27, AirSubmode::sightseeingFlight },
            {   28, AirSubmode::helicopterService },
            {   29, AirSubmode::domesticCharterFlight },
            {   30, AirSubmode::SchengenAreaFlight },
            {   31, AirSubmode::airshipService },
            {   32, AirSubmode::shortHaulInternationalFlight },
        }),
        // enum 'BusSubmode'
        QtMocHelpers::EnumData<enum BusSubmode>(33, 33, QMC::EnumIsScoped).add({
            {   34, BusSubmode::localBus },
            {   35, BusSubmode::regionalBus },
            {   36, BusSubmode::expressBus },
            {   37, BusSubmode::nightBus },
            {   38, BusSubmode::postBus },
            {   39, BusSubmode::specialNeedsBus },
            {   40, BusSubmode::mobilityBus },
            {   41, BusSubmode::mobilityBusForRegisteredDisabled },
            {   42, BusSubmode::sightseeingBus },
            {   43, BusSubmode::shuttleBus },
            {   44, BusSubmode::highFrequencyBus },
            {   45, BusSubmode::dedicatedLaneBus },
            {   46, BusSubmode::schoolBus },
            {   47, BusSubmode::schoolAndPublicServiceBus },
            {   48, BusSubmode::railReplacementBus },
            {   49, BusSubmode::demandAndResponseBus },
            {   50, BusSubmode::airportLinkBus },
        }),
        // enum 'CoachSubmode'
        QtMocHelpers::EnumData<enum CoachSubmode>(51, 51, QMC::EnumIsScoped).add({
            {   52, CoachSubmode::internationalCoach },
            {   53, CoachSubmode::nationalCoach },
            {   54, CoachSubmode::shuttleCoach },
            {   55, CoachSubmode::regionalCoach },
            {   56, CoachSubmode::specialCoach },
            {   57, CoachSubmode::schoolCoach },
            {   58, CoachSubmode::sightseeingCoach },
            {   59, CoachSubmode::touristCoach },
            {   60, CoachSubmode::commuterCoach },
        }),
        // enum 'MetroSubmode'
        QtMocHelpers::EnumData<enum MetroSubmode>(61, 61, QMC::EnumIsScoped).add({
            {   10, MetroSubmode::metro },
            {   62, MetroSubmode::tube },
            {   63, MetroSubmode::urbanRailway },
        }),
        // enum 'RailSubmode'
        QtMocHelpers::EnumData<enum RailSubmode>(64, 64, QMC::EnumIsScoped).add({
            {   65, RailSubmode::local },
            {   66, RailSubmode::highSpeedRail },
            {   67, RailSubmode::suburbanRailway },
            {   68, RailSubmode::regionalRail },
            {   69, RailSubmode::interregionalRail },
            {   70, RailSubmode::longDistance },
            {   71, RailSubmode::international },
            {   72, RailSubmode::sleeperRailService },
            {   73, RailSubmode::nightRail },
            {   74, RailSubmode::carTransportRailService },
            {   75, RailSubmode::touristRailway },
            {   76, RailSubmode::airportLinkRail },
            {   77, RailSubmode::railShuttle },
            {   78, RailSubmode::replacementRailService },
            {   79, RailSubmode::specialTrain },
            {   80, RailSubmode::crossCountryRail },
            {   81, RailSubmode::rackAndPinionRailway },
        }),
        // enum 'TramSubmode'
        QtMocHelpers::EnumData<enum TramSubmode>(82, 82, QMC::EnumIsScoped).add({
            {   83, TramSubmode::cityTram },
            {   84, TramSubmode::localTram },
            {   85, TramSubmode::regionalTram },
            {   86, TramSubmode::sightseeingTram },
            {   87, TramSubmode::shuttleTram },
            {   88, TramSubmode::trainTram },
        }),
        // enum 'WaterSubmode'
        QtMocHelpers::EnumData<enum WaterSubmode>(89, 89, QMC::EnumIsScoped).add({
            {   90, WaterSubmode::internationalCarFerry },
            {   91, WaterSubmode::nationalCarFerry },
            {   92, WaterSubmode::regionalCarFerry },
            {   93, WaterSubmode::localCarFerry },
            {   94, WaterSubmode::internationalPassengerFerry },
            {   95, WaterSubmode::nationalPassengerFerry },
            {   96, WaterSubmode::regionalPassengerFerry },
            {   97, WaterSubmode::localPassengerFerry },
            {   98, WaterSubmode::postBoat },
            {   99, WaterSubmode::trainFerry },
            {  100, WaterSubmode::roadFerryLink },
            {  101, WaterSubmode::airportBoatLink },
            {  102, WaterSubmode::highSpeedVehicleService },
            {  103, WaterSubmode::highSpeedPassengerService },
            {  104, WaterSubmode::sightseeingService },
            {  105, WaterSubmode::schoolBoat },
            {  106, WaterSubmode::cableFerry },
            {  107, WaterSubmode::riverBus },
            {  108, WaterSubmode::scheduledFerry },
            {  109, WaterSubmode::shuttleFerryService },
            {  110, WaterSubmode::canalBarge },
        }),
        // enum 'TelecabinSubmode'
        QtMocHelpers::EnumData<enum TelecabinSubmode>(111, 111, QMC::EnumIsScoped).add({
            {  112, TelecabinSubmode::telecabin },
            {  113, TelecabinSubmode::cableCar },
            {    7, TelecabinSubmode::lift },
            {  114, TelecabinSubmode::chairLift },
            {  115, TelecabinSubmode::dragLift },
            {  116, TelecabinSubmode::telecabinLink },
        }),
        // enum 'FunicularSubmode'
        QtMocHelpers::EnumData<enum FunicularSubmode>(117, 117, QMC::EnumIsScoped).add({
            {    6, FunicularSubmode::funicular },
            {  118, FunicularSubmode::streetCableCar },
        }),
        // enum 'TaxiSubmode'
        QtMocHelpers::EnumData<enum TaxiSubmode>(119, 119, QMC::EnumIsScoped).add({
            {  120, TaxiSubmode::communalTaxi },
            {  121, TaxiSubmode::charterTaxi },
            {  122, TaxiSubmode::waterTaxi },
            {  123, TaxiSubmode::railTaxi },
            {  124, TaxiSubmode::bikeTaxi },
            {  125, TaxiSubmode::blackCab },
            {  126, TaxiSubmode::miniCab },
        }),
    };
    return QtMocHelpers::metaObjectData<Mode, qt_meta_tag_ZN16KPublicTransport4Siri4ModeE_t>(QMC::PropertyAccessInStaticMetaCall, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject KPublicTransport::Siri::Mode::staticMetaObject = { {
    nullptr,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN16KPublicTransport4Siri4ModeE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN16KPublicTransport4Siri4ModeE_t>.data,
    nullptr,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN16KPublicTransport4Siri4ModeE_t>.metaTypes,
    nullptr
} };

QT_WARNING_POP
